import { LayoutOptionBase, Node } from '../../types';
export interface BBox {
    x1: number;
    y1: number;
    x2?: number;
    y2?: number;
    w: number;
    h: number;
}
interface NodeValue {
    value: number;
    node: Node;
}
interface Level extends Array<NodeValue> {
    dTheta?: number;
    r?: number;
}
interface ConcentricConfig extends LayoutOptionBase {
    /** 同心圆的布局范围，默认为当前画布的宽高范围 */
    boundingBox: BBox;
    /** 节点间的距离，默认为60 */
    minNodeSpacing: number;
    /** 每层的节点度数范围 */
    levelWidth: (nodes: Node[], maxDegree: number) => number;
    counterclockwise: boolean;
    clockwise: boolean;
    concentric: (node: Node) => number;
    avoidOverlap: boolean;
    sweep?: number;
    equidistant: boolean;
    startAngle: number;
}
declare type PartialConcentricOption = Partial<Exclude<ConcentricConfig, keyof LayoutOptionBase>>;
export declare type ConcentricOption = PartialConcentricOption & LayoutOptionBase;
export declare const makeBoundingBox: (bb: BBox) => BBox | undefined;
declare class ConcentricLayout {
    options: ConcentricOption;
    constructor(options: Partial<ConcentricOption>);
    run(): {
        outerR: number | undefined;
        levels: Level[];
        nodes: Node[];
        edges: import("../../types").Edge[];
    };
}
export default ConcentricLayout;
