import React from 'react';
import { groupBy, pickBy, flatMap, cloneDeep, debounce } from 'lodash';
import G6 from '@antv/g6';
import svg2marker from 'svg2marker';
import { Shape } from '@antv/g-canvas';

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _isNativeReflectConstruct() {
  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
  if (Reflect.construct.sham) return false;
  if (typeof Proxy === "function") return true;

  try {
    Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
    return true;
  } catch (e) {
    return false;
  }
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

function _createSuper(Derived) {
  return function () {
    var Super = _getPrototypeOf(Derived),
        result;

    if (_isNativeReflectConstruct()) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(n);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var initGraphAfterRender = function initGraphAfterRender(props, graphDOM, instance) {
  var _props$options = props.options,
      options = _props$options === void 0 ? {} : _props$options;
  var pan = options.pan,
      zoom = options.zoom; // 平移

  if (pan) instance.moveTo(pan.x, pan.y); // 缩放

  if (zoom) instance.zoomTo(zoom, pan);
};

var initGraph = function initGraph(props, graphDOM, behaviorsMode) {
  var clientWidth = graphDOM.clientWidth,
      clientHeight = graphDOM.clientHeight;
  /** default options  */

  var defaultOptions = {
    // initial canvas
    container: graphDOM,
    renderer: 'canvas',
    width: clientWidth,
    height: clientHeight,
    // initial viewport state:
    zoom: 1,
    // pan: { x: clientWidth / 2, y: clientHeight / 2 },
    // interaction options:
    minZoom: 0.2,
    maxZoom: 10,
    // rendering options:
    animate: true,
    animateCfg: {
      onFrame: undefined,
      duration: 500,
      easing: 'easeLinear'
    },
    plugins: [],
    modes: {
      default: []
    },
    // Graphin unique options
    disablePan: false,
    disableZoom: false,
    disableDrag: false,
    wheelSensitivity: 1,
    // 必须将 groupByTypes 设置为 false，带有 combo 的图中元素的视觉层级才能合理:https://g6.antv.vision/zh/docs/manual/middle/combo
    groupByTypes: false,
    // 默认关闭多边设置
    autoPolyEdge: false,
    // 默认开启多边设置
    autoLoopEdge: true
  };
  /** merged options */

  var options = _objectSpread2({}, defaultOptions, {}, props.options || {});
  /** deconstruct g6 Options */


  var disableZoom = options.disableZoom,
      disablePan = options.disablePan,
      disableDrag = options.disableDrag,
      disableClick = options.disableClick,
      disableBrush = options.disableBrush,
      wheelSensitivity = options.wheelSensitivity,
      pan = options.pan,
      zoom = options.zoom,
      modes = options.modes,
      g6Options = _objectWithoutProperties(options, ["disableZoom", "disablePan", "disableDrag", "disableClick", "disableBrush", "wheelSensitivity", "pan", "zoom", "modes"]);
  /** Graphin built-in g6 behaviors */


  var innerBehaviors = [// 拖拽画布
  {
    type: 'drag-canvas',
    disable: disablePan,
    options: {}
  }, // 缩放画布
  {
    type: 'zoom-canvas',
    disable: disableZoom,
    options: {
      sensitivity: wheelSensitivity
    }
  }, // 画布框选
  {
    type: 'brush-select',
    disable: disableBrush,
    options: {
      trigger: 'shift',
      includeEdges: false
    }
  }, // 点击选择
  {
    type: 'click-select',
    disable: disableClick,
    options: {
      multiple: true,
      trigger: 'alt'
    }
  }, // 拖拽节点
  {
    type: 'drag-node',
    disable: disableDrag,
    options: {}
  }, // combo
  {
    type: 'drag-combo',
    options: {}
  }, {
    type: 'collapse-expand-combo',
    options: {}
  }];
  var defaultModes = innerBehaviors.filter(function (c) {
    return !c.disable;
  }).map(function (c) {
    return _objectSpread2({
      type: c.type
    }, c.options);
  });
  var instance = new G6.Graph(_objectSpread2({}, g6Options, {
    modes: _objectSpread2({}, behaviorsMode, {
      default: [].concat(_toConsumableArray(defaultModes), _toConsumableArray(modes.default), _toConsumableArray(behaviorsMode.default))
    })
  })); // close local refresh issue to avoid clip ghost

  instance.get('canvas').set('localRefresh', false); // 平移

  if (pan) instance.moveTo(pan.x, pan.y); // 缩放

  if (zoom) instance.zoomTo(zoom, pan);
  return {
    options: options || defaultOptions,
    instance: instance,
    width: clientWidth,
    height: clientHeight
  };
};

var DEFAULT_MARKER = {
  // 自然人icon
  person: {
    path: "<path d=\"M914.285769 802.889143q0 68.534857-41.691429 108.251429t-110.884571 39.716571l-499.419429 0q-69.12 0-110.884571-39.716571t-41.691429-108.251429q0-30.281143 1.974857-59.172571t7.972571-62.317714 15.140571-62.025143 24.576-55.734857 35.401143-46.299429 48.859429-30.573714 63.707429-11.410286q5.12 0 23.990857 12.288t42.569143 27.428571 61.732571 27.428571 76.288 12.288 76.288-12.288 61.732571-27.428571 42.569143-27.428571 23.990857-12.288q34.889143 0 63.707429 11.410286t48.859429 30.573714 35.401143 46.299429 24.576 55.734857 15.140571 62.025143 7.972571 62.317714 1.974857 59.172571zM731.428626 292.571429q0 90.843429-64.292571 155.136t-155.136 64.292571-155.136-64.292571-64.292571-155.136 64.292571-155.136 155.136-64.292571 155.136 64.292571 64.292571 155.136z\" p-id=\"2551\" />"
  },
  // 手机号
  phone: {
    path: "<path d=\"M703.591573 64.021106 255.859295 64.021106c-35.322483 0-63.956637 28.634154-63.956637 63.956637l0 767.535931c0 35.322483 28.634154 63.956637 63.956637 63.956637l447.732278 0c35.322483 0 63.956637-28.634154 63.956637-63.956637L767.54821 127.977743C767.54821 92.65526 738.914056 64.021106 703.591573 64.021106zM703.58748 863.787088c0 17.520025-14.202467 31.722492-31.722492 31.722492L287.585881 895.509581c-17.520025 0-31.722492-14.202467-31.722492-31.722492L255.863389 159.704328c0-17.520025 14.202467-31.722492 31.722492-31.722492l384.279107 0c17.520025 0 31.722492 14.202467 31.722492 31.722492L703.58748 863.787088zM575.667042 224.180805c0 17.520025-14.202467 31.722492-31.722492 31.722492L415.507342 255.903298c-17.520025 0-31.722492-14.202467-31.722492-31.722492l0-0.515746c0-17.520025 14.202467-31.722492 31.722492-31.722492l128.437208 0c17.520025 0 31.722492 14.202467 31.722492 31.722492L575.667042 224.180805zM479.725946 831.54885m-31.980365 0a31.252 31.252 0 1 0 63.960731 0 31.252 31.252 0 1 0-63.960731 0ZM255.863389 735.49826l447.724091 0 0 31.722492-447.724091 0 0-31.722492Z\" p-id=\"4078\"></path>"
  },
  // 邮箱
  email: {
    path: "<path d=\"M512.012041 630.535466l415.548448-346.226152c-2.25174-0.409407-4.274694-1.348636-6.610724-1.348636L103.074318 282.960677c-2.287865 0-4.32286 0.927187-6.5746 1.348636L512.012041 630.535466zM958.133584 320.144497c0-3.901411-1.071684-7.513829-2.25174-11.06604L661.313264 554.602446l295.014111 295.074318c0.758608-2.974224 1.806209-5.840075 1.806209-9.055127L958.133584 320.144497zM68.15428 309.042333c-1.143932 3.576294-2.287865 7.140546-2.287865 11.102164l0 520.465099c0 3.251176 1.119849 6.104986 1.854374 9.07921l295.110442-295.098401L68.15428 309.042333zM632.582502 578.492568l-108.697648 90.539229c-3.407714 2.901976-7.622201 4.298777-11.872813 4.298777-4.214487 0-8.453057-1.396802-11.896896-4.298777l-108.601317-90.491063L94.079398 875.963123c2.926058 0.770649 5.828034 1.842333 8.99492 1.842333l817.887488 0c3.227093 0 6.129069-1.059643 9.115334-1.842333L632.582502 578.492568z\" p-id=\"16508\"></path>"
  },
  // 找不到ICON的，先这样处理
  device: {
    path: "<path d=\"M128 256h768V170.666667H128c-46.933333 0-85.333333 38.4-85.333333 85.333333v512c0 46.933333 38.4 85.333333 85.333333 85.333333h170.666667v-85.333333H128V256z m426.666667 256h-170.666667v75.946667c-26.026667 23.466667-42.666667 56.96-42.666667 94.72s16.64 71.253333 42.666667 94.72V853.333333h170.666667v-75.946666c26.026667-23.466667 42.666667-56.96 42.666666-94.72s-16.64-71.253333-42.666666-94.72V512z m-85.333334 234.666667c-35.413333 0-64-28.586667-64-64s28.586667-64 64-64 64 28.586667 64 64-28.586667 64-64 64z m469.333334-405.333334H682.666667c-21.333333 0-42.666667 21.333333-42.666667 42.666667v426.666667c0 21.333333 21.333333 42.666667 42.666667 42.666666h256c21.333333 0 42.666667-21.333333 42.666666-42.666666V384c0-21.333333-21.333333-42.666667-42.666666-42.666667z m-42.666667 426.666667h-170.666667V426.666667h170.666667v341.333333z\" p-id=\"12672\"></path>"
  },
  company: {
    path: "<path d=\"M831.808 869.184V171.168l-97.856-65.312-356.704 159.2v123.2l-197.12 68.64v412.288H160v48.992h64.352V485.472l261.472-85.696v518.4h181.024v-53.056h-40.224V391.584l-94.912-57.152-106.24 36.992V293.6l257.472-114.304v738.848H864v-48.992h-32.192v0.032zM256.544 595.68l189.056-61.216v-81.632l-189.056 65.312v77.536z m0 106.144l189.056-40.832v-81.632l-189.056 48.992v73.472z m0 110.208l189.056-24.512v-81.632l-189.056 28.576v77.568z m0 106.112l189.056-4.096v-81.632l-189.056 8.192v77.536z\" p-id=\"818\"></path>"
  },
  none: {
    path: ""
  }
};

var registerInnerMarker = (function (customIcons) {
  var CUSTOM_ICONS = customIcons && customIcons.reduce(function (acc, curr) {
    return _objectSpread2({}, acc, _defineProperty({}, curr.name, {
      path: curr.path
    }));
  }, {});

  var icons = _objectSpread2({}, DEFAULT_MARKER, {}, CUSTOM_ICONS);

  Object.keys(icons).forEach(function (key) {
    // TODO deprecated hack function
    Shape.Marker.Symbols[key] = svg2marker(icons[key].path);
  });
});

var reset = function reset(shapes, shapeComponents) {
  shapes.forEach(function (shape, index) {
    if (!shapeComponents[index].noReset) shape.attr(_objectSpread2({}, shapeComponents[index].attrs));
  });
};

var compiler = function compiler(extendNodeShape) {
  var registerName = extendNodeShape.name,
      renderNodeShape = extendNodeShape.render;

  if (!renderNodeShape) {
    return;
  }
  /** 设置初始化shapeComponent，按照节点ID进行分类 */


  var initShapeComponentMap = {};
  var initStateMap = {}; // eslint-disable-line

  G6.registerNode(registerName, {
    // 自定义Shape
    // eslint-disable-next-line
    draw: function draw(inputCfg, group) {
      /** 得到用户返回的shapeComponents，然后拼装 */
      var _renderNodeShape = renderNodeShape(inputCfg),
          shapeComponents = _renderNodeShape.shapeComponents,
          RenderState = _renderNodeShape.state;
      /** 每次draw后的shape就是初始化shape，这个在节点update后，用于setstate的reset */


      initShapeComponentMap[inputCfg.data.id] = shapeComponents;
      initStateMap[inputCfg.data.id] = RenderState;
      var keyshapeIndex = 0;
      var g6Shapes = shapeComponents.map(function (component, index) {
        var _component$attrs;

        if (component.isKeyShape) keyshapeIndex = index;
        return group.addShape(component.type || component.shape, {
          attrs: _objectSpread2({}, component.attrs),
          draggable: true,
          name: (_component$attrs = component.attrs) === null || _component$attrs === void 0 ? void 0 : _component$attrs.id
        });
      });
      return g6Shapes[keyshapeIndex];
    },
    // 设置各种交互状态
    setState: function setState(name, value, node) {
      var id = node.get('model').data.id;
      var initShapeComponent = initShapeComponentMap[id];
      var initState = initStateMap[id];
      var shapes = node.getContainer().get('children'); // 顺序根据 draw 时确定
      // 如果为false，则重置到初始状态

      if (!value || !name) {
        reset(shapes, initShapeComponent);
        return;
      } // 如果为为selected状态，则不作高亮
      // if (node.hasState('selected') && name === 'highlight.light' && value) return;


      Object.keys(initState).forEach(function (key) {
        // state 的 key 和 behavior 里触发的 name 匹配
        if (name === key) {
          shapes.forEach(function (g6Shape) {
            var originAttrs = g6Shape.attr();
            var customAttrs = initState[key][originAttrs.id];

            if (customAttrs) {
              var animate = customAttrs.animate,
                  otherAttrs = _objectWithoutProperties(customAttrs, ["animate"]);

              g6Shape.attr(otherAttrs);

              if (animate) {
                var attrs = animate.attrs,
                    duration = animate.duration,
                    easing = animate.easing,
                    callback = animate.callback,
                    delay = animate.delay;
                g6Shape.animate(attrs, duration, easing, callback, delay);
              }
            }
          });
        }
      });
    }
  });
};

var id = "1522921";
var name = "graphin";
var font_family = "graphin";
var css_prefix_text = "icon-";
var description = "";
var glyphs = [
	{
		icon_id: "4765721",
		name: "check-circle",
		font_class: "check-circle",
		unicode: "e77d",
		unicode_decimal: 59261
	},
	{
		icon_id: "4765722",
		name: "CI",
		font_class: "CI",
		unicode: "e77e",
		unicode_decimal: 59262
	},
	{
		icon_id: "4765723",
		name: "Dollar",
		font_class: "Dollar",
		unicode: "e77f",
		unicode_decimal: 59263
	},
	{
		icon_id: "4765724",
		name: "compass",
		font_class: "compass",
		unicode: "e780",
		unicode_decimal: 59264
	},
	{
		icon_id: "4765725",
		name: "close-circle",
		font_class: "close-circle",
		unicode: "e781",
		unicode_decimal: 59265
	},
	{
		icon_id: "4765726",
		name: "frown",
		font_class: "frown",
		unicode: "e782",
		unicode_decimal: 59266
	},
	{
		icon_id: "4765727",
		name: "info-circle",
		font_class: "info-circle",
		unicode: "e783",
		unicode_decimal: 59267
	},
	{
		icon_id: "4765728",
		name: "left-circle",
		font_class: "left-circle",
		unicode: "e784",
		unicode_decimal: 59268
	},
	{
		icon_id: "4765729",
		name: "down-circle",
		font_class: "down-circle",
		unicode: "e785",
		unicode_decimal: 59269
	},
	{
		icon_id: "4765730",
		name: "EURO",
		font_class: "EURO",
		unicode: "e786",
		unicode_decimal: 59270
	},
	{
		icon_id: "4765731",
		name: "copyright",
		font_class: "copyright",
		unicode: "e787",
		unicode_decimal: 59271
	},
	{
		icon_id: "4765732",
		name: "minus-circle",
		font_class: "minus-circle",
		unicode: "e788",
		unicode_decimal: 59272
	},
	{
		icon_id: "4765733",
		name: "meh",
		font_class: "meh",
		unicode: "e789",
		unicode_decimal: 59273
	},
	{
		icon_id: "4765734",
		name: "plus-circle",
		font_class: "plus-circle",
		unicode: "e78a",
		unicode_decimal: 59274
	},
	{
		icon_id: "4765735",
		name: "play-circle",
		font_class: "play-circle",
		unicode: "e78b",
		unicode_decimal: 59275
	},
	{
		icon_id: "4765736",
		name: "question-circle",
		font_class: "question-circle",
		unicode: "e78c",
		unicode_decimal: 59276
	},
	{
		icon_id: "4765737",
		name: "Pound",
		font_class: "Pound",
		unicode: "e78d",
		unicode_decimal: 59277
	},
	{
		icon_id: "4765738",
		name: "right-circle",
		font_class: "right-circle",
		unicode: "e78e",
		unicode_decimal: 59278
	},
	{
		icon_id: "4765739",
		name: "smile",
		font_class: "smile",
		unicode: "e78f",
		unicode_decimal: 59279
	},
	{
		icon_id: "4765740",
		name: "trademark",
		font_class: "trademark",
		unicode: "e790",
		unicode_decimal: 59280
	},
	{
		icon_id: "4765741",
		name: "time-circle",
		font_class: "time-circle",
		unicode: "e791",
		unicode_decimal: 59281
	},
	{
		icon_id: "4765742",
		name: "time out",
		font_class: "timeout",
		unicode: "e792",
		unicode_decimal: 59282
	},
	{
		icon_id: "4765743",
		name: "earth",
		font_class: "earth",
		unicode: "e793",
		unicode_decimal: 59283
	},
	{
		icon_id: "4765744",
		name: "YUAN",
		font_class: "YUAN",
		unicode: "e794",
		unicode_decimal: 59284
	},
	{
		icon_id: "4765745",
		name: "up-circle",
		font_class: "up-circle",
		unicode: "e795",
		unicode_decimal: 59285
	},
	{
		icon_id: "4765746",
		name: "warning-circle",
		font_class: "warning-circle",
		unicode: "e796",
		unicode_decimal: 59286
	},
	{
		icon_id: "4765811",
		name: "sync",
		font_class: "sync",
		unicode: "e797",
		unicode_decimal: 59287
	},
	{
		icon_id: "4765812",
		name: "transaction",
		font_class: "transaction",
		unicode: "e798",
		unicode_decimal: 59288
	},
	{
		icon_id: "4765837",
		name: "undo",
		font_class: "undo",
		unicode: "e799",
		unicode_decimal: 59289
	},
	{
		icon_id: "4765838",
		name: "redo",
		font_class: "redo",
		unicode: "e79a",
		unicode_decimal: 59290
	},
	{
		icon_id: "4765852",
		name: "reload",
		font_class: "reload",
		unicode: "e79b",
		unicode_decimal: 59291
	},
	{
		icon_id: "4765853",
		name: "reload time",
		font_class: "reloadtime",
		unicode: "e79c",
		unicode_decimal: 59292
	},
	{
		icon_id: "4765866",
		name: "message",
		font_class: "message",
		unicode: "e79d",
		unicode_decimal: 59293
	},
	{
		icon_id: "4765881",
		name: "dashboard",
		font_class: "dashboard",
		unicode: "e79e",
		unicode_decimal: 59294
	},
	{
		icon_id: "4765886",
		name: "issues close",
		font_class: "issuesclose",
		unicode: "e79f",
		unicode_decimal: 59295
	},
	{
		icon_id: "4765887",
		name: "poweroff",
		font_class: "poweroff",
		unicode: "e7a0",
		unicode_decimal: 59296
	},
	{
		icon_id: "4765888",
		name: "logout",
		font_class: "logout",
		unicode: "e7a1",
		unicode_decimal: 59297
	},
	{
		icon_id: "4765890",
		name: "pie chart",
		font_class: "piechart",
		unicode: "e7a2",
		unicode_decimal: 59298
	},
	{
		icon_id: "4765891",
		name: "setting",
		font_class: "setting",
		unicode: "e7a3",
		unicode_decimal: 59299
	},
	{
		icon_id: "4765896",
		name: "eye",
		font_class: "eye",
		unicode: "e7a4",
		unicode_decimal: 59300
	},
	{
		icon_id: "4765897",
		name: "location",
		font_class: "location",
		unicode: "e7a5",
		unicode_decimal: 59301
	},
	{
		icon_id: "4765957",
		name: "edit-square",
		font_class: "edit-square",
		unicode: "e7a6",
		unicode_decimal: 59302
	},
	{
		icon_id: "4765958",
		name: "export",
		font_class: "export",
		unicode: "e7a7",
		unicode_decimal: 59303
	},
	{
		icon_id: "4765959",
		name: "save",
		font_class: "save",
		unicode: "e7a8",
		unicode_decimal: 59304
	},
	{
		icon_id: "4765960",
		name: "Import",
		font_class: "Import",
		unicode: "e7a9",
		unicode_decimal: 59305
	},
	{
		icon_id: "4765962",
		name: "app store",
		font_class: "appstore",
		unicode: "e7aa",
		unicode_decimal: 59306
	},
	{
		icon_id: "4765964",
		name: "close-square",
		font_class: "close-square",
		unicode: "e7ab",
		unicode_decimal: 59307
	},
	{
		icon_id: "4765965",
		name: "down-square",
		font_class: "down-square",
		unicode: "e7ac",
		unicode_decimal: 59308
	},
	{
		icon_id: "4765966",
		name: "layout",
		font_class: "layout",
		unicode: "e7ad",
		unicode_decimal: 59309
	},
	{
		icon_id: "4765967",
		name: "left-square",
		font_class: "left-square",
		unicode: "e7ae",
		unicode_decimal: 59310
	},
	{
		icon_id: "4765968",
		name: "play-square",
		font_class: "play-square",
		unicode: "e7af",
		unicode_decimal: 59311
	},
	{
		icon_id: "4765969",
		name: "control",
		font_class: "control",
		unicode: "e7b0",
		unicode_decimal: 59312
	},
	{
		icon_id: "4765970",
		name: "code library",
		font_class: "codelibrary",
		unicode: "e7b1",
		unicode_decimal: 59313
	},
	{
		icon_id: "4765971",
		name: "detail",
		font_class: "detail",
		unicode: "e7b2",
		unicode_decimal: 59314
	},
	{
		icon_id: "4765972",
		name: "minus-square",
		font_class: "minus-square",
		unicode: "e7b3",
		unicode_decimal: 59315
	},
	{
		icon_id: "4765973",
		name: "plus-square",
		font_class: "plus-square",
		unicode: "e7b4",
		unicode_decimal: 59316
	},
	{
		icon_id: "4765974",
		name: "right-square",
		font_class: "right-square",
		unicode: "e7b5",
		unicode_decimal: 59317
	},
	{
		icon_id: "4765975",
		name: "project",
		font_class: "project",
		unicode: "e7b6",
		unicode_decimal: 59318
	},
	{
		icon_id: "4765976",
		name: "wallet",
		font_class: "wallet",
		unicode: "e7b7",
		unicode_decimal: 59319
	},
	{
		icon_id: "4765977",
		name: "up-square",
		font_class: "up-square",
		unicode: "e7b8",
		unicode_decimal: 59320
	},
	{
		icon_id: "4765978",
		name: "calculator",
		font_class: "calculator",
		unicode: "e7b9",
		unicode_decimal: 59321
	},
	{
		icon_id: "4766245",
		name: "interation",
		font_class: "interation",
		unicode: "e7ba",
		unicode_decimal: 59322
	},
	{
		icon_id: "4766253",
		name: "check-square",
		font_class: "check-square",
		unicode: "e7bb",
		unicode_decimal: 59323
	},
	{
		icon_id: "4766265",
		name: "border",
		font_class: "border",
		unicode: "e7bc",
		unicode_decimal: 59324
	},
	{
		icon_id: "4766266",
		name: "border-outer",
		font_class: "border-outer",
		unicode: "e7bd",
		unicode_decimal: 59325
	},
	{
		icon_id: "4766268",
		name: "border-top",
		font_class: "border-top",
		unicode: "e7be",
		unicode_decimal: 59326
	},
	{
		icon_id: "4766269",
		name: "border-bottom",
		font_class: "border-bottom",
		unicode: "e7bf",
		unicode_decimal: 59327
	},
	{
		icon_id: "4766270",
		name: "border-left",
		font_class: "border-left",
		unicode: "e7c0",
		unicode_decimal: 59328
	},
	{
		icon_id: "4766271",
		name: "border-right",
		font_class: "border-right",
		unicode: "e7c1",
		unicode_decimal: 59329
	},
	{
		icon_id: "4766276",
		name: "border-inner",
		font_class: "border-inner",
		unicode: "e7c2",
		unicode_decimal: 59330
	},
	{
		icon_id: "4766277",
		name: "border-verticle",
		font_class: "border-verticle",
		unicode: "e7c3",
		unicode_decimal: 59331
	},
	{
		icon_id: "4766278",
		name: "border-horizontal",
		font_class: "border-horizontal",
		unicode: "e7c4",
		unicode_decimal: 59332
	},
	{
		icon_id: "4766282",
		name: "radius-bottomleft",
		font_class: "radius-bottomleft",
		unicode: "e7c5",
		unicode_decimal: 59333
	},
	{
		icon_id: "4766283",
		name: "radius-bottomright",
		font_class: "radius-bottomright",
		unicode: "e7c6",
		unicode_decimal: 59334
	},
	{
		icon_id: "4766284",
		name: "radius-upleft",
		font_class: "radius-upleft",
		unicode: "e7c7",
		unicode_decimal: 59335
	},
	{
		icon_id: "4766285",
		name: "radius-upright",
		font_class: "radius-upright",
		unicode: "e7c8",
		unicode_decimal: 59336
	},
	{
		icon_id: "4766286",
		name: "radius-setting",
		font_class: "radius-setting",
		unicode: "e7c9",
		unicode_decimal: 59337
	},
	{
		icon_id: "4766289",
		name: "add user",
		font_class: "adduser",
		unicode: "e7ca",
		unicode_decimal: 59338
	},
	{
		icon_id: "4766290",
		name: "delete team",
		font_class: "deleteteam",
		unicode: "e7cb",
		unicode_decimal: 59339
	},
	{
		icon_id: "4766291",
		name: "delete user",
		font_class: "deleteuser",
		unicode: "e7cc",
		unicode_decimal: 59340
	},
	{
		icon_id: "4766292",
		name: "addteam",
		font_class: "addteam",
		unicode: "e7cd",
		unicode_decimal: 59341
	},
	{
		icon_id: "4766293",
		name: "user",
		font_class: "user",
		unicode: "e7ce",
		unicode_decimal: 59342
	},
	{
		icon_id: "4766294",
		name: "team",
		font_class: "team",
		unicode: "e7cf",
		unicode_decimal: 59343
	},
	{
		icon_id: "4766297",
		name: "area chart",
		font_class: "areachart",
		unicode: "e7d0",
		unicode_decimal: 59344
	},
	{
		icon_id: "4766298",
		name: "line chart",
		font_class: "linechart",
		unicode: "e7d1",
		unicode_decimal: 59345
	},
	{
		icon_id: "4766299",
		name: "bar chart",
		font_class: "barchart",
		unicode: "e7d2",
		unicode_decimal: 59346
	},
	{
		icon_id: "4766300",
		name: "point map",
		font_class: "pointmap",
		unicode: "e7d3",
		unicode_decimal: 59347
	},
	{
		icon_id: "4766438",
		name: "container",
		font_class: "container",
		unicode: "e7d4",
		unicode_decimal: 59348
	},
	{
		icon_id: "4766439",
		name: "database",
		font_class: "database",
		unicode: "e7d5",
		unicode_decimal: 59349
	},
	{
		icon_id: "4766440",
		name: "sever",
		font_class: "sever",
		unicode: "e7d6",
		unicode_decimal: 59350
	},
	{
		icon_id: "4766451",
		name: "mobile",
		font_class: "mobile",
		unicode: "e7d7",
		unicode_decimal: 59351
	},
	{
		icon_id: "4766452",
		name: "tablet",
		font_class: "tablet",
		unicode: "e7d8",
		unicode_decimal: 59352
	},
	{
		icon_id: "4766453",
		name: "red envelope",
		font_class: "redenvelope",
		unicode: "e7d9",
		unicode_decimal: 59353
	},
	{
		icon_id: "4766454",
		name: "book",
		font_class: "book",
		unicode: "e7da",
		unicode_decimal: 59354
	},
	{
		icon_id: "4766459",
		name: "file done",
		font_class: "filedone",
		unicode: "e7db",
		unicode_decimal: 59355
	},
	{
		icon_id: "4766460",
		name: "reconciliation",
		font_class: "reconciliation",
		unicode: "e7dc",
		unicode_decimal: 59356
	},
	{
		icon_id: "4766461",
		name: "file -exception",
		font_class: "file-exception",
		unicode: "e7dd",
		unicode_decimal: 59357
	},
	{
		icon_id: "4766462",
		name: "file sync",
		font_class: "filesync",
		unicode: "e7de",
		unicode_decimal: 59358
	},
	{
		icon_id: "4766463",
		name: "file search",
		font_class: "filesearch",
		unicode: "e7df",
		unicode_decimal: 59359
	},
	{
		icon_id: "4766464",
		name: "solution",
		font_class: "solution",
		unicode: "e7e0",
		unicode_decimal: 59360
	},
	{
		icon_id: "4766465",
		name: "file protect",
		font_class: "fileprotect",
		unicode: "e7e1",
		unicode_decimal: 59361
	},
	{
		icon_id: "4766468",
		name: "file-add",
		font_class: "file-add",
		unicode: "e7e2",
		unicode_decimal: 59362
	},
	{
		icon_id: "4766469",
		name: "file-excel",
		font_class: "file-excel",
		unicode: "e7e3",
		unicode_decimal: 59363
	},
	{
		icon_id: "4766470",
		name: "file-exclamation",
		font_class: "file-exclamation",
		unicode: "e7e4",
		unicode_decimal: 59364
	},
	{
		icon_id: "4766472",
		name: "file-pdf",
		font_class: "file-pdf",
		unicode: "e7e5",
		unicode_decimal: 59365
	},
	{
		icon_id: "4766473",
		name: "file-image",
		font_class: "file-image",
		unicode: "e7e6",
		unicode_decimal: 59366
	},
	{
		icon_id: "4766474",
		name: "file-markdown",
		font_class: "file-markdown",
		unicode: "e7e7",
		unicode_decimal: 59367
	},
	{
		icon_id: "4766475",
		name: "file-unknown",
		font_class: "file-unknown",
		unicode: "e7e8",
		unicode_decimal: 59368
	},
	{
		icon_id: "4766476",
		name: "file-ppt",
		font_class: "file-ppt",
		unicode: "e7e9",
		unicode_decimal: 59369
	},
	{
		icon_id: "4766477",
		name: "file-word",
		font_class: "file-word",
		unicode: "e7ea",
		unicode_decimal: 59370
	},
	{
		icon_id: "4766478",
		name: "file",
		font_class: "file",
		unicode: "e7eb",
		unicode_decimal: 59371
	},
	{
		icon_id: "4766479",
		name: "file-zip",
		font_class: "file-zip",
		unicode: "e7ec",
		unicode_decimal: 59372
	},
	{
		icon_id: "4766480",
		name: "file-text",
		font_class: "file-text",
		unicode: "e7ed",
		unicode_decimal: 59373
	},
	{
		icon_id: "4766481",
		name: "file-copy",
		font_class: "file-copy",
		unicode: "e7ee",
		unicode_decimal: 59374
	},
	{
		icon_id: "4766482",
		name: "snippets",
		font_class: "snippets",
		unicode: "e7ef",
		unicode_decimal: 59375
	},
	{
		icon_id: "4766507",
		name: "audit",
		font_class: "audit",
		unicode: "e7f0",
		unicode_decimal: 59376
	},
	{
		icon_id: "4766508",
		name: "diff",
		font_class: "diff",
		unicode: "e7f1",
		unicode_decimal: 59377
	},
	{
		icon_id: "4766509",
		name: "Batch folding",
		font_class: "Batchfolding",
		unicode: "e7f2",
		unicode_decimal: 59378
	},
	{
		icon_id: "4766511",
		name: "security scan",
		font_class: "securityscan",
		unicode: "e7f3",
		unicode_decimal: 59379
	},
	{
		icon_id: "4766512",
		name: "property safety",
		font_class: "propertysafety",
		unicode: "e7f4",
		unicode_decimal: 59380
	},
	{
		icon_id: "4766513",
		name: "safety certificate",
		font_class: "safetycertificate",
		unicode: "e7f5",
		unicode_decimal: 59381
	},
	{
		icon_id: "4766514",
		name: "insurance ",
		font_class: "insurance",
		unicode: "e7f6",
		unicode_decimal: 59382
	},
	{
		icon_id: "4766675",
		name: "alert",
		font_class: "alert",
		unicode: "e7f7",
		unicode_decimal: 59383
	},
	{
		icon_id: "4766676",
		name: "delete",
		font_class: "delete",
		unicode: "e7f8",
		unicode_decimal: 59384
	},
	{
		icon_id: "4766677",
		name: "hourglass",
		font_class: "hourglass",
		unicode: "e7f9",
		unicode_decimal: 59385
	},
	{
		icon_id: "4766678",
		name: "bulb",
		font_class: "bulb",
		unicode: "e7fa",
		unicode_decimal: 59386
	},
	{
		icon_id: "4766679",
		name: "experiment",
		font_class: "experiment",
		unicode: "e7fb",
		unicode_decimal: 59387
	},
	{
		icon_id: "4766680",
		name: "bell",
		font_class: "bell",
		unicode: "e7fc",
		unicode_decimal: 59388
	},
	{
		icon_id: "4766681",
		name: "trophy",
		font_class: "trophy",
		unicode: "e7fd",
		unicode_decimal: 59389
	},
	{
		icon_id: "4766682",
		name: "rest",
		font_class: "rest",
		unicode: "e7fe",
		unicode_decimal: 59390
	},
	{
		icon_id: "4766683",
		name: "USB",
		font_class: "USB",
		unicode: "e7ff",
		unicode_decimal: 59391
	},
	{
		icon_id: "4766684",
		name: "skin",
		font_class: "skin",
		unicode: "e800",
		unicode_decimal: 59392
	},
	{
		icon_id: "4766685",
		name: "home",
		font_class: "home",
		unicode: "e801",
		unicode_decimal: 59393
	},
	{
		icon_id: "4766686",
		name: "bank",
		font_class: "bank",
		unicode: "e802",
		unicode_decimal: 59394
	},
	{
		icon_id: "4766688",
		name: "filter",
		font_class: "filter",
		unicode: "e803",
		unicode_decimal: 59395
	},
	{
		icon_id: "4766689",
		name: "funnel plot",
		font_class: "funnelplot",
		unicode: "e804",
		unicode_decimal: 59396
	},
	{
		icon_id: "4766692",
		name: "like",
		font_class: "like",
		unicode: "e805",
		unicode_decimal: 59397
	},
	{
		icon_id: "4766693",
		name: "unlike",
		font_class: "unlike",
		unicode: "e806",
		unicode_decimal: 59398
	},
	{
		icon_id: "4766694",
		name: "unlock",
		font_class: "unlock",
		unicode: "e807",
		unicode_decimal: 59399
	},
	{
		icon_id: "4766695",
		name: "lock",
		font_class: "lock",
		unicode: "e808",
		unicode_decimal: 59400
	},
	{
		icon_id: "4766762",
		name: "customerservice",
		font_class: "customerservice",
		unicode: "e809",
		unicode_decimal: 59401
	},
	{
		icon_id: "4766767",
		name: "flag",
		font_class: "flag",
		unicode: "e80a",
		unicode_decimal: 59402
	},
	{
		icon_id: "4766773",
		name: "money collect",
		font_class: "moneycollect",
		unicode: "e80b",
		unicode_decimal: 59403
	},
	{
		icon_id: "4766774",
		name: "medicinebox",
		font_class: "medicinebox",
		unicode: "e80c",
		unicode_decimal: 59404
	},
	{
		icon_id: "4766775",
		name: "shop",
		font_class: "shop",
		unicode: "e80d",
		unicode_decimal: 59405
	},
	{
		icon_id: "4766778",
		name: "rocket",
		font_class: "rocket",
		unicode: "e80e",
		unicode_decimal: 59406
	},
	{
		icon_id: "4766779",
		name: "shopping",
		font_class: "shopping",
		unicode: "e80f",
		unicode_decimal: 59407
	},
	{
		icon_id: "4766846",
		name: "folder",
		font_class: "folder",
		unicode: "e810",
		unicode_decimal: 59408
	},
	{
		icon_id: "4766847",
		name: "folder-open",
		font_class: "folder-open",
		unicode: "e811",
		unicode_decimal: 59409
	},
	{
		icon_id: "4766848",
		name: "folder-add",
		font_class: "folder-add",
		unicode: "e812",
		unicode_decimal: 59410
	},
	{
		icon_id: "4766849",
		name: "deployment unit",
		font_class: "deploymentunit",
		unicode: "e813",
		unicode_decimal: 59411
	},
	{
		icon_id: "4766854",
		name: "account book",
		font_class: "accountbook",
		unicode: "e814",
		unicode_decimal: 59412
	},
	{
		icon_id: "4766855",
		name: "contacts",
		font_class: "contacts",
		unicode: "e815",
		unicode_decimal: 59413
	},
	{
		icon_id: "4766856",
		name: "carry out",
		font_class: "carryout",
		unicode: "e816",
		unicode_decimal: 59414
	},
	{
		icon_id: "4766857",
		name: "calendar-check",
		font_class: "calendar-check",
		unicode: "e817",
		unicode_decimal: 59415
	},
	{
		icon_id: "4766858",
		name: "calendar",
		font_class: "calendar",
		unicode: "e818",
		unicode_decimal: 59416
	},
	{
		icon_id: "4766861",
		name: "scan",
		font_class: "scan",
		unicode: "e819",
		unicode_decimal: 59417
	},
	{
		icon_id: "4766862",
		name: "select",
		font_class: "select",
		unicode: "e81a",
		unicode_decimal: 59418
	},
	{
		icon_id: "4766871",
		name: "box plot",
		font_class: "boxplot",
		unicode: "e81b",
		unicode_decimal: 59419
	},
	{
		icon_id: "4766872",
		name: "build",
		font_class: "build",
		unicode: "e81c",
		unicode_decimal: 59420
	},
	{
		icon_id: "4766874",
		name: "sliders",
		font_class: "sliders",
		unicode: "e81d",
		unicode_decimal: 59421
	},
	{
		icon_id: "4766881",
		name: "laptop",
		font_class: "laptop",
		unicode: "e81e",
		unicode_decimal: 59422
	},
	{
		icon_id: "4766882",
		name: "barcode",
		font_class: "barcode",
		unicode: "e81f",
		unicode_decimal: 59423
	},
	{
		icon_id: "4766883",
		name: "camera",
		font_class: "camera",
		unicode: "e820",
		unicode_decimal: 59424
	},
	{
		icon_id: "4766884",
		name: "cluster",
		font_class: "cluster",
		unicode: "e821",
		unicode_decimal: 59425
	},
	{
		icon_id: "4766885",
		name: "gateway",
		font_class: "gateway",
		unicode: "e822",
		unicode_decimal: 59426
	},
	{
		icon_id: "4766886",
		name: "car",
		font_class: "car",
		unicode: "e823",
		unicode_decimal: 59427
	},
	{
		icon_id: "4766887",
		name: "printer",
		font_class: "printer",
		unicode: "e824",
		unicode_decimal: 59428
	},
	{
		icon_id: "4766888",
		name: "read",
		font_class: "read",
		unicode: "e825",
		unicode_decimal: 59429
	},
	{
		icon_id: "4766900",
		name: "cloud-server",
		font_class: "cloud-server",
		unicode: "e826",
		unicode_decimal: 59430
	},
	{
		icon_id: "4766901",
		name: "cloud-upload",
		font_class: "cloud-upload",
		unicode: "e827",
		unicode_decimal: 59431
	},
	{
		icon_id: "4766902",
		name: "cloud",
		font_class: "cloud",
		unicode: "e828",
		unicode_decimal: 59432
	},
	{
		icon_id: "4766903",
		name: "cloud-download",
		font_class: "cloud-download",
		unicode: "e829",
		unicode_decimal: 59433
	},
	{
		icon_id: "4766904",
		name: "cloud-sync",
		font_class: "cloud-sync",
		unicode: "e82a",
		unicode_decimal: 59434
	},
	{
		icon_id: "4766905",
		name: "video",
		font_class: "video",
		unicode: "e82b",
		unicode_decimal: 59435
	},
	{
		icon_id: "4766906",
		name: "notification",
		font_class: "notification",
		unicode: "e82c",
		unicode_decimal: 59436
	},
	{
		icon_id: "4766907",
		name: "sound",
		font_class: "sound",
		unicode: "e82d",
		unicode_decimal: 59437
	},
	{
		icon_id: "4766911",
		name: "radar chart",
		font_class: "radarchart",
		unicode: "e82e",
		unicode_decimal: 59438
	},
	{
		icon_id: "4766912",
		name: "qrcode",
		font_class: "qrcode",
		unicode: "e82f",
		unicode_decimal: 59439
	},
	{
		icon_id: "4766916",
		name: "fund",
		font_class: "fund",
		unicode: "e830",
		unicode_decimal: 59440
	},
	{
		icon_id: "4766917",
		name: "image",
		font_class: "image",
		unicode: "e831",
		unicode_decimal: 59441
	},
	{
		icon_id: "4766918",
		name: "mail",
		font_class: "mail",
		unicode: "e832",
		unicode_decimal: 59442
	},
	{
		icon_id: "4766919",
		name: "table",
		font_class: "table",
		unicode: "e833",
		unicode_decimal: 59443
	},
	{
		icon_id: "4766920",
		name: "id card",
		font_class: "idcard",
		unicode: "e834",
		unicode_decimal: 59444
	},
	{
		icon_id: "4766921",
		name: "credit card",
		font_class: "creditcard",
		unicode: "e835",
		unicode_decimal: 59445
	},
	{
		icon_id: "4766951",
		name: "heart",
		font_class: "heart",
		unicode: "e836",
		unicode_decimal: 59446
	},
	{
		icon_id: "4766952",
		name: "block",
		font_class: "block",
		unicode: "e837",
		unicode_decimal: 59447
	},
	{
		icon_id: "4766953",
		name: "error",
		font_class: "error",
		unicode: "e838",
		unicode_decimal: 59448
	},
	{
		icon_id: "4766954",
		name: "star",
		font_class: "star",
		unicode: "e839",
		unicode_decimal: 59449
	},
	{
		icon_id: "4766955",
		name: "gold",
		font_class: "gold",
		unicode: "e83a",
		unicode_decimal: 59450
	},
	{
		icon_id: "4766956",
		name: "heat map",
		font_class: "heatmap",
		unicode: "e83b",
		unicode_decimal: 59451
	},
	{
		icon_id: "4766957",
		name: "wifi",
		font_class: "wifi",
		unicode: "e83c",
		unicode_decimal: 59452
	},
	{
		icon_id: "4766958",
		name: "attachment",
		font_class: "attachment",
		unicode: "e83d",
		unicode_decimal: 59453
	},
	{
		icon_id: "4766959",
		name: "edit",
		font_class: "edit",
		unicode: "e83e",
		unicode_decimal: 59454
	},
	{
		icon_id: "4766960",
		name: "key",
		font_class: "key",
		unicode: "e83f",
		unicode_decimal: 59455
	},
	{
		icon_id: "4766961",
		name: "api",
		font_class: "api",
		unicode: "e840",
		unicode_decimal: 59456
	},
	{
		icon_id: "4766962",
		name: "disconnect",
		font_class: "disconnect",
		unicode: "e841",
		unicode_decimal: 59457
	},
	{
		icon_id: "4766963",
		name: "highlight",
		font_class: "highlight",
		unicode: "e842",
		unicode_decimal: 59458
	},
	{
		icon_id: "4766964",
		name: "monitor",
		font_class: "monitor",
		unicode: "e843",
		unicode_decimal: 59459
	},
	{
		icon_id: "4766965",
		name: "link",
		font_class: "link",
		unicode: "e844",
		unicode_decimal: 59460
	},
	{
		icon_id: "4766966",
		name: "man",
		font_class: "man",
		unicode: "e845",
		unicode_decimal: 59461
	},
	{
		icon_id: "4766967",
		name: "percentage",
		font_class: "percentage",
		unicode: "e846",
		unicode_decimal: 59462
	},
	{
		icon_id: "4766969",
		name: "pushpin",
		font_class: "pushpin",
		unicode: "e847",
		unicode_decimal: 59463
	},
	{
		icon_id: "4766970",
		name: "phone",
		font_class: "phone",
		unicode: "e848",
		unicode_decimal: 59464
	},
	{
		icon_id: "4766971",
		name: "shake",
		font_class: "shake",
		unicode: "e849",
		unicode_decimal: 59465
	},
	{
		icon_id: "4766972",
		name: "tag",
		font_class: "tag",
		unicode: "e84a",
		unicode_decimal: 59466
	},
	{
		icon_id: "4766973",
		name: "wrench",
		font_class: "wrench",
		unicode: "e84b",
		unicode_decimal: 59467
	},
	{
		icon_id: "4766975",
		name: "tags",
		font_class: "tags",
		unicode: "e84c",
		unicode_decimal: 59468
	},
	{
		icon_id: "4766982",
		name: "scissor",
		font_class: "scissor",
		unicode: "e84d",
		unicode_decimal: 59469
	},
	{
		icon_id: "4766984",
		name: "mr",
		font_class: "mr",
		unicode: "e84e",
		unicode_decimal: 59470
	},
	{
		icon_id: "4766985",
		name: "share",
		font_class: "share",
		unicode: "e84f",
		unicode_decimal: 59471
	},
	{
		icon_id: "4766986",
		name: "branches",
		font_class: "branches",
		unicode: "e850",
		unicode_decimal: 59472
	},
	{
		icon_id: "4766995",
		name: "fork",
		font_class: "fork",
		unicode: "e851",
		unicode_decimal: 59473
	},
	{
		icon_id: "4767006",
		name: "shrink",
		font_class: "shrink",
		unicode: "e852",
		unicode_decimal: 59474
	},
	{
		icon_id: "4767007",
		name: "arrawsalt",
		font_class: "arrawsalt",
		unicode: "e853",
		unicode_decimal: 59475
	},
	{
		icon_id: "4767009",
		name: "vertical right",
		font_class: "verticalright",
		unicode: "e854",
		unicode_decimal: 59476
	},
	{
		icon_id: "4767010",
		name: "vertical left",
		font_class: "verticalleft",
		unicode: "e855",
		unicode_decimal: 59477
	},
	{
		icon_id: "4767011",
		name: "right",
		font_class: "right",
		unicode: "e856",
		unicode_decimal: 59478
	},
	{
		icon_id: "4767012",
		name: "left",
		font_class: "left",
		unicode: "e857",
		unicode_decimal: 59479
	},
	{
		icon_id: "4767013",
		name: "up",
		font_class: "up",
		unicode: "e858",
		unicode_decimal: 59480
	},
	{
		icon_id: "4767014",
		name: "down",
		font_class: "down",
		unicode: "e859",
		unicode_decimal: 59481
	},
	{
		icon_id: "4767015",
		name: "fullscreen",
		font_class: "fullscreen",
		unicode: "e85a",
		unicode_decimal: 59482
	},
	{
		icon_id: "4767016",
		name: "fullscreen-exit",
		font_class: "fullscreen-exit",
		unicode: "e85b",
		unicode_decimal: 59483
	},
	{
		icon_id: "4767018",
		name: "doubleleft",
		font_class: "doubleleft",
		unicode: "e85c",
		unicode_decimal: 59484
	},
	{
		icon_id: "4767019",
		name: "double right",
		font_class: "doubleright",
		unicode: "e85d",
		unicode_decimal: 59485
	},
	{
		icon_id: "4767020",
		name: "arrowright",
		font_class: "arrowright",
		unicode: "e85e",
		unicode_decimal: 59486
	},
	{
		icon_id: "4767021",
		name: "arrowup",
		font_class: "arrowup",
		unicode: "e85f",
		unicode_decimal: 59487
	},
	{
		icon_id: "4767022",
		name: "arrowleft",
		font_class: "arrowleft",
		unicode: "e860",
		unicode_decimal: 59488
	},
	{
		icon_id: "4767023",
		name: "arrowdown",
		font_class: "arrowdown",
		unicode: "e861",
		unicode_decimal: 59489
	},
	{
		icon_id: "4767025",
		name: "upload",
		font_class: "upload",
		unicode: "e862",
		unicode_decimal: 59490
	},
	{
		icon_id: "4767026",
		name: "colum-height",
		font_class: "colum-height",
		unicode: "e863",
		unicode_decimal: 59491
	},
	{
		icon_id: "4767027",
		name: "vertical-align-botto",
		font_class: "vertical-align-botto",
		unicode: "e864",
		unicode_decimal: 59492
	},
	{
		icon_id: "4767028",
		name: "vertical-align-middl",
		font_class: "vertical-align-middl",
		unicode: "e865",
		unicode_decimal: 59493
	},
	{
		icon_id: "4767029",
		name: "totop",
		font_class: "totop",
		unicode: "e866",
		unicode_decimal: 59494
	},
	{
		icon_id: "4767030",
		name: "vertical-align-top",
		font_class: "vertical-align-top",
		unicode: "e867",
		unicode_decimal: 59495
	},
	{
		icon_id: "4767031",
		name: "download",
		font_class: "download",
		unicode: "e868",
		unicode_decimal: 59496
	},
	{
		icon_id: "4767038",
		name: "sort-descending",
		font_class: "sort-descending",
		unicode: "e869",
		unicode_decimal: 59497
	},
	{
		icon_id: "4767039",
		name: "sort-ascending",
		font_class: "sort-ascending",
		unicode: "e86a",
		unicode_decimal: 59498
	},
	{
		icon_id: "4767043",
		name: "fall",
		font_class: "fall",
		unicode: "e86b",
		unicode_decimal: 59499
	},
	{
		icon_id: "4767044",
		name: "swap",
		font_class: "swap",
		unicode: "e86c",
		unicode_decimal: 59500
	},
	{
		icon_id: "4767045",
		name: "stock",
		font_class: "stock",
		unicode: "e86d",
		unicode_decimal: 59501
	},
	{
		icon_id: "4767046",
		name: "rise",
		font_class: "rise",
		unicode: "e86e",
		unicode_decimal: 59502
	},
	{
		icon_id: "4767050",
		name: "indent",
		font_class: "indent",
		unicode: "e86f",
		unicode_decimal: 59503
	},
	{
		icon_id: "4767051",
		name: "outdent",
		font_class: "outdent",
		unicode: "e870",
		unicode_decimal: 59504
	},
	{
		icon_id: "4767059",
		name: "menu",
		font_class: "menu",
		unicode: "e871",
		unicode_decimal: 59505
	},
	{
		icon_id: "4767060",
		name: "unordered list",
		font_class: "unorderedlist",
		unicode: "e872",
		unicode_decimal: 59506
	},
	{
		icon_id: "4767061",
		name: "ordered list",
		font_class: "orderedlist",
		unicode: "e873",
		unicode_decimal: 59507
	},
	{
		icon_id: "4767062",
		name: "align-right",
		font_class: "align-right",
		unicode: "e874",
		unicode_decimal: 59508
	},
	{
		icon_id: "4767063",
		name: "align-center",
		font_class: "align-center",
		unicode: "e875",
		unicode_decimal: 59509
	},
	{
		icon_id: "4767064",
		name: "align-left",
		font_class: "align-left",
		unicode: "e876",
		unicode_decimal: 59510
	},
	{
		icon_id: "4767072",
		name: "pic-center",
		font_class: "pic-center",
		unicode: "e877",
		unicode_decimal: 59511
	},
	{
		icon_id: "4767073",
		name: "pic-right",
		font_class: "pic-right",
		unicode: "e878",
		unicode_decimal: 59512
	},
	{
		icon_id: "4767074",
		name: "pic-left",
		font_class: "pic-left",
		unicode: "e879",
		unicode_decimal: 59513
	},
	{
		icon_id: "4767078",
		name: "bold",
		font_class: "bold",
		unicode: "e87a",
		unicode_decimal: 59514
	},
	{
		icon_id: "4767079",
		name: "font-colors",
		font_class: "font-colors",
		unicode: "e87b",
		unicode_decimal: 59515
	},
	{
		icon_id: "4767080",
		name: "exclaimination",
		font_class: "exclaimination",
		unicode: "e87c",
		unicode_decimal: 59516
	},
	{
		icon_id: "4767081",
		name: "font-size",
		font_class: "font-size",
		unicode: "e87d",
		unicode_decimal: 59517
	},
	{
		icon_id: "4767082",
		name: "infomation",
		font_class: "infomation",
		unicode: "e87e",
		unicode_decimal: 59518
	},
	{
		icon_id: "4767083",
		name: "line-height",
		font_class: "line-height",
		unicode: "e87f",
		unicode_decimal: 59519
	},
	{
		icon_id: "4767084",
		name: "strikethrough",
		font_class: "strikethrough",
		unicode: "e880",
		unicode_decimal: 59520
	},
	{
		icon_id: "4767085",
		name: "underline",
		font_class: "underline",
		unicode: "e881",
		unicode_decimal: 59521
	},
	{
		icon_id: "4767086",
		name: "number",
		font_class: "number",
		unicode: "e882",
		unicode_decimal: 59522
	},
	{
		icon_id: "4767087",
		name: "italic",
		font_class: "italic",
		unicode: "e883",
		unicode_decimal: 59523
	},
	{
		icon_id: "4767091",
		name: "code",
		font_class: "code",
		unicode: "e884",
		unicode_decimal: 59524
	},
	{
		icon_id: "4767092",
		name: "column-width",
		font_class: "column-width",
		unicode: "e885",
		unicode_decimal: 59525
	},
	{
		icon_id: "4767093",
		name: "check",
		font_class: "check",
		unicode: "e886",
		unicode_decimal: 59526
	},
	{
		icon_id: "4767094",
		name: "ellipsis",
		font_class: "ellipsis",
		unicode: "e887",
		unicode_decimal: 59527
	},
	{
		icon_id: "4767095",
		name: "dash",
		font_class: "dash",
		unicode: "e888",
		unicode_decimal: 59528
	},
	{
		icon_id: "4767096",
		name: "close",
		font_class: "close",
		unicode: "e889",
		unicode_decimal: 59529
	},
	{
		icon_id: "4767097",
		name: "enter",
		font_class: "enter",
		unicode: "e88a",
		unicode_decimal: 59530
	},
	{
		icon_id: "4767098",
		name: "line",
		font_class: "line",
		unicode: "e88b",
		unicode_decimal: 59531
	},
	{
		icon_id: "4767099",
		name: "minus",
		font_class: "minus",
		unicode: "e88c",
		unicode_decimal: 59532
	},
	{
		icon_id: "4767100",
		name: "question",
		font_class: "question",
		unicode: "e88d",
		unicode_decimal: 59533
	},
	{
		icon_id: "4767102",
		name: "rollback",
		font_class: "rollback",
		unicode: "e88e",
		unicode_decimal: 59534
	},
	{
		icon_id: "4767103",
		name: "small-dash",
		font_class: "small-dash",
		unicode: "e88f",
		unicode_decimal: 59535
	},
	{
		icon_id: "4767104",
		name: "pause",
		font_class: "pause",
		unicode: "e890",
		unicode_decimal: 59536
	},
	{
		icon_id: "4767106",
		name: "bg-colors",
		font_class: "bg-colors",
		unicode: "e891",
		unicode_decimal: 59537
	},
	{
		icon_id: "4936455",
		name: "crown",
		font_class: "crown",
		unicode: "e892",
		unicode_decimal: 59538
	},
	{
		icon_id: "4936456",
		name: "drag",
		font_class: "drag",
		unicode: "e893",
		unicode_decimal: 59539
	},
	{
		icon_id: "4936457",
		name: "desktop",
		font_class: "desktop",
		unicode: "e894",
		unicode_decimal: 59540
	},
	{
		icon_id: "4936458",
		name: "gift",
		font_class: "gift",
		unicode: "e895",
		unicode_decimal: 59541
	},
	{
		icon_id: "4936459",
		name: "stop",
		font_class: "stop",
		unicode: "e896",
		unicode_decimal: 59542
	},
	{
		icon_id: "4936460",
		name: "fire",
		font_class: "fire",
		unicode: "e897",
		unicode_decimal: 59543
	},
	{
		icon_id: "4936461",
		name: "thunderbolt",
		font_class: "thunderbolt",
		unicode: "e898",
		unicode_decimal: 59544
	},
	{
		icon_id: "4936478",
		name: "check-circle-fill",
		font_class: "check-circle-fill",
		unicode: "e899",
		unicode_decimal: 59545
	},
	{
		icon_id: "4936479",
		name: "left-circle-fill",
		font_class: "left-circle-fill",
		unicode: "e89a",
		unicode_decimal: 59546
	},
	{
		icon_id: "4936480",
		name: "down-circle-fill",
		font_class: "down-circle-fill",
		unicode: "e89b",
		unicode_decimal: 59547
	},
	{
		icon_id: "4936481",
		name: "minus-circle-fill",
		font_class: "minus-circle-fill",
		unicode: "e89c",
		unicode_decimal: 59548
	},
	{
		icon_id: "4936482",
		name: "close-circle-fill",
		font_class: "close-circle-fill",
		unicode: "e89d",
		unicode_decimal: 59549
	},
	{
		icon_id: "4936483",
		name: "info-circle-fill",
		font_class: "info-circle-fill",
		unicode: "e89e",
		unicode_decimal: 59550
	},
	{
		icon_id: "4936484",
		name: "up-circle-fill",
		font_class: "up-circle-fill",
		unicode: "e89f",
		unicode_decimal: 59551
	},
	{
		icon_id: "4936485",
		name: "right-circle-fill",
		font_class: "right-circle-fill",
		unicode: "e8a0",
		unicode_decimal: 59552
	},
	{
		icon_id: "4936486",
		name: "plus-circle-fill",
		font_class: "plus-circle-fill",
		unicode: "e8a1",
		unicode_decimal: 59553
	},
	{
		icon_id: "4936487",
		name: "question-circle-fill",
		font_class: "question-circle-fill",
		unicode: "e8a2",
		unicode_decimal: 59554
	},
	{
		icon_id: "4936499",
		name: "EURO-circle-fill",
		font_class: "EURO-circle-fill",
		unicode: "e8a3",
		unicode_decimal: 59555
	},
	{
		icon_id: "4936500",
		name: "frown-fill",
		font_class: "frown-fill",
		unicode: "e8a4",
		unicode_decimal: 59556
	},
	{
		icon_id: "4936501",
		name: "copyright-circle-fil",
		font_class: "copyright-circle-fil",
		unicode: "e8a5",
		unicode_decimal: 59557
	},
	{
		icon_id: "4936502",
		name: "CI-circle-fill",
		font_class: "CI-circle-fill",
		unicode: "e8a6",
		unicode_decimal: 59558
	},
	{
		icon_id: "4936503",
		name: "compass-fill",
		font_class: "compass-fill",
		unicode: "e8a7",
		unicode_decimal: 59559
	},
	{
		icon_id: "4936504",
		name: "Dollar-circle-fill",
		font_class: "Dollar-circle-fill",
		unicode: "e8a8",
		unicode_decimal: 59560
	},
	{
		icon_id: "4936505",
		name: "poweroff-circle-fill",
		font_class: "poweroff-circle-fill",
		unicode: "e8a9",
		unicode_decimal: 59561
	},
	{
		icon_id: "4936506",
		name: "meh-fill",
		font_class: "meh-fill",
		unicode: "e8aa",
		unicode_decimal: 59562
	},
	{
		icon_id: "4936507",
		name: "play-circle-fill",
		font_class: "play-circle-fill",
		unicode: "e8ab",
		unicode_decimal: 59563
	},
	{
		icon_id: "4936508",
		name: "Pound-circle-fill",
		font_class: "Pound-circle-fill",
		unicode: "e8ac",
		unicode_decimal: 59564
	},
	{
		icon_id: "4936509",
		name: "smile-fill",
		font_class: "smile-fill",
		unicode: "e8ad",
		unicode_decimal: 59565
	},
	{
		icon_id: "4936510",
		name: "stop-fill",
		font_class: "stop-fill",
		unicode: "e8ae",
		unicode_decimal: 59566
	},
	{
		icon_id: "4936511",
		name: "warning-circle-fill",
		font_class: "warning-circle-fill",
		unicode: "e8af",
		unicode_decimal: 59567
	},
	{
		icon_id: "4936512",
		name: "time-circle-fill",
		font_class: "time-circle-fill",
		unicode: "e8b0",
		unicode_decimal: 59568
	},
	{
		icon_id: "4936513",
		name: "trademark-circle-fil",
		font_class: "trademark-circle-fil",
		unicode: "e8b1",
		unicode_decimal: 59569
	},
	{
		icon_id: "4936514",
		name: "YUAN-circle-fill",
		font_class: "YUAN-circle-fill",
		unicode: "e8b2",
		unicode_decimal: 59570
	},
	{
		icon_id: "4936519",
		name: "heart-fill",
		font_class: "heart-fill",
		unicode: "e8b3",
		unicode_decimal: 59571
	},
	{
		icon_id: "4936520",
		name: "pie chart-circle-fil",
		font_class: "piechart-circle-fil",
		unicode: "e8b4",
		unicode_decimal: 59572
	},
	{
		icon_id: "4936521",
		name: "dashboard-fill",
		font_class: "dashboard-fill",
		unicode: "e8b5",
		unicode_decimal: 59573
	},
	{
		icon_id: "4936522",
		name: "message-fill",
		font_class: "message-fill",
		unicode: "e8b6",
		unicode_decimal: 59574
	},
	{
		icon_id: "4936529",
		name: "check-square-fill",
		font_class: "check-square-fill",
		unicode: "e8b7",
		unicode_decimal: 59575
	},
	{
		icon_id: "4936530",
		name: "down-square-fill",
		font_class: "down-square-fill",
		unicode: "e8b8",
		unicode_decimal: 59576
	},
	{
		icon_id: "4936531",
		name: "minus-square-fill",
		font_class: "minus-square-fill",
		unicode: "e8b9",
		unicode_decimal: 59577
	},
	{
		icon_id: "4936532",
		name: "close-square-fill",
		font_class: "close-square-fill",
		unicode: "e8ba",
		unicode_decimal: 59578
	},
	{
		icon_id: "4936533",
		name: "code library-fill",
		font_class: "codelibrary-fill",
		unicode: "e8bb",
		unicode_decimal: 59579
	},
	{
		icon_id: "4936534",
		name: "left-square-fill",
		font_class: "left-square-fill",
		unicode: "e8bc",
		unicode_decimal: 59580
	},
	{
		icon_id: "4936535",
		name: "play-square-fill",
		font_class: "play-square-fill",
		unicode: "e8bd",
		unicode_decimal: 59581
	},
	{
		icon_id: "4936536",
		name: "up-square-fill",
		font_class: "up-square-fill",
		unicode: "e8be",
		unicode_decimal: 59582
	},
	{
		icon_id: "4936537",
		name: "right-square-fill",
		font_class: "right-square-fill",
		unicode: "e8bf",
		unicode_decimal: 59583
	},
	{
		icon_id: "4936538",
		name: "plus-square-fill",
		font_class: "plus-square-fill",
		unicode: "e8c0",
		unicode_decimal: 59584
	},
	{
		icon_id: "4936542",
		name: "account book-fill",
		font_class: "accountbook-fill",
		unicode: "e8c1",
		unicode_decimal: 59585
	},
	{
		icon_id: "4936543",
		name: "carry out-fill",
		font_class: "carryout-fill",
		unicode: "e8c2",
		unicode_decimal: 59586
	},
	{
		icon_id: "4936544",
		name: "calendar-fill",
		font_class: "calendar-fill",
		unicode: "e8c3",
		unicode_decimal: 59587
	},
	{
		icon_id: "4936545",
		name: "calculator-fill",
		font_class: "calculator-fill",
		unicode: "e8c4",
		unicode_decimal: 59588
	},
	{
		icon_id: "4936546",
		name: "interation-fill",
		font_class: "interation-fill",
		unicode: "e8c5",
		unicode_decimal: 59589
	},
	{
		icon_id: "4936550",
		name: "project-fill",
		font_class: "project-fill",
		unicode: "e8c6",
		unicode_decimal: 59590
	},
	{
		icon_id: "4936571",
		name: "detail-fill",
		font_class: "detail-fill",
		unicode: "e8c7",
		unicode_decimal: 59591
	},
	{
		icon_id: "4936575",
		name: "save-fill",
		font_class: "save-fill",
		unicode: "e8c8",
		unicode_decimal: 59592
	},
	{
		icon_id: "4936576",
		name: "wallet-fill",
		font_class: "wallet-fill",
		unicode: "e8c9",
		unicode_decimal: 59593
	},
	{
		icon_id: "4936577",
		name: "control-fill",
		font_class: "control-fill",
		unicode: "e8ca",
		unicode_decimal: 59594
	},
	{
		icon_id: "4936583",
		name: "layout-fill",
		font_class: "layout-fill",
		unicode: "e8cb",
		unicode_decimal: 59595
	},
	{
		icon_id: "4936584",
		name: "app store-fill",
		font_class: "appstore-fill",
		unicode: "e8cc",
		unicode_decimal: 59596
	},
	{
		icon_id: "4936585",
		name: "mobile-fill",
		font_class: "mobile-fill",
		unicode: "e8cd",
		unicode_decimal: 59597
	},
	{
		icon_id: "4936586",
		name: "tablet-fill",
		font_class: "tablet-fill",
		unicode: "e8ce",
		unicode_decimal: 59598
	},
	{
		icon_id: "4936587",
		name: "book-fill",
		font_class: "book-fill",
		unicode: "e8cf",
		unicode_decimal: 59599
	},
	{
		icon_id: "4936588",
		name: "red envelope-fill",
		font_class: "redenvelope-fill",
		unicode: "e8d0",
		unicode_decimal: 59600
	},
	{
		icon_id: "4936591",
		name: "safety certificate-f",
		font_class: "safetycertificate-f",
		unicode: "e8d1",
		unicode_decimal: 59601
	},
	{
		icon_id: "4936592",
		name: "property safety-fill",
		font_class: "propertysafety-fill",
		unicode: "e8d2",
		unicode_decimal: 59602
	},
	{
		icon_id: "4936598",
		name: "insurance-fill",
		font_class: "insurance-fill",
		unicode: "e8d3",
		unicode_decimal: 59603
	},
	{
		icon_id: "4936599",
		name: "security scan-fill",
		font_class: "securityscan-fill",
		unicode: "e8d4",
		unicode_decimal: 59604
	},
	{
		icon_id: "4936602",
		name: "file-exclamation-fil",
		font_class: "file-exclamation-fil",
		unicode: "e8d5",
		unicode_decimal: 59605
	},
	{
		icon_id: "4936604",
		name: "file-add-fill",
		font_class: "file-add-fill",
		unicode: "e8d6",
		unicode_decimal: 59606
	},
	{
		icon_id: "4936605",
		name: "file-fill",
		font_class: "file-fill",
		unicode: "e8d7",
		unicode_decimal: 59607
	},
	{
		icon_id: "4936606",
		name: "file-excel-fill",
		font_class: "file-excel-fill",
		unicode: "e8d8",
		unicode_decimal: 59608
	},
	{
		icon_id: "4936607",
		name: "file-markdown-fill",
		font_class: "file-markdown-fill",
		unicode: "e8d9",
		unicode_decimal: 59609
	},
	{
		icon_id: "4936608",
		name: "file-text-fill",
		font_class: "file-text-fill",
		unicode: "e8da",
		unicode_decimal: 59610
	},
	{
		icon_id: "4936609",
		name: "file-ppt-fill",
		font_class: "file-ppt-fill",
		unicode: "e8db",
		unicode_decimal: 59611
	},
	{
		icon_id: "4936610",
		name: "file-unknown-fill",
		font_class: "file-unknown-fill",
		unicode: "e8dc",
		unicode_decimal: 59612
	},
	{
		icon_id: "4936611",
		name: "file-word-fill",
		font_class: "file-word-fill",
		unicode: "e8dd",
		unicode_decimal: 59613
	},
	{
		icon_id: "4936612",
		name: "file-zip-fill",
		font_class: "file-zip-fill",
		unicode: "e8de",
		unicode_decimal: 59614
	},
	{
		icon_id: "4936613",
		name: "file-pdf-fill",
		font_class: "file-pdf-fill",
		unicode: "e8df",
		unicode_decimal: 59615
	},
	{
		icon_id: "4936615",
		name: "file-image-fill",
		font_class: "file-image-fill",
		unicode: "e8e0",
		unicode_decimal: 59616
	},
	{
		icon_id: "4936617",
		name: "diff-fill",
		font_class: "diff-fill",
		unicode: "e8e1",
		unicode_decimal: 59617
	},
	{
		icon_id: "4936618",
		name: "file-copy-fill",
		font_class: "file-copy-fill",
		unicode: "e8e2",
		unicode_decimal: 59618
	},
	{
		icon_id: "4936619",
		name: "snippets-fill",
		font_class: "snippets-fill",
		unicode: "e8e3",
		unicode_decimal: 59619
	},
	{
		icon_id: "4936620",
		name: "batch folding-fill",
		font_class: "batchfolding-fill",
		unicode: "e8e4",
		unicode_decimal: 59620
	},
	{
		icon_id: "4936621",
		name: "reconciliation-fill",
		font_class: "reconciliation-fill",
		unicode: "e8e5",
		unicode_decimal: 59621
	},
	{
		icon_id: "4936622",
		name: "folder-add-fill",
		font_class: "folder-add-fill",
		unicode: "e8e6",
		unicode_decimal: 59622
	},
	{
		icon_id: "4936623",
		name: "folder-fill",
		font_class: "folder-fill",
		unicode: "e8e7",
		unicode_decimal: 59623
	},
	{
		icon_id: "4936624",
		name: "folder-open-fill",
		font_class: "folder-open-fill",
		unicode: "e8e8",
		unicode_decimal: 59624
	},
	{
		icon_id: "4936626",
		name: "database-fill",
		font_class: "database-fill",
		unicode: "e8e9",
		unicode_decimal: 59625
	},
	{
		icon_id: "4936627",
		name: "container-fill",
		font_class: "container-fill",
		unicode: "e8ea",
		unicode_decimal: 59626
	},
	{
		icon_id: "4936628",
		name: "sever-fill",
		font_class: "sever-fill",
		unicode: "e8eb",
		unicode_decimal: 59627
	},
	{
		icon_id: "4936629",
		name: "calendar-check-fill",
		font_class: "calendar-check-fill",
		unicode: "e8ec",
		unicode_decimal: 59628
	},
	{
		icon_id: "4936630",
		name: "image-fill",
		font_class: "image-fill",
		unicode: "e8ed",
		unicode_decimal: 59629
	},
	{
		icon_id: "4936631",
		name: "id card-fill",
		font_class: "idcard-fill",
		unicode: "e8ee",
		unicode_decimal: 59630
	},
	{
		icon_id: "4936633",
		name: "credit card-fill",
		font_class: "creditcard-fill",
		unicode: "e8ef",
		unicode_decimal: 59631
	},
	{
		icon_id: "4936634",
		name: "fund-fill",
		font_class: "fund-fill",
		unicode: "e8f0",
		unicode_decimal: 59632
	},
	{
		icon_id: "4936635",
		name: "read-fill",
		font_class: "read-fill",
		unicode: "e8f1",
		unicode_decimal: 59633
	},
	{
		icon_id: "4936636",
		name: "contacts-fill",
		font_class: "contacts-fill",
		unicode: "e8f2",
		unicode_decimal: 59634
	},
	{
		icon_id: "4936637",
		name: "delete-fill",
		font_class: "delete-fill",
		unicode: "e8f3",
		unicode_decimal: 59635
	},
	{
		icon_id: "4936638",
		name: "notification-fill",
		font_class: "notification-fill",
		unicode: "e8f4",
		unicode_decimal: 59636
	},
	{
		icon_id: "4936639",
		name: "flag-fill",
		font_class: "flag-fill",
		unicode: "e8f5",
		unicode_decimal: 59637
	},
	{
		icon_id: "4936640",
		name: "money collect-fill",
		font_class: "moneycollect-fill",
		unicode: "e8f6",
		unicode_decimal: 59638
	},
	{
		icon_id: "4936641",
		name: "medicine box-fill",
		font_class: "medicinebox-fill",
		unicode: "e8f7",
		unicode_decimal: 59639
	},
	{
		icon_id: "4936642",
		name: "rest-fill",
		font_class: "rest-fill",
		unicode: "e8f8",
		unicode_decimal: 59640
	},
	{
		icon_id: "4936643",
		name: "shopping-fill",
		font_class: "shopping-fill",
		unicode: "e8f9",
		unicode_decimal: 59641
	},
	{
		icon_id: "4936644",
		name: "skin-fill",
		font_class: "skin-fill",
		unicode: "e8fa",
		unicode_decimal: 59642
	},
	{
		icon_id: "4936645",
		name: "video-fill",
		font_class: "video-fill",
		unicode: "e8fb",
		unicode_decimal: 59643
	},
	{
		icon_id: "4936646",
		name: "sound-fill",
		font_class: "sound-fill",
		unicode: "e8fc",
		unicode_decimal: 59644
	},
	{
		icon_id: "4936649",
		name: "bulb-fill",
		font_class: "bulb-fill",
		unicode: "e8fd",
		unicode_decimal: 59645
	},
	{
		icon_id: "4936650",
		name: "bell-fill",
		font_class: "bell-fill",
		unicode: "e8fe",
		unicode_decimal: 59646
	},
	{
		icon_id: "4936651",
		name: "filter-fill",
		font_class: "filter-fill",
		unicode: "e8ff",
		unicode_decimal: 59647
	},
	{
		icon_id: "4936652",
		name: "fire-fill",
		font_class: "fire-fill",
		unicode: "e900",
		unicode_decimal: 59648
	},
	{
		icon_id: "4936653",
		name: "funnel plot-fill",
		font_class: "funnelplot-fill",
		unicode: "e901",
		unicode_decimal: 59649
	},
	{
		icon_id: "4936654",
		name: "gift-fill",
		font_class: "gift-fill",
		unicode: "e902",
		unicode_decimal: 59650
	},
	{
		icon_id: "4936655",
		name: "hourglass-fill",
		font_class: "hourglass-fill",
		unicode: "e903",
		unicode_decimal: 59651
	},
	{
		icon_id: "4936656",
		name: "home-fill",
		font_class: "home-fill",
		unicode: "e904",
		unicode_decimal: 59652
	},
	{
		icon_id: "4936657",
		name: "trophy-fill",
		font_class: "trophy-fill",
		unicode: "e905",
		unicode_decimal: 59653
	},
	{
		icon_id: "4936659",
		name: "location-fill",
		font_class: "location-fill",
		unicode: "e906",
		unicode_decimal: 59654
	},
	{
		icon_id: "4936665",
		name: "cloud-fill",
		font_class: "cloud-fill",
		unicode: "e907",
		unicode_decimal: 59655
	},
	{
		icon_id: "4936666",
		name: "customerservice-fill",
		font_class: "customerservice-fill",
		unicode: "e908",
		unicode_decimal: 59656
	},
	{
		icon_id: "4936667",
		name: "experiment-fill",
		font_class: "experiment-fill",
		unicode: "e909",
		unicode_decimal: 59657
	},
	{
		icon_id: "4936668",
		name: "eye-fill",
		font_class: "eye-fill",
		unicode: "e90a",
		unicode_decimal: 59658
	},
	{
		icon_id: "4936669",
		name: "like-fill",
		font_class: "like-fill",
		unicode: "e90b",
		unicode_decimal: 59659
	},
	{
		icon_id: "4936671",
		name: "lock-fill",
		font_class: "lock-fill",
		unicode: "e90c",
		unicode_decimal: 59660
	},
	{
		icon_id: "4936672",
		name: "unlike-fill",
		font_class: "unlike-fill",
		unicode: "e90d",
		unicode_decimal: 59661
	},
	{
		icon_id: "4936673",
		name: "star-fill",
		font_class: "star-fill",
		unicode: "e90e",
		unicode_decimal: 59662
	},
	{
		icon_id: "4936674",
		name: "unlock-fill",
		font_class: "unlock-fill",
		unicode: "e90f",
		unicode_decimal: 59663
	},
	{
		icon_id: "4936675",
		name: "alert-fill",
		font_class: "alert-fill",
		unicode: "e910",
		unicode_decimal: 59664
	},
	{
		icon_id: "4936676",
		name: "api-fill",
		font_class: "api-fill",
		unicode: "e911",
		unicode_decimal: 59665
	},
	{
		icon_id: "4936677",
		name: "highlight-fill",
		font_class: "highlight-fill",
		unicode: "e912",
		unicode_decimal: 59666
	},
	{
		icon_id: "4936678",
		name: "phone-fill",
		font_class: "phone-fill",
		unicode: "e913",
		unicode_decimal: 59667
	},
	{
		icon_id: "4936679",
		name: "edit-fill",
		font_class: "edit-fill",
		unicode: "e914",
		unicode_decimal: 59668
	},
	{
		icon_id: "4936680",
		name: "pushpin-fill",
		font_class: "pushpin-fill",
		unicode: "e915",
		unicode_decimal: 59669
	},
	{
		icon_id: "4936681",
		name: "rocket-fill",
		font_class: "rocket-fill",
		unicode: "e916",
		unicode_decimal: 59670
	},
	{
		icon_id: "4936682",
		name: "thunderbolt-fill",
		font_class: "thunderbolt-fill",
		unicode: "e917",
		unicode_decimal: 59671
	},
	{
		icon_id: "4936683",
		name: "tag-fill",
		font_class: "tag-fill",
		unicode: "e918",
		unicode_decimal: 59672
	},
	{
		icon_id: "4936684",
		name: "wrench-fill",
		font_class: "wrench-fill",
		unicode: "e919",
		unicode_decimal: 59673
	},
	{
		icon_id: "4936685",
		name: "tags-fill",
		font_class: "tags-fill",
		unicode: "e91a",
		unicode_decimal: 59674
	},
	{
		icon_id: "4936686",
		name: "bank-fill",
		font_class: "bank-fill",
		unicode: "e91b",
		unicode_decimal: 59675
	},
	{
		icon_id: "4936687",
		name: "camera-fill",
		font_class: "camera-fill",
		unicode: "e91c",
		unicode_decimal: 59676
	},
	{
		icon_id: "4936688",
		name: "error-fill",
		font_class: "error-fill",
		unicode: "e91d",
		unicode_decimal: 59677
	},
	{
		icon_id: "4936689",
		name: "crown-fill",
		font_class: "crown-fill",
		unicode: "e91e",
		unicode_decimal: 59678
	},
	{
		icon_id: "4936690",
		name: "mail-fill",
		font_class: "mail-fill",
		unicode: "e91f",
		unicode_decimal: 59679
	},
	{
		icon_id: "4936691",
		name: "car-fill",
		font_class: "car-fill",
		unicode: "e920",
		unicode_decimal: 59680
	},
	{
		icon_id: "4936692",
		name: "printer-fill",
		font_class: "printer-fill",
		unicode: "e921",
		unicode_decimal: 59681
	},
	{
		icon_id: "4936693",
		name: "shop-fill",
		font_class: "shop-fill",
		unicode: "e922",
		unicode_decimal: 59682
	},
	{
		icon_id: "4936694",
		name: "setting-fill",
		font_class: "setting-fill",
		unicode: "e923",
		unicode_decimal: 59683
	},
	{
		icon_id: "4936695",
		name: "USB-fill",
		font_class: "USB-fill",
		unicode: "e924",
		unicode_decimal: 59684
	},
	{
		icon_id: "4936696",
		name: "golden-fill",
		font_class: "golden-fill",
		unicode: "e925",
		unicode_decimal: 59685
	},
	{
		icon_id: "4936697",
		name: "build-fill",
		font_class: "build-fill",
		unicode: "e926",
		unicode_decimal: 59686
	},
	{
		icon_id: "4936698",
		name: "box plot-fill",
		font_class: "boxplot-fill",
		unicode: "e927",
		unicode_decimal: 59687
	},
	{
		icon_id: "4936699",
		name: "sliders-fill",
		font_class: "sliders-fill",
		unicode: "e928",
		unicode_decimal: 59688
	},
	{
		icon_id: "4936943",
		name: "alibaba",
		font_class: "alibaba",
		unicode: "e929",
		unicode_decimal: 59689
	},
	{
		icon_id: "4936944",
		name: "alibabacloud",
		font_class: "alibabacloud",
		unicode: "e92a",
		unicode_decimal: 59690
	},
	{
		icon_id: "4936946",
		name: "ant design",
		font_class: "antdesign",
		unicode: "e92b",
		unicode_decimal: 59691
	},
	{
		icon_id: "4936947",
		name: "ant-cloud",
		font_class: "ant-cloud",
		unicode: "e92c",
		unicode_decimal: 59692
	},
	{
		icon_id: "4936948",
		name: "behance",
		font_class: "behance",
		unicode: "e92d",
		unicode_decimal: 59693
	},
	{
		icon_id: "4936949",
		name: "google plus",
		font_class: "googleplus",
		unicode: "e92e",
		unicode_decimal: 59694
	},
	{
		icon_id: "4936950",
		name: "medium",
		font_class: "medium",
		unicode: "e92f",
		unicode_decimal: 59695
	},
	{
		icon_id: "4936951",
		name: "google",
		font_class: "google",
		unicode: "e930",
		unicode_decimal: 59696
	},
	{
		icon_id: "4936952",
		name: "IE",
		font_class: "IE",
		unicode: "e931",
		unicode_decimal: 59697
	},
	{
		icon_id: "4936953",
		name: "amazon",
		font_class: "amazon",
		unicode: "e932",
		unicode_decimal: 59698
	},
	{
		icon_id: "4936954",
		name: "slack",
		font_class: "slack",
		unicode: "e933",
		unicode_decimal: 59699
	},
	{
		icon_id: "4936955",
		name: "alipay",
		font_class: "alipay",
		unicode: "e934",
		unicode_decimal: 59700
	},
	{
		icon_id: "4936956",
		name: "taobao",
		font_class: "taobao",
		unicode: "e935",
		unicode_decimal: 59701
	},
	{
		icon_id: "4936957",
		name: "zhihu",
		font_class: "zhihu",
		unicode: "e936",
		unicode_decimal: 59702
	},
	{
		icon_id: "4936958",
		name: "HTML5",
		font_class: "HTML",
		unicode: "e937",
		unicode_decimal: 59703
	},
	{
		icon_id: "4936959",
		name: "linkedin",
		font_class: "linkedin",
		unicode: "e938",
		unicode_decimal: 59704
	},
	{
		icon_id: "4936960",
		name: "yahoo",
		font_class: "yahoo",
		unicode: "e939",
		unicode_decimal: 59705
	},
	{
		icon_id: "4936961",
		name: "facebook",
		font_class: "facebook",
		unicode: "e93a",
		unicode_decimal: 59706
	},
	{
		icon_id: "4936962",
		name: "skype",
		font_class: "skype",
		unicode: "e93b",
		unicode_decimal: 59707
	},
	{
		icon_id: "4936963",
		name: "CodeSandbox",
		font_class: "CodeSandbox",
		unicode: "e93c",
		unicode_decimal: 59708
	},
	{
		icon_id: "4936964",
		name: "chrome",
		font_class: "chrome",
		unicode: "e93d",
		unicode_decimal: 59709
	},
	{
		icon_id: "4936965",
		name: "codepen",
		font_class: "codepen",
		unicode: "e93e",
		unicode_decimal: 59710
	},
	{
		icon_id: "4936966",
		name: "aliwangwang",
		font_class: "aliwangwang",
		unicode: "e93f",
		unicode_decimal: 59711
	},
	{
		icon_id: "4936967",
		name: "apple",
		font_class: "apple",
		unicode: "e940",
		unicode_decimal: 59712
	},
	{
		icon_id: "4936968",
		name: "android",
		font_class: "android",
		unicode: "e941",
		unicode_decimal: 59713
	},
	{
		icon_id: "4936969",
		name: "sketch",
		font_class: "sketch",
		unicode: "e942",
		unicode_decimal: 59714
	},
	{
		icon_id: "4936970",
		name: "Gitlab",
		font_class: "Gitlab",
		unicode: "e943",
		unicode_decimal: 59715
	},
	{
		icon_id: "4936971",
		name: "dribbble",
		font_class: "dribbble",
		unicode: "e944",
		unicode_decimal: 59716
	},
	{
		icon_id: "4936972",
		name: "instagram",
		font_class: "instagram",
		unicode: "e945",
		unicode_decimal: 59717
	},
	{
		icon_id: "4936973",
		name: "reddit",
		font_class: "reddit",
		unicode: "e946",
		unicode_decimal: 59718
	},
	{
		icon_id: "4936974",
		name: "windows",
		font_class: "windows",
		unicode: "e947",
		unicode_decimal: 59719
	},
	{
		icon_id: "4936975",
		name: "yuque",
		font_class: "yuque",
		unicode: "e948",
		unicode_decimal: 59720
	},
	{
		icon_id: "4936976",
		name: "Youtube",
		font_class: "Youtube",
		unicode: "e949",
		unicode_decimal: 59721
	},
	{
		icon_id: "4936977",
		name: "Gitlab-fill",
		font_class: "Gitlab-fill",
		unicode: "e94a",
		unicode_decimal: 59722
	},
	{
		icon_id: "4936978",
		name: "dropbox",
		font_class: "dropbox",
		unicode: "e94b",
		unicode_decimal: 59723
	},
	{
		icon_id: "4936979",
		name: "dingtalk",
		font_class: "dingtalk",
		unicode: "e94c",
		unicode_decimal: 59724
	},
	{
		icon_id: "4936980",
		name: "android-fill",
		font_class: "android-fill",
		unicode: "e94d",
		unicode_decimal: 59725
	},
	{
		icon_id: "4936981",
		name: "apple-fill",
		font_class: "apple-fill",
		unicode: "e94e",
		unicode_decimal: 59726
	},
	{
		icon_id: "4936982",
		name: "HTML5-fill",
		font_class: "HTML-fill",
		unicode: "e94f",
		unicode_decimal: 59727
	},
	{
		icon_id: "4936983",
		name: "windows-fill",
		font_class: "windows-fill",
		unicode: "e950",
		unicode_decimal: 59728
	},
	{
		icon_id: "4936984",
		name: "QQ",
		font_class: "QQ",
		unicode: "e951",
		unicode_decimal: 59729
	},
	{
		icon_id: "4936985",
		name: "twitter",
		font_class: "twitter",
		unicode: "e952",
		unicode_decimal: 59730
	},
	{
		icon_id: "4936986",
		name: "skype-fill",
		font_class: "skype-fill",
		unicode: "e953",
		unicode_decimal: 59731
	},
	{
		icon_id: "4936987",
		name: "weibo",
		font_class: "weibo",
		unicode: "e954",
		unicode_decimal: 59732
	},
	{
		icon_id: "4936988",
		name: "yuque-fill",
		font_class: "yuque-fill",
		unicode: "e955",
		unicode_decimal: 59733
	},
	{
		icon_id: "4936989",
		name: "Youtube-fill",
		font_class: "Youtube-fill",
		unicode: "e956",
		unicode_decimal: 59734
	},
	{
		icon_id: "4936990",
		name: "yahoo-fill",
		font_class: "yahoo-fill",
		unicode: "e957",
		unicode_decimal: 59735
	},
	{
		icon_id: "4936991",
		name: "wechat-fill",
		font_class: "wechat-fill",
		unicode: "e958",
		unicode_decimal: 59736
	},
	{
		icon_id: "4936992",
		name: "chrome-fill",
		font_class: "chrome-fill",
		unicode: "e959",
		unicode_decimal: 59737
	},
	{
		icon_id: "4936993",
		name: "alipay-circle-fill",
		font_class: "alipay-circle-fill",
		unicode: "e95a",
		unicode_decimal: 59738
	},
	{
		icon_id: "4936994",
		name: "aliwangwang-fill",
		font_class: "aliwangwang-fill",
		unicode: "e95b",
		unicode_decimal: 59739
	},
	{
		icon_id: "4936995",
		name: "behance-circle-fill",
		font_class: "behance-circle-fill",
		unicode: "e95c",
		unicode_decimal: 59740
	},
	{
		icon_id: "4936996",
		name: "amazon-circle-fill",
		font_class: "amazon-circle-fill",
		unicode: "e95d",
		unicode_decimal: 59741
	},
	{
		icon_id: "4936997",
		name: "codepen-circle-fill",
		font_class: "codepen-circle-fill",
		unicode: "e95e",
		unicode_decimal: 59742
	},
	{
		icon_id: "4936998",
		name: "CodeSandbox-circle-f",
		font_class: "CodeSandbox-circle-f",
		unicode: "e95f",
		unicode_decimal: 59743
	},
	{
		icon_id: "4936999",
		name: "dropbox-circle-fill",
		font_class: "dropbox-circle-fill",
		unicode: "e960",
		unicode_decimal: 59744
	},
	{
		icon_id: "4937000",
		name: "github-fill",
		font_class: "github-fill",
		unicode: "e961",
		unicode_decimal: 59745
	},
	{
		icon_id: "4937001",
		name: "dribbble-circle-fill",
		font_class: "dribbble-circle-fill",
		unicode: "e962",
		unicode_decimal: 59746
	},
	{
		icon_id: "4937002",
		name: "google plus-circle-f",
		font_class: "googleplus-circle-f",
		unicode: "e963",
		unicode_decimal: 59747
	},
	{
		icon_id: "4937003",
		name: "medium-circle-fill",
		font_class: "medium-circle-fill",
		unicode: "e964",
		unicode_decimal: 59748
	},
	{
		icon_id: "4937004",
		name: "QQ-circle-fill",
		font_class: "QQ-circle-fill",
		unicode: "e965",
		unicode_decimal: 59749
	},
	{
		icon_id: "4937005",
		name: "IE-circle-fill",
		font_class: "IE-circle-fill",
		unicode: "e966",
		unicode_decimal: 59750
	},
	{
		icon_id: "4937006",
		name: "google-circle-fill",
		font_class: "google-circle-fill",
		unicode: "e967",
		unicode_decimal: 59751
	},
	{
		icon_id: "4937007",
		name: "dingtalk-circle-fill",
		font_class: "dingtalk-circle-fill",
		unicode: "e968",
		unicode_decimal: 59752
	},
	{
		icon_id: "4937008",
		name: "sketch-circle-fill",
		font_class: "sketch-circle-fill",
		unicode: "e969",
		unicode_decimal: 59753
	},
	{
		icon_id: "4937009",
		name: "slack-circle-fill",
		font_class: "slack-circle-fill",
		unicode: "e96a",
		unicode_decimal: 59754
	},
	{
		icon_id: "4937010",
		name: "twitter-circle-fill",
		font_class: "twitter-circle-fill",
		unicode: "e96b",
		unicode_decimal: 59755
	},
	{
		icon_id: "4937011",
		name: "taobao-circle-fill",
		font_class: "taobao-circle-fill",
		unicode: "e96c",
		unicode_decimal: 59756
	},
	{
		icon_id: "4937012",
		name: "weibo-circle-fill",
		font_class: "weibo-circle-fill",
		unicode: "e96d",
		unicode_decimal: 59757
	},
	{
		icon_id: "4937013",
		name: "zhihu-circle-fill",
		font_class: "zhihu-circle-fill",
		unicode: "e96e",
		unicode_decimal: 59758
	},
	{
		icon_id: "4937014",
		name: "reddit-circle-fill",
		font_class: "reddit-circle-fill",
		unicode: "e96f",
		unicode_decimal: 59759
	},
	{
		icon_id: "4937015",
		name: "alipay-square-fill",
		font_class: "alipay-square-fill",
		unicode: "e970",
		unicode_decimal: 59760
	},
	{
		icon_id: "4937016",
		name: "dingtalk-square-fill",
		font_class: "dingtalk-square-fill",
		unicode: "e971",
		unicode_decimal: 59761
	},
	{
		icon_id: "4937017",
		name: "CodeSandbox-square-f",
		font_class: "CodeSandbox-square-f",
		unicode: "e972",
		unicode_decimal: 59762
	},
	{
		icon_id: "4937018",
		name: "behance-square-fill",
		font_class: "behance-square-fill",
		unicode: "e973",
		unicode_decimal: 59763
	},
	{
		icon_id: "4937019",
		name: "amazon-square-fill",
		font_class: "amazon-square-fill",
		unicode: "e974",
		unicode_decimal: 59764
	},
	{
		icon_id: "4937020",
		name: "codepen-square-fill",
		font_class: "codepen-square-fill",
		unicode: "e975",
		unicode_decimal: 59765
	},
	{
		icon_id: "4937021",
		name: "dribbble-square-fill",
		font_class: "dribbble-square-fill",
		unicode: "e976",
		unicode_decimal: 59766
	},
	{
		icon_id: "4937022",
		name: "dropbox-square-fill",
		font_class: "dropbox-square-fill",
		unicode: "e977",
		unicode_decimal: 59767
	},
	{
		icon_id: "4937023",
		name: "facebook-fill",
		font_class: "facebook-fill",
		unicode: "e978",
		unicode_decimal: 59768
	},
	{
		icon_id: "4937024",
		name: "google plus-square-f",
		font_class: "googleplus-square-f",
		unicode: "e979",
		unicode_decimal: 59769
	},
	{
		icon_id: "4937025",
		name: "google-square-fill",
		font_class: "google-square-fill",
		unicode: "e97a",
		unicode_decimal: 59770
	},
	{
		icon_id: "4937026",
		name: "instagram-fill",
		font_class: "instagram-fill",
		unicode: "e97b",
		unicode_decimal: 59771
	},
	{
		icon_id: "4937027",
		name: "IE-square-fill",
		font_class: "IE-square-fill",
		unicode: "e97c",
		unicode_decimal: 59772
	},
	{
		icon_id: "4937028",
		name: "medium-square-fill",
		font_class: "medium-square-fill",
		unicode: "e97d",
		unicode_decimal: 59773
	},
	{
		icon_id: "4937029",
		name: "linkedin-fill",
		font_class: "linkedin-fill",
		unicode: "e97e",
		unicode_decimal: 59774
	},
	{
		icon_id: "4937030",
		name: "QQ-square-fill",
		font_class: "QQ-square-fill",
		unicode: "e97f",
		unicode_decimal: 59775
	},
	{
		icon_id: "4937031",
		name: "reddit-square-fill",
		font_class: "reddit-square-fill",
		unicode: "e980",
		unicode_decimal: 59776
	},
	{
		icon_id: "4937032",
		name: "twitter-square-fill",
		font_class: "twitter-square-fill",
		unicode: "e981",
		unicode_decimal: 59777
	},
	{
		icon_id: "4937033",
		name: "sketch-square-fill",
		font_class: "sketch-square-fill",
		unicode: "e982",
		unicode_decimal: 59778
	},
	{
		icon_id: "4937034",
		name: "slack-square-fill",
		font_class: "slack-square-fill",
		unicode: "e983",
		unicode_decimal: 59779
	},
	{
		icon_id: "4937035",
		name: "taobao-square-fill",
		font_class: "taobao-square-fill",
		unicode: "e984",
		unicode_decimal: 59780
	},
	{
		icon_id: "4937036",
		name: "weibo-square-fill",
		font_class: "weibo-square-fill",
		unicode: "e985",
		unicode_decimal: 59781
	},
	{
		icon_id: "4937037",
		name: "zhihu-square-fill",
		font_class: "zhihu-square-fill",
		unicode: "e986",
		unicode_decimal: 59782
	},
	{
		icon_id: "5756279",
		name: "zoom out",
		font_class: "zoomout",
		unicode: "e987",
		unicode_decimal: 59783
	},
	{
		icon_id: "5756280",
		name: "apartment",
		font_class: "apartment",
		unicode: "e988",
		unicode_decimal: 59784
	},
	{
		icon_id: "5756281",
		name: "audio",
		font_class: "audio",
		unicode: "e989",
		unicode_decimal: 59785
	},
	{
		icon_id: "5756282",
		name: "audio-fill",
		font_class: "audio-fill",
		unicode: "e98a",
		unicode_decimal: 59786
	},
	{
		icon_id: "5756283",
		name: "robot",
		font_class: "robot",
		unicode: "e98b",
		unicode_decimal: 59787
	},
	{
		icon_id: "5756284",
		name: "zoom in",
		font_class: "zoomin",
		unicode: "e98c",
		unicode_decimal: 59788
	},
	{
		icon_id: "6598312",
		name: "robot-fill",
		font_class: "robot-fill",
		unicode: "e98d",
		unicode_decimal: 59789
	},
	{
		icon_id: "6598313",
		name: "bug-fill",
		font_class: "bug-fill",
		unicode: "e98e",
		unicode_decimal: 59790
	},
	{
		icon_id: "6598314",
		name: "bug",
		font_class: "bug",
		unicode: "e98f",
		unicode_decimal: 59791
	},
	{
		icon_id: "6598315",
		name: "audio static",
		font_class: "audiostatic",
		unicode: "e990",
		unicode_decimal: 59792
	},
	{
		icon_id: "6598316",
		name: "comment",
		font_class: "comment",
		unicode: "e991",
		unicode_decimal: 59793
	},
	{
		icon_id: "6598317",
		name: "signal-fill",
		font_class: "signal-fill",
		unicode: "e992",
		unicode_decimal: 59794
	},
	{
		icon_id: "6598318",
		name: "verified",
		font_class: "verified",
		unicode: "e993",
		unicode_decimal: 59795
	},
	{
		icon_id: "6598319",
		name: "shortcut-fill",
		font_class: "shortcut-fill",
		unicode: "e994",
		unicode_decimal: 59796
	},
	{
		icon_id: "6598320",
		name: "videocamera add",
		font_class: "videocameraadd",
		unicode: "e995",
		unicode_decimal: 59797
	},
	{
		icon_id: "6598321",
		name: "switch user",
		font_class: "switchuser",
		unicode: "e996",
		unicode_decimal: 59798
	},
	{
		icon_id: "6598322",
		name: "whatsapp",
		font_class: "whatsapp",
		unicode: "e997",
		unicode_decimal: 59799
	},
	{
		icon_id: "6598323",
		name: "appstore add",
		font_class: "appstoreadd",
		unicode: "e998",
		unicode_decimal: 59800
	},
	{
		icon_id: "6598339",
		name: "caret-down",
		font_class: "caret-down",
		unicode: "e999",
		unicode_decimal: 59801
	},
	{
		icon_id: "6598340",
		name: "backward",
		font_class: "backward",
		unicode: "e99a",
		unicode_decimal: 59802
	},
	{
		icon_id: "6598341",
		name: "caret-up",
		font_class: "caret-up",
		unicode: "e99b",
		unicode_decimal: 59803
	},
	{
		icon_id: "6598342",
		name: "caret-right",
		font_class: "caret-right",
		unicode: "e99c",
		unicode_decimal: 59804
	},
	{
		icon_id: "6598343",
		name: "caret-left",
		font_class: "caret-left",
		unicode: "e99d",
		unicode_decimal: 59805
	},
	{
		icon_id: "6598344",
		name: "fast-backward",
		font_class: "fast-backward",
		unicode: "e99e",
		unicode_decimal: 59806
	},
	{
		icon_id: "6598345",
		name: "forward",
		font_class: "forward",
		unicode: "e99f",
		unicode_decimal: 59807
	},
	{
		icon_id: "6598346",
		name: "fast-forward",
		font_class: "fast-forward",
		unicode: "e9a0",
		unicode_decimal: 59808
	},
	{
		icon_id: "6598347",
		name: "search",
		font_class: "search",
		unicode: "e9a1",
		unicode_decimal: 59809
	},
	{
		icon_id: "6598348",
		name: "retweet",
		font_class: "retweet",
		unicode: "e9a2",
		unicode_decimal: 59810
	},
	{
		icon_id: "6598349",
		name: "login",
		font_class: "login",
		unicode: "e9a3",
		unicode_decimal: 59811
	},
	{
		icon_id: "6598350",
		name: "step-backward",
		font_class: "step-backward",
		unicode: "e9a4",
		unicode_decimal: 59812
	},
	{
		icon_id: "6598351",
		name: "step-forward",
		font_class: "step-forward",
		unicode: "e9a5",
		unicode_decimal: 59813
	},
	{
		icon_id: "6598352",
		name: "swap-right",
		font_class: "swap-right",
		unicode: "e9a6",
		unicode_decimal: 59814
	},
	{
		icon_id: "6598353",
		name: "swap-left",
		font_class: "swap-left",
		unicode: "e9a7",
		unicode_decimal: 59815
	},
	{
		icon_id: "6598354",
		name: "woman",
		font_class: "woman",
		unicode: "e9a8",
		unicode_decimal: 59816
	},
	{
		icon_id: "7605109",
		name: "company",
		font_class: "company",
		unicode: "e623",
		unicode_decimal: 58915
	},
	{
		icon_id: "7834345",
		name: "plus",
		font_class: "plus",
		unicode: "e9a9",
		unicode_decimal: 59817
	},
	{
		icon_id: "8092166",
		name: "eye close-fill",
		font_class: "eyeclose-fill",
		unicode: "e9aa",
		unicode_decimal: 59818
	},
	{
		icon_id: "8092167",
		name: "eye-close",
		font_class: "eye-close",
		unicode: "e9ab",
		unicode_decimal: 59819
	},
	{
		icon_id: "8094805",
		name: "clear",
		font_class: "clear",
		unicode: "e9ac",
		unicode_decimal: 59820
	},
	{
		icon_id: "8094806",
		name: "collapse",
		font_class: "collapse",
		unicode: "e9ad",
		unicode_decimal: 59821
	},
	{
		icon_id: "8094807",
		name: "expand",
		font_class: "expand",
		unicode: "e9ae",
		unicode_decimal: 59822
	},
	{
		icon_id: "8094808",
		name: "delete column",
		font_class: "deletecolumn",
		unicode: "e9af",
		unicode_decimal: 59823
	},
	{
		icon_id: "8094809",
		name: "merge-cells",
		font_class: "merge-cells",
		unicode: "e9b0",
		unicode_decimal: 59824
	},
	{
		icon_id: "8094810",
		name: "subnode",
		font_class: "subnode",
		unicode: "e9b1",
		unicode_decimal: 59825
	},
	{
		icon_id: "8094811",
		name: "rotate-left",
		font_class: "rotate-left",
		unicode: "e9b2",
		unicode_decimal: 59826
	},
	{
		icon_id: "8094812",
		name: "rotate-right",
		font_class: "rotate-right",
		unicode: "e9b3",
		unicode_decimal: 59827
	},
	{
		icon_id: "8094813",
		name: "insert row below",
		font_class: "insertrowbelow",
		unicode: "e9b4",
		unicode_decimal: 59828
	},
	{
		icon_id: "8094814",
		name: "insert row above",
		font_class: "insertrowabove",
		unicode: "e9b5",
		unicode_decimal: 59829
	},
	{
		icon_id: "8094815",
		name: "table",
		font_class: "table1",
		unicode: "e9b6",
		unicode_decimal: 59830
	},
	{
		icon_id: "8094816",
		name: "solit-cells",
		font_class: "solit-cells",
		unicode: "e9b7",
		unicode_decimal: 59831
	},
	{
		icon_id: "8094817",
		name: "format painter",
		font_class: "formatpainter",
		unicode: "e9b8",
		unicode_decimal: 59832
	},
	{
		icon_id: "8094818",
		name: "insert row right",
		font_class: "insertrowright",
		unicode: "e9b9",
		unicode_decimal: 59833
	},
	{
		icon_id: "8094819",
		name: "format painter-fill",
		font_class: "formatpainter-fill",
		unicode: "e9ba",
		unicode_decimal: 59834
	},
	{
		icon_id: "8094820",
		name: "insert row left",
		font_class: "insertrowleft",
		unicode: "e9bb",
		unicode_decimal: 59835
	},
	{
		icon_id: "8094821",
		name: "translate",
		font_class: "translate",
		unicode: "e9bc",
		unicode_decimal: 59836
	},
	{
		icon_id: "8094822",
		name: "delete row",
		font_class: "deleterow",
		unicode: "e9bd",
		unicode_decimal: 59837
	},
	{
		icon_id: "8094823",
		name: "sisternode",
		font_class: "sisternode",
		unicode: "e9be",
		unicode_decimal: 59838
	},
	{
		icon_id: "9229175",
		name: "Field-number",
		font_class: "Field-number",
		unicode: "e9bf",
		unicode_decimal: 59839
	},
	{
		icon_id: "9229176",
		name: "Field-String",
		font_class: "Field-String",
		unicode: "e9c0",
		unicode_decimal: 59840
	},
	{
		icon_id: "9229177",
		name: "Function",
		font_class: "Function",
		unicode: "e9c1",
		unicode_decimal: 59841
	},
	{
		icon_id: "9229178",
		name: "Field-time",
		font_class: "Field-time",
		unicode: "e9c2",
		unicode_decimal: 59842
	},
	{
		icon_id: "9229179",
		name: "GIF",
		font_class: "GIF",
		unicode: "e9c3",
		unicode_decimal: 59843
	},
	{
		icon_id: "9229180",
		name: "Partition",
		font_class: "Partition",
		unicode: "e9c4",
		unicode_decimal: 59844
	},
	{
		icon_id: "9229181",
		name: "index",
		font_class: "index",
		unicode: "e9c5",
		unicode_decimal: 59845
	},
	{
		icon_id: "9229182",
		name: "Stored procedure",
		font_class: "Storedprocedure",
		unicode: "e9c6",
		unicode_decimal: 59846
	},
	{
		icon_id: "9229184",
		name: "Field-Binary",
		font_class: "Field-Binary",
		unicode: "e9c7",
		unicode_decimal: 59847
	},
	{
		icon_id: "9229185",
		name: "Console-SQL",
		font_class: "Console-SQL",
		unicode: "e9c8",
		unicode_decimal: 59848
	},
	{
		icon_id: "9230689",
		name: "1:1",
		font_class: "icon-test",
		unicode: "e9c9",
		unicode_decimal: 59849
	},
	{
		icon_id: "9230690",
		name: "aim",
		font_class: "aim",
		unicode: "e9ca",
		unicode_decimal: 59850
	},
	{
		icon_id: "9230691",
		name: "compress",
		font_class: "compress",
		unicode: "e9cb",
		unicode_decimal: 59851
	},
	{
		icon_id: "9230692",
		name: "expend",
		font_class: "expend",
		unicode: "e9cc",
		unicode_decimal: 59852
	},
	{
		icon_id: "9230693",
		name: "folder-view",
		font_class: "folder-view",
		unicode: "e9cd",
		unicode_decimal: 59853
	},
	{
		icon_id: "9230694",
		name: "file-GIF",
		font_class: "file-GIF",
		unicode: "e9ce",
		unicode_decimal: 59854
	},
	{
		icon_id: "9230695",
		name: "group",
		font_class: "group",
		unicode: "e9cf",
		unicode_decimal: 59855
	},
	{
		icon_id: "9230696",
		name: "send",
		font_class: "send",
		unicode: "e9d0",
		unicode_decimal: 59856
	},
	{
		icon_id: "9230697",
		name: "Report",
		font_class: "Report",
		unicode: "e9d1",
		unicode_decimal: 59857
	},
	{
		icon_id: "9230698",
		name: "View",
		font_class: "View",
		unicode: "e9d2",
		unicode_decimal: 59858
	},
	{
		icon_id: "9230699",
		name: "shortcut",
		font_class: "shortcut",
		unicode: "e9d3",
		unicode_decimal: 59859
	},
	{
		icon_id: "9230700",
		name: "ungroup",
		font_class: "ungroup",
		unicode: "e9d4",
		unicode_decimal: 59860
	}
];
var fonts = {
	id: id,
	name: name,
	font_family: font_family,
	css_prefix_text: css_prefix_text,
	description: description,
	glyphs: glyphs
};

var ICON_FONT_FAMILY_MAP = {};
var registerFontFamily = function registerFontFamily(extendIcons) {
  ICON_FONT_FAMILY_MAP.graphin = fonts.glyphs;
  extendIcons.forEach(function (item) {
    ICON_FONT_FAMILY_MAP[item.fontFamily] = item.map;
  });
};
var iconFont = (function (type, fontFamily) {
  var selectedIconFont = ICON_FONT_FAMILY_MAP[fontFamily]; // fontFamily not found

  if (!selectedIconFont) {
    console.warn("fontFamily ".concat(fontFamily, " not found"));
    return '';
  }

  var icons = selectedIconFont.map(function (icon) {
    return {
      name: icon.name,
      unicode: String.fromCodePoint(icon.unicode_decimal)
    };
  });
  var matchIcon = icons.find(function (icon) {
    return icon.name === type;
  }) || {
    unicode: '',
    name: ''
  };
  return matchIcon.unicode;
});

var defaultStyle = {
  nodeSize: 20,
  primaryColor: '#9900EF',
  fontSize: 12,
  fontColor: '#3b3b3b',
  dark: '#eee',
  fontFamily: 'graphin'
};

var renderNodeShape = function renderNodeShape(node) {
  var mergedStyle = _objectSpread2({}, defaultStyle, {}, node.style);

  var primaryColor = mergedStyle.primaryColor,
      nodeSize = mergedStyle.nodeSize,
      fontColor = mergedStyle.fontColor,
      fontSize = mergedStyle.fontSize,
      dark = mergedStyle.dark,
      fontFamily = mergedStyle.fontFamily,
      icon = mergedStyle.icon;
  var iconSize = nodeSize;
  var fontPosition = nodeSize * 1.4;
  return {
    type: 'CircleNode',
    shapeComponents: [{
      type: 'circle',
      attrs: {
        id: 'circle-container',
        x: 0,
        y: 0,
        r: nodeSize,
        fill: '#fff',
        stroke: primaryColor,
        cursor: 'pointer',
        lineWidth: 2
      }
    }, // G6 iconfont 方案。https://www.yuque.com/antv/g6/acaihu
    {
      type: 'text',
      attrs: {
        id: 'node-icon',
        x: 0,
        y: 0,
        fontSize: iconSize,
        fill: primaryColor,
        text: iconFont(icon || node.data.type || '', fontFamily),
        fontFamily: fontFamily,
        textAlign: 'center',
        textBaseline: 'middle',
        cursor: 'pointer'
      }
    }, {
      type: 'text',
      attrs: {
        id: 'text-desc',
        text: node.label || node.data.label,
        x: 0,
        y: fontPosition,
        cursor: 'pointer',
        fontSize: fontSize,
        fill: fontColor,
        fontWeight: 'lighter',
        fontFamily: 'Courier New',
        textAlign: 'center',
        textBaseline: 'top'
      }
    }],
    state: {
      selected: {
        'circle-container': {
          stroke: primaryColor,
          // fill: '#000',
          animate: {
            attrs: {
              lineWidth: 6,
              shadowOffsetX: 0,
              shadowOffsetY: 0,
              shadowBlur: 2,
              shadowColor: '#fff',
              repeat: false
            },
            duration: 200,
            easing: 'easeCubic',
            callback: null,
            delay: 0
          }
        }
      },
      // 'highlight.light': {
      //     'circle-container': {
      //         stroke: primaryColor,
      //         fill: '#ddd',
      //     },
      // },
      'highlight.dark': {
        'circle-container': {
          fill: dark,
          stroke: dark
        },
        'node-icon': {
          fill: dark
        },
        'text-desc': {
          fill: dark
        }
      }
    }
  };
};

/**
 * https://github.com/misund/hex-to-rgba/blob/master/src/index.js
 */
var removeHash = function removeHash(hex) {
  return hex.charAt(0) === '#' ? hex.slice(1) : hex;
};

var parseHex = function parseHex(nakedHex) {
  var isShort = nakedHex.length === 3 || nakedHex.length === 4;
  var twoDigitHexR = isShort ? "".concat(nakedHex.slice(0, 1)).concat(nakedHex.slice(0, 1)) : nakedHex.slice(0, 2);
  var twoDigitHexG = isShort ? "".concat(nakedHex.slice(1, 2)).concat(nakedHex.slice(1, 2)) : nakedHex.slice(2, 4);
  var twoDigitHexB = isShort ? "".concat(nakedHex.slice(2, 3)).concat(nakedHex.slice(2, 3)) : nakedHex.slice(4, 6);
  var twoDigitHexA = (isShort ? "".concat(nakedHex.slice(3, 4)).concat(nakedHex.slice(3, 4)) : nakedHex.slice(6, 8)) || 'ff'; // const numericA = +((parseInt(a, 16) / 255).toFixed(2));

  return {
    r: twoDigitHexR,
    g: twoDigitHexG,
    b: twoDigitHexB,
    a: twoDigitHexA
  };
};

var hexToDecimal = function hexToDecimal(hex) {
  return parseInt(hex, 16);
};

var hexesToDecimals = function hexesToDecimals(_ref) {
  var r = _ref.r,
      g = _ref.g,
      b = _ref.b,
      a = _ref.a;
  return {
    r: hexToDecimal(r),
    g: hexToDecimal(g),
    b: hexToDecimal(b),
    a: +(hexToDecimal(a) / 255).toFixed(2)
  };
};

var isNumeric = function isNumeric(n) {
  return !isNaN(parseFloat(String(n))) && isFinite(Number(n));
}; // eslint-disable-line no-restricted-globals, max-len


var formatRgb = function formatRgb(decimalObject, parameterA) {
  var r = decimalObject.r,
      g = decimalObject.g,
      b = decimalObject.b,
      parsedA = decimalObject.a;
  var a = isNumeric(parameterA) ? parameterA : parsedA;
  return "rgba(".concat(r, ", ").concat(g, ", ").concat(b, ", ").concat(a, ")");
};
/**
 * Turns an old-fashioned css hex color value into a rgb color value.
 *
 * If you specify an alpha value, you'll get a rgba() value instead.
 *
 * @param The hex value to convert. ('123456'. '#123456', ''123', '#123')
 * @param An alpha value to apply. (optional) ('0.5', '0.25')
 * @return An rgb or rgba value. ('rgb(11, 22, 33)'. 'rgba(11, 22, 33, 0.5)')
 */


var hexToRgba = function hexToRgba(hex, a) {
  var hashlessHex = removeHash(hex);
  var hexObject = parseHex(hashlessHex);
  var decimalObject = hexesToDecimals(hexObject);
  return formatRgb(decimalObject, a);
};

/* eslint-disable no-underscore-dangle */

var reset$1 = function reset(shape, initStyle) {
  var lineWidth = initStyle.lineWidth,
      stroke = initStyle.stroke;
  shape.stopAnimate();
  shape.attr('lineWidth', lineWidth);
  shape.attr('stroke', stroke);
}; // eslint-disable-next-line


var cache = function cache(model) {
  if (!model.initStyle) {
    model.initStyle = model.style;
  }

  return model.initStyle;
};

var setEdgeState = (function (name, value, item) {
  var group = item.getContainer();
  var shape = group.get('children')[0]; // 顺序根据 draw 时确定

  var textShape = group.get('children')[1];
  var model = item.get('model');
  /** 设置缓存 */

  var initStyle = cache(model);
  /** 如果是false，则直接reset到初始状态 */

  if (!value || !name) {
    reset$1(shape, initStyle);

    if (textShape) {
      textShape.originFill = textShape.originFill || textShape._attrs.fillStyle;
      textShape.attr('fill', textShape.originFill);
    }

    return;
  }
  /** 状态设置 */


  var lineWidth = initStyle.lineWidth,
      stroke = initStyle.stroke;

  if (name === 'selected') {
    shape.attr('lineWidth', 5);
    shape.attr('stroke', '#1890FF');
    shape.animate({
      lineWidth: lineWidth + 3,
      repeat: false
    }, 200, 'easeCubic', null, 0);
  }

  if (name === 'highlight.light') {
    shape.attr('lineWidth', 3);
  }

  if (name === 'highlight.dark') {
    if (textShape) {
      textShape.originFill = textShape.originFill || textShape._attrs.fillStyle;
      textShape.attr('fill', '#ccc');
    }

    shape.attr('lineWidth', 1);
    shape.attr('stroke', hexToRgba(stroke, '0.1'));
  }
});

var RegisterSimplicityLineEdge = (function (G6) {
  G6.registerEdge('Simplicity', {
    // 设置状态
    setState: function setState(name, value, item) {
      setEdgeState(name, value, item);
    }
  }, 'line');
});

function normalizeColor(rgb) {
  if (Array.isArray(rgb)) {
    return {
      dark: "rgba(".concat(rgb.join(','), ", 0.7)"),
      normal: "rgba(".concat(rgb.join(','), ", 1)"),
      reflect: "rgba(".concat(rgb.join(','), ", 0.1)")
    };
  }

  if (typeof rgb === 'string') {
    return {
      dark: rgb,
      normal: rgb,
      reflect: rgb
    };
  }

  return rgb;
}

var GREY = normalizeColor([204, 204, 204]);
var EDGE_LINE_DEFAULT_COLOR = normalizeColor([105, 123, 140]);
var EDGE_LABEL_DEFAULT_COLOR = normalizeColor([59, 59, 59]);
var HIDDEN_LABEL_COLOR = normalizeColor([238, 238, 238]);
var HIDDEN_LINE_COLOR = normalizeColor([238, 238, 238]);
var PRIMARY_NODE_COLOR = normalizeColor([135, 59, 244]);
var DEFAULT_ICON_FONT_FAMILY = 'graphin';
var EnumNodeAndEdgeStatus;

(function (EnumNodeAndEdgeStatus) {
  EnumNodeAndEdgeStatus["NORMAL"] = "normal";
  EnumNodeAndEdgeStatus["SELECTED"] = "selected";
  EnumNodeAndEdgeStatus["LIGHT"] = "highlight.light";
  EnumNodeAndEdgeStatus["DARK"] = "highlight.dark";
  EnumNodeAndEdgeStatus["HOVERED"] = "hovered";
})(EnumNodeAndEdgeStatus || (EnumNodeAndEdgeStatus = {}));

var RegisterLineEdge = (function (g6) {
  g6.registerEdge('LineEdge', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style$line, _cfg$style2, _cfg$style2$line, _cfg$style3, _cfg$style3$line, _cfg$style4, _cfg$style4$label, _cfg$style5, _cfg$style5$label, _cfg$style6, _cfg$style7, _cfg$style8, _cfg$style8$line, _cfg$style9, _cfg$style9$line;

      var hasLabel = cfg.label;
      var startPoint = cfg.startPoint,
          endPoint = cfg.endPoint;
      var d = (((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : (_cfg$style$line = _cfg$style.line) === null || _cfg$style$line === void 0 ? void 0 : _cfg$style$line.width) || 1) + 1;
      var attrs = {
        path: [['M', startPoint.x, startPoint.y], ['L', endPoint.x, endPoint.y]]
      };
      var lineColor = ((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : (_cfg$style2$line = _cfg$style2.line) === null || _cfg$style2$line === void 0 ? void 0 : _cfg$style2$line.color) ? normalizeColor((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : (_cfg$style3$line = _cfg$style3.line) === null || _cfg$style3$line === void 0 ? void 0 : _cfg$style3$line.color) : EDGE_LINE_DEFAULT_COLOR;
      var labelColor = ((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : (_cfg$style4$label = _cfg$style4.label) === null || _cfg$style4$label === void 0 ? void 0 : _cfg$style4$label.color) ? normalizeColor((_cfg$style5 = cfg.style) === null || _cfg$style5 === void 0 ? void 0 : (_cfg$style5$label = _cfg$style5.label) === null || _cfg$style5$label === void 0 ? void 0 : _cfg$style5$label.color) : EDGE_LABEL_DEFAULT_COLOR;
      group.addShape('path', {
        attrs: _objectSpread2({
          id: 'selected'
        }, attrs, {
          lineWidth: 1,
          stroke: '#000',
          opacity: 0.05
        }),
        draggable: true,
        name: 'selected'
      });
      var key = group.addShape('path', {
        attrs: _objectSpread2({
          id: 'main'
        }, attrs, {
          lineAppendWidth: 4,
          stroke: ((_cfg$style6 = cfg.style) === null || _cfg$style6 === void 0 ? void 0 : _cfg$style6.dark) ? GREY.dark : lineColor.dark,
          lineWidth: ((_cfg$style7 = cfg.style) === null || _cfg$style7 === void 0 ? void 0 : _cfg$style7.dark) ? 1 : ((_cfg$style8 = cfg.style) === null || _cfg$style8 === void 0 ? void 0 : (_cfg$style8$line = _cfg$style8.line) === null || _cfg$style8$line === void 0 ? void 0 : _cfg$style8$line.width) || 1,
          lineDash: (_cfg$style9 = cfg.style) === null || _cfg$style9 === void 0 ? void 0 : (_cfg$style9$line = _cfg$style9.line) === null || _cfg$style9$line === void 0 ? void 0 : _cfg$style9$line.dash,
          endArrow: {
            d: -d / 2,
            path: "M 0,0 L ".concat(d, ",").concat(d / 2, " L ").concat(d, ",-").concat(d / 2, " Z")
          }
        }),
        draggable: true,
        name: 'main'
      });

      if (hasLabel) {
        var _cfg$style10, _cfg$style10$label, _cfg$style11, _cfg$style11$label, _cfg$style12;

        var label = group.addShape('text', {
          attrs: {
            id: 'label',
            x: 0,
            y: 0,
            fontSize: ((_cfg$style10 = cfg.style) === null || _cfg$style10 === void 0 ? void 0 : (_cfg$style10$label = _cfg$style10.label) === null || _cfg$style10$label === void 0 ? void 0 : _cfg$style10$label.size) || 12,
            text: cfg.label,
            textAlign: 'center',
            fontFamily: (_cfg$style11 = cfg.style) === null || _cfg$style11 === void 0 ? void 0 : (_cfg$style11$label = _cfg$style11.label) === null || _cfg$style11$label === void 0 ? void 0 : _cfg$style11$label.family,
            fill: ((_cfg$style12 = cfg.style) === null || _cfg$style12 === void 0 ? void 0 : _cfg$style12.dark) ? HIDDEN_LABEL_COLOR.normal : labelColor.dark
          },
          draggable: true,
          name: 'label'
        });
        label.rotate(endPoint.x - startPoint.x === 0 ? Math.PI / 2 : Math.atan((endPoint.y - startPoint.y) / (endPoint.x - startPoint.x)));
        label.translate((startPoint.x + endPoint.x) / 2, (startPoint.y + endPoint.y) / 2);
      }

      return key;
    },
    setState: function setState(name, value, edge) {
      var _data$style, _data$style$line, _data$style2, _data$style3, _data$style3$line, _data$style4, _data$style4$line, _data$style5, _data$style5$line, _data$style6, _data$style6$label, _data$style7, _data$style7$label, _data$style8, _data$style9;

      if (!name) return;
      var data = edge.get('model');
      var mainShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'main';
      });
      var selectedShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'selected';
      });
      var textShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'label';
      });
      var d = (((_data$style = data.style) === null || _data$style === void 0 ? void 0 : (_data$style$line = _data$style.line) === null || _data$style$line === void 0 ? void 0 : _data$style$line.width) || 1) + 1;
      var basicLineWidth = ((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.dark) ? 1 : ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : (_data$style3$line = _data$style3.line) === null || _data$style3$line === void 0 ? void 0 : _data$style3$line.width) || 1;
      var lineColor = ((_data$style4 = data.style) === null || _data$style4 === void 0 ? void 0 : (_data$style4$line = _data$style4.line) === null || _data$style4$line === void 0 ? void 0 : _data$style4$line.color) ? normalizeColor((_data$style5 = data.style) === null || _data$style5 === void 0 ? void 0 : (_data$style5$line = _data$style5.line) === null || _data$style5$line === void 0 ? void 0 : _data$style5$line.color) : EDGE_LINE_DEFAULT_COLOR;
      var labelColor = ((_data$style6 = data.style) === null || _data$style6 === void 0 ? void 0 : (_data$style6$label = _data$style6.label) === null || _data$style6$label === void 0 ? void 0 : _data$style6$label.color) ? normalizeColor((_data$style7 = data.style) === null || _data$style7 === void 0 ? void 0 : (_data$style7$label = _data$style7.label) === null || _data$style7$label === void 0 ? void 0 : _data$style7$label.color) : EDGE_LABEL_DEFAULT_COLOR;
      var targetAttrs = {
        main: {},
        selected: {},
        text: {}
      };
      targetAttrs.main = {
        stroke: ((_data$style8 = data.style) === null || _data$style8 === void 0 ? void 0 : _data$style8.dark) ? GREY.dark : lineColor.dark,
        lineWidth: basicLineWidth,
        endArrow: {
          d: -d / 2,
          path: "M 0,0 L ".concat(d, ",").concat(d / 2, " L ").concat(d, ",-").concat(d / 2, " Z")
        }
      };
      targetAttrs.selected = {
        lineWidth: 0
      };
      targetAttrs.text = {
        fill: ((_data$style9 = data.style) === null || _data$style9 === void 0 ? void 0 : _data$style9.dark) ? HIDDEN_LABEL_COLOR.normal : labelColor.dark
      };

      if (name === EnumNodeAndEdgeStatus.HOVERED && value) {
        var deltaD = d + 1;
        targetAttrs.main = {
          lineWidth: basicLineWidth + 1,
          endArrow: {
            d: -deltaD / 2,
            path: "M 0,0 L ".concat(deltaD, ",").concat(deltaD / 2, " L ").concat(deltaD, ",-").concat(deltaD / 2, " Z")
          }
        };
      }

      if (name === EnumNodeAndEdgeStatus.SELECTED && value || name === EnumNodeAndEdgeStatus.LIGHT && value) {
        var _deltaD = d + 1;

        targetAttrs.main = {
          lineWidth: basicLineWidth + 1,
          endArrow: {
            d: -_deltaD / 2,
            path: "M 0,0 L ".concat(_deltaD, ",").concat(_deltaD / 2, " L ").concat(_deltaD, ",-").concat(_deltaD / 2, " Z")
          }
        };
        targetAttrs.selected = {
          lineWidth: basicLineWidth + 10
        };
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.main = {
          stroke: GREY.dark,
          lineWidth: 1,
          endArrow: {
            d: -1,
            path: 'M 0,0 L 2,1 L 2,-1 Z'
          }
        };
        targetAttrs.text = {
          fill: '#8D93B0'
        };
      }

      mainShape.attr(targetAttrs.main);
      selectedShape.attr(targetAttrs.selected);
      if (textShape) textShape.attr(targetAttrs.text);
    }
  });
});

//   const pm = {
//     x: (p2.x + p1.x) / 2,
//     y: (p2.y + p1.y) / 2,
//   };
//   const dx = p2.x - p1.x;
//   const dy = p2.y - p1.y;
//   const y = pm.y - (dx * d) / Math.sqrt(dx ** 2 + dy ** 2) || 0;
//   const x = pm.x + (dy * d) / Math.sqrt(dx ** 2 + dy ** 2) || 0;
//   return {
//     x, y,
//   };
// }

function getPolyEdgeControlPoint(p1, p2, d) {
  var pm = {
    x: (p2.x + p1.x) / 2,
    y: (p2.y + p1.y) / 2
  };
  var dx = p2.x - p1.x;
  var dy = p2.y - p1.y;
  var y = pm.y - dx * d / Math.sqrt(Math.pow(dx, 2) + Math.pow(dy, 2)) || 0;
  var x = pm.x + dy * d / Math.sqrt(Math.pow(dx, 2) + Math.pow(dy, 2)) || 0;
  return {
    x: x,
    y: y
  };
} // eslint-disable-next-line @typescript-eslint/no-explicit-any


var RegisterPolyEdge = (function (g6) {
  g6.registerEdge('PolyEdge', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style$line, _cfg$poly, _cfg$style2, _cfg$style3, _cfg$style4, _cfg$style4$label, _cfg$style5, _cfg$style5$label, _cfg$style6, _cfg$style7, _cfg$style8, _cfg$style9;

      var hasLabel = cfg.label;
      var startPoint = cfg.startPoint,
          endPoint = cfg.endPoint;
      var d = (((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : (_cfg$style$line = _cfg$style.line) === null || _cfg$style$line === void 0 ? void 0 : _cfg$style$line.width) || 1) + 1;
      var points = [{
        id: cfg.source,
        point: startPoint
      }, {
        id: cfg.target,
        point: endPoint
      }].sort(function (a, b) {
        if (a.id < b.id) return -1;
        if (a.id > b.id) return 1;
        return 0;
      }).map(function (item) {
        return item.point;
      });
      var controlPoints = getPolyEdgeControlPoint(points[0], points[1], ((_cfg$poly = cfg.poly) === null || _cfg$poly === void 0 ? void 0 : _cfg$poly.distance) || 0);
      var attrs = {
        path: [['M', startPoint.x, startPoint.y], ['Q', controlPoints.x, controlPoints.y, endPoint.x, endPoint.y]]
      };
      var lineColor = ((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : _cfg$style2.line.color) ? normalizeColor((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : _cfg$style3.line.color) : EDGE_LINE_DEFAULT_COLOR;
      var labelColor = ((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : (_cfg$style4$label = _cfg$style4.label) === null || _cfg$style4$label === void 0 ? void 0 : _cfg$style4$label.color) ? normalizeColor((_cfg$style5 = cfg.style) === null || _cfg$style5 === void 0 ? void 0 : (_cfg$style5$label = _cfg$style5.label) === null || _cfg$style5$label === void 0 ? void 0 : _cfg$style5$label.color) : EDGE_LABEL_DEFAULT_COLOR;
      group.addShape('path', {
        attrs: _objectSpread2({
          id: 'selected'
        }, attrs, {
          lineWidth: 1,
          stroke: '#000',
          opacity: 0.05
        })
      });
      var key = group.addShape('path', {
        attrs: _objectSpread2({
          id: 'main'
        }, attrs, {
          lineAppendWidth: 4,
          stroke: ((_cfg$style6 = cfg.style) === null || _cfg$style6 === void 0 ? void 0 : _cfg$style6.dark) ? GREY.dark : lineColor.dark,
          lineWidth: ((_cfg$style7 = cfg.style) === null || _cfg$style7 === void 0 ? void 0 : _cfg$style7.dark) ? 1 : ((_cfg$style8 = cfg.style) === null || _cfg$style8 === void 0 ? void 0 : _cfg$style8.line.width) || 1,
          lineDash: (_cfg$style9 = cfg.style) === null || _cfg$style9 === void 0 ? void 0 : _cfg$style9.line.dash,
          endArrow: {
            d: -d / 2,
            path: "M 0,0 L ".concat(d, ",").concat(d / 2, " L ").concat(d, ",-").concat(d / 2, " Z")
          }
        })
      });

      if (hasLabel) {
        var _cfg$style10, _cfg$style10$label, _cfg$style11, _cfg$style11$label, _cfg$style12;

        var label = group.addShape('text', {
          attrs: {
            id: 'label',
            x: 0,
            y: 0,
            fontSize: ((_cfg$style10 = cfg.style) === null || _cfg$style10 === void 0 ? void 0 : (_cfg$style10$label = _cfg$style10.label) === null || _cfg$style10$label === void 0 ? void 0 : _cfg$style10$label.size) || 12,
            text: cfg.label,
            textAlign: 'center',
            fontFamily: (_cfg$style11 = cfg.style) === null || _cfg$style11 === void 0 ? void 0 : (_cfg$style11$label = _cfg$style11.label) === null || _cfg$style11$label === void 0 ? void 0 : _cfg$style11$label.family,
            fill: ((_cfg$style12 = cfg.style) === null || _cfg$style12 === void 0 ? void 0 : _cfg$style12.dark) ? HIDDEN_LABEL_COLOR.normal : labelColor.dark
          }
        });
        label.rotate(endPoint.x - startPoint.x === 0 ? Math.PI / 2 : Math.atan((endPoint.y - startPoint.y) / (endPoint.x - startPoint.x)));
        var mid = [(startPoint.x + endPoint.x) / 2, (startPoint.y + endPoint.y) / 2]; // TODO: 这里label坐标计算有问题，需要调整算法, 今天搞不动了，明天再处理

        label.translate((controlPoints.x + mid[0]) / 2, (controlPoints.y + mid[1]) / 2);
      }

      return key;
    },
    setState: function setState(name, value, edge) {
      var _data$style, _data$style$line, _data$style2, _data$style3, _data$style4, _data$style5, _data$style6, _data$style6$label, _data$style7, _data$style7$label, _data$style8, _data$style9;

      if (!name) return;
      var data = edge.get('model');
      var mainShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'main';
      });
      var selectedShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'selected';
      });
      var textShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'label';
      });
      var d = (((_data$style = data.style) === null || _data$style === void 0 ? void 0 : (_data$style$line = _data$style.line) === null || _data$style$line === void 0 ? void 0 : _data$style$line.width) || 1) + 1;
      var basicLineWidth = ((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.dark) ? 1 : ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : _data$style3.line.width) || 1;
      var lineColor = ((_data$style4 = data.style) === null || _data$style4 === void 0 ? void 0 : _data$style4.line.color) ? normalizeColor((_data$style5 = data.style) === null || _data$style5 === void 0 ? void 0 : _data$style5.line.color) : EDGE_LINE_DEFAULT_COLOR;
      var labelColor = ((_data$style6 = data.style) === null || _data$style6 === void 0 ? void 0 : (_data$style6$label = _data$style6.label) === null || _data$style6$label === void 0 ? void 0 : _data$style6$label.color) ? normalizeColor((_data$style7 = data.style) === null || _data$style7 === void 0 ? void 0 : (_data$style7$label = _data$style7.label) === null || _data$style7$label === void 0 ? void 0 : _data$style7$label.color) : EDGE_LABEL_DEFAULT_COLOR;
      var targetAttrs = {
        main: {},
        selected: {},
        text: {}
      };
      targetAttrs.main = {
        stroke: ((_data$style8 = data.style) === null || _data$style8 === void 0 ? void 0 : _data$style8.dark) ? GREY.dark : lineColor.dark,
        lineWidth: basicLineWidth,
        endArrow: {
          d: -d / 2,
          path: "M 0,0 L ".concat(d, ",").concat(d / 2, " L ").concat(d, ",-").concat(d / 2, " Z")
        }
      };
      targetAttrs.selected = {
        lineWidth: 0
      };
      targetAttrs.text = {
        fill: ((_data$style9 = data.style) === null || _data$style9 === void 0 ? void 0 : _data$style9.dark) ? HIDDEN_LABEL_COLOR.normal : labelColor.dark
      };

      if (name === EnumNodeAndEdgeStatus.HOVERED && value) {
        var deltaD = d + 1;
        targetAttrs.main = {
          lineWidth: basicLineWidth + 1,
          endArrow: {
            d: -deltaD / 2,
            path: "M 0,0 L ".concat(deltaD, ",").concat(deltaD / 2, " L ").concat(deltaD, ",-").concat(deltaD / 2, " Z")
          }
        };
      }

      if (name === EnumNodeAndEdgeStatus.SELECTED && value || name === EnumNodeAndEdgeStatus.LIGHT && value) {
        var _deltaD = d + 1;

        targetAttrs.main = {
          lineWidth: basicLineWidth + 1,
          endArrow: {
            d: -_deltaD / 2,
            path: "M 0,0 L ".concat(_deltaD, ",").concat(_deltaD / 2, " L ").concat(_deltaD, ",-").concat(_deltaD / 2, " Z")
          }
        };
        targetAttrs.selected = {
          lineWidth: basicLineWidth + 10
        };
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.main = {
          stroke: GREY.dark,
          lineWidth: 1,
          endArrow: {
            d: -1,
            path: 'M 0,0 L 2,1 L 2,-1 Z'
          }
        };
        targetAttrs.text = {
          fill: '#8D93B0'
        };
      }

      mainShape.attr(targetAttrs.main);
      selectedShape.attr(targetAttrs.selected);
      if (textShape) textShape.attr(targetAttrs.text);
    }
  });
});

var PADDING = 2;
var RADIO = 0.75; // eslint-disable-next-line @typescript-eslint/no-explicit-any

var RegisterLoopEdge = (function (g6) {
  g6.registerEdge('LoopEdge', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style$line, _target$style, _target$style2, _cfg$style2, _cfg$style2$line, _cfg$style3, _cfg$style3$line, _cfg$style4, _cfg$style4$label, _cfg$style5, _cfg$style5$label, _cfg$style6, _cfg$style7, _cfg$style8, _cfg$style8$line, _cfg$style9;

      var hasLabel = cfg.label;
      var startPoint = cfg.startPoint,
          endPoint = cfg.endPoint;
      var d = (((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : (_cfg$style$line = _cfg$style.line) === null || _cfg$style$line === void 0 ? void 0 : _cfg$style$line.width) || 1) + 1;
      var target = cfg.sourceNode.get('model');
      var size = (((_target$style = target.style) === null || _target$style === void 0 ? void 0 : _target$style.nodeSize) || 0) > 28 ? (_target$style2 = target.style) === null || _target$style2 === void 0 ? void 0 : _target$style2.nodeSize : 28;
      size = size * RADIO;
      var attrs = {
        path: [['M', startPoint.x - size / 2 - PADDING, startPoint.y - Math.sqrt(3) / 2 * size - PADDING], ['A', size, size, 0, 1, 1, startPoint.x + size / 2 + PADDING, startPoint.y - Math.sqrt(3) / 2 * size - PADDING]]
      };
      var lineColor = ((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : (_cfg$style2$line = _cfg$style2.line) === null || _cfg$style2$line === void 0 ? void 0 : _cfg$style2$line.color) ? normalizeColor((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : (_cfg$style3$line = _cfg$style3.line) === null || _cfg$style3$line === void 0 ? void 0 : _cfg$style3$line.color) : EDGE_LINE_DEFAULT_COLOR;
      var labelColor = ((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : (_cfg$style4$label = _cfg$style4.label) === null || _cfg$style4$label === void 0 ? void 0 : _cfg$style4$label.color) ? normalizeColor((_cfg$style5 = cfg.style) === null || _cfg$style5 === void 0 ? void 0 : (_cfg$style5$label = _cfg$style5.label) === null || _cfg$style5$label === void 0 ? void 0 : _cfg$style5$label.color) : EDGE_LABEL_DEFAULT_COLOR;
      group.addShape('path', {
        attrs: _objectSpread2({
          id: 'selected'
        }, attrs, {
          lineWidth: 1,
          stroke: '#000',
          opacity: 0.05
        }),
        draggable: true,
        name: 'selected'
      });
      var key = group.addShape('path', {
        attrs: _objectSpread2({
          id: 'main'
        }, attrs, {
          lineAppendWidth: 4,
          stroke: ((_cfg$style6 = cfg.style) === null || _cfg$style6 === void 0 ? void 0 : _cfg$style6.dark) ? GREY.dark : lineColor.dark,
          lineWidth: ((_cfg$style7 = cfg.style) === null || _cfg$style7 === void 0 ? void 0 : _cfg$style7.dark) ? 1 : ((_cfg$style8 = cfg.style) === null || _cfg$style8 === void 0 ? void 0 : (_cfg$style8$line = _cfg$style8.line) === null || _cfg$style8$line === void 0 ? void 0 : _cfg$style8$line.width) || 1,
          lineDash: (_cfg$style9 = cfg.style) === null || _cfg$style9 === void 0 ? void 0 : _cfg$style9.line.dash,
          endArrow: {
            d: -d / 2,
            path: "M 0,0 L ".concat(d, ",").concat(d / 2, " L ").concat(d, ",-").concat(d / 2, " Z")
          },
          draggable: true,
          name: 'path'
        })
      });

      if (hasLabel) {
        var _cfg$style10, _cfg$style10$label, _cfg$style11, _cfg$style11$label, _cfg$style12;

        var label = group.addShape('text', {
          attrs: {
            id: 'label',
            x: 0,
            y: 0,
            fontSize: ((_cfg$style10 = cfg.style) === null || _cfg$style10 === void 0 ? void 0 : (_cfg$style10$label = _cfg$style10.label) === null || _cfg$style10$label === void 0 ? void 0 : _cfg$style10$label.size) || 10,
            text: cfg.label,
            textAlign: 'center',
            fontFamily: (_cfg$style11 = cfg.style) === null || _cfg$style11 === void 0 ? void 0 : (_cfg$style11$label = _cfg$style11.label) === null || _cfg$style11$label === void 0 ? void 0 : _cfg$style11$label.family,
            fill: ((_cfg$style12 = cfg.style) === null || _cfg$style12 === void 0 ? void 0 : _cfg$style12.dark) ? HIDDEN_LABEL_COLOR.normal : labelColor.dark
          },
          draggable: true,
          name: 'label'
        });
        label.rotate(endPoint.x - startPoint.x === 0 ? Math.PI / 2 : Math.atan((endPoint.y - startPoint.y) / (endPoint.x - startPoint.x)));
        label.translate((startPoint.x + endPoint.x) / 2, (startPoint.y + endPoint.y) / 2);
        label.translate(-5, -5);
      }

      return key;
    },
    setState: function setState(name, value, edge) {
      var _data$style, _data$style$line, _data$style2, _data$style3, _data$style3$line, _data$style4, _data$style4$line, _data$style5, _data$style5$line, _data$style6, _data$style6$label, _data$style7, _data$style7$label, _data$style8, _data$style9;

      if (!name) return;
      var data = edge.get('model');
      var mainShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'main';
      });
      var selectedShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'selected';
      });
      var textShape = edge.getContainer().get('children').find(function (item) {
        return item.attr().id === 'label';
      });
      var d = (((_data$style = data.style) === null || _data$style === void 0 ? void 0 : (_data$style$line = _data$style.line) === null || _data$style$line === void 0 ? void 0 : _data$style$line.width) || 1) + 1;
      var basicLineWidth = ((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.dark) ? 1 : ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : (_data$style3$line = _data$style3.line) === null || _data$style3$line === void 0 ? void 0 : _data$style3$line.width) || 1;
      var lineColor = ((_data$style4 = data.style) === null || _data$style4 === void 0 ? void 0 : (_data$style4$line = _data$style4.line) === null || _data$style4$line === void 0 ? void 0 : _data$style4$line.color) ? normalizeColor((_data$style5 = data.style) === null || _data$style5 === void 0 ? void 0 : (_data$style5$line = _data$style5.line) === null || _data$style5$line === void 0 ? void 0 : _data$style5$line.color) : EDGE_LINE_DEFAULT_COLOR;
      var labelColor = ((_data$style6 = data.style) === null || _data$style6 === void 0 ? void 0 : (_data$style6$label = _data$style6.label) === null || _data$style6$label === void 0 ? void 0 : _data$style6$label.color) ? normalizeColor((_data$style7 = data.style) === null || _data$style7 === void 0 ? void 0 : (_data$style7$label = _data$style7.label) === null || _data$style7$label === void 0 ? void 0 : _data$style7$label.color) : EDGE_LABEL_DEFAULT_COLOR;
      var targetAttrs = {
        main: {},
        selected: {},
        text: {}
      };
      targetAttrs.main = {
        stroke: ((_data$style8 = data.style) === null || _data$style8 === void 0 ? void 0 : _data$style8.dark) ? GREY.dark : lineColor.dark,
        lineWidth: basicLineWidth,
        endArrow: {
          d: -d / 2,
          path: "M 0,0 L ".concat(d, ",").concat(d / 2, " L ").concat(d, ",-").concat(d / 2, " Z")
        }
      };
      targetAttrs.selected = {
        lineWidth: 0
      };
      targetAttrs.text = {
        fill: ((_data$style9 = data.style) === null || _data$style9 === void 0 ? void 0 : _data$style9.dark) ? HIDDEN_LABEL_COLOR.normal : labelColor.dark
      };

      if (name === EnumNodeAndEdgeStatus.HOVERED && value) {
        var deltaD = d + 1;
        targetAttrs.main = {
          lineWidth: basicLineWidth + 1,
          endArrow: {
            d: -deltaD / 2,
            path: "M 0,0 L ".concat(deltaD, ",").concat(deltaD / 2, " L ").concat(deltaD, ",-").concat(deltaD / 2, " Z")
          }
        };
      }

      if (name === EnumNodeAndEdgeStatus.SELECTED && value || name === EnumNodeAndEdgeStatus.LIGHT && value) {
        var _deltaD = d + 1;

        targetAttrs.main = {
          lineWidth: basicLineWidth + 1,
          endArrow: {
            d: -_deltaD / 2,
            path: "M 0,0 L ".concat(_deltaD, ",").concat(_deltaD / 2, " L ").concat(_deltaD, ",-").concat(_deltaD / 2, " Z")
          }
        };
        targetAttrs.selected = {
          lineWidth: basicLineWidth + 10
        };
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.main = {
          stroke: GREY.dark,
          lineWidth: 1,
          endArrow: {
            d: -1,
            path: 'M 0,0 L 2,1 L 2,-1 Z'
          }
        };
        targetAttrs.text = {
          fill: '#8D93B0'
        };
      }

      mainShape.attr(targetAttrs.main);
      selectedShape.attr(targetAttrs.selected);
      if (textShape) textShape.attr(targetAttrs.text);
    }
  }, 'single-edge');
});

var RegisterCircleNode = (function (g6) {
  g6.registerNode('CircleNode', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style2, _cfg$style3, _cfg$style4, _cfg$style5, _cfg$style6, _cfg$style7, _cfg$style8, _cfg$style9, _cfg$style11, _cfg$style12;

      var hasLabel = cfg.label;
      var innerNodeSize = ((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : _cfg$style.nodeSize) || 48;
      var innerSize = innerNodeSize > 28 ? innerNodeSize : 28;
      var outerSize = innerSize + 4;
      var color = ((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : _cfg$style2.dark) ? GREY : normalizeColor(((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : _cfg$style3.primaryColor) || PRIMARY_NODE_COLOR);
      var keyShape = group.addShape('circle', {
        attrs: {
          id: 'circle-floor',
          x: 0,
          y: 0,
          r: outerSize / 2
        },
        draggable: true,
        name: 'circle-floor'
      });
      group.addShape('circle', {
        attrs: {
          id: 'circle-selected',
          x: 0,
          y: 0,
          r: 0,
          fill: '#000',
          opacity: 0.05
        },
        draggable: true,
        name: 'circle-selected'
      });
      group.addShape('circle', {
        attrs: {
          id: 'circle-border',
          x: 0,
          y: 0,
          r: outerSize / 2,
          stroke: ((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : _cfg$style4.dark) ? GREY.normal : color.normal,
          lineWidth: 2
        },
        name: 'circle-border',
        draggable: true
      });
      var inner = group.addGroup({
        attrs: {
          id: 'circle-inner-group'
        },
        draggable: true,
        name: 'circle-inner-group'
      }, {});
      inner.addShape('circle', {
        attrs: {
          id: 'circle-inner',
          x: 0,
          y: 0,
          r: innerSize / 2,
          fill: ((_cfg$style5 = cfg.style) === null || _cfg$style5 === void 0 ? void 0 : _cfg$style5.dark) ? GREY.dark : color.dark
        },
        draggable: true,
        name: 'circle-inner'
      });
      inner.addShape('text', {
        attrs: {
          id: 'circle-icon',
          x: 0,
          y: 0,
          text: iconFont(((_cfg$style6 = cfg.style) === null || _cfg$style6 === void 0 ? void 0 : _cfg$style6.icon) || cfg.data.type || '', ((_cfg$style7 = cfg.style) === null || _cfg$style7 === void 0 ? void 0 : _cfg$style7.fontFamily) || DEFAULT_ICON_FONT_FAMILY),
          fontSize: 20,
          textAlign: 'center',
          textBaseline: 'middle',
          fontFamily: ((_cfg$style8 = cfg.style) === null || _cfg$style8 === void 0 ? void 0 : _cfg$style8.fontFamily) || DEFAULT_ICON_FONT_FAMILY,
          fill: ((_cfg$style9 = cfg.style) === null || _cfg$style9 === void 0 ? void 0 : _cfg$style9.dark) ? '#8D93B0' : '#FFFFFF'
        },
        draggable: true,
        name: 'circle-icon'
      });

      if (hasLabel) {
        var _cfg$style10;

        group.addShape('text', {
          attrs: {
            id: 'circle-label',
            x: 0,
            y: outerSize / 2 + 14,
            fontSize: 12,
            text: cfg.label,
            textAlign: 'center',
            fill: ((_cfg$style10 = cfg.style) === null || _cfg$style10 === void 0 ? void 0 : _cfg$style10.dark) ? '#8D93B0' : '#3B3B3B'
          },
          draggable: true,
          name: 'circle-label'
        });
      }

      if (!cfg.badge) return keyShape;
      var children = group.addGroup({
        attrs: {
          id: 'circle-children-group'
        },
        draggable: true,
        name: 'circle-children-group'
      }, {});
      children.addShape('circle', {
        attrs: {
          id: 'circle-children',
          x: outerSize / 2 - 9,
          y: -outerSize / 2 + 9,
          r: 9,
          fill: ((_cfg$style11 = cfg.style) === null || _cfg$style11 === void 0 ? void 0 : _cfg$style11.dark) ? '#1E202D' : color.dark
        },
        draggable: true,
        name: 'circle-children'
      });
      children.addShape('text', {
        attrs: {
          id: 'circle-children-icon',
          x: outerSize / 2 - 9,
          y: -outerSize / 2 + 9,
          text: cfg.badge,
          fontSize: 10,
          textAlign: 'center',
          textBaseline: 'middle',
          fill: ((_cfg$style12 = cfg.style) === null || _cfg$style12 === void 0 ? void 0 : _cfg$style12.dark) ? '#8D93B0' : '#FFFFFF'
        },
        draggable: true,
        name: 'circle-children-icon'
      });
      return keyShape;
    },
    setState: function setState(name, value, node) {
      var _data$style, _data$style2, _data$style3, _data$style4, _data$style5, _data$style6;

      if (!name) return;
      var data = node.get('model');
      var container = node.getContainer(); // const circleFloor = container.get('children').find(node => node.attr().id === 'circle-floor');

      var circleBorder = container.get('children').find(function (item) {
        return item.attr().id === 'circle-border';
      });
      var circleSelected = container.get('children').find(function (item) {
        return item.attr().id === 'circle-selected';
      });
      var circleInnerGroup = container.get('children').find(function (item) {
        return item.attr().id === 'circle-inner-group';
      });
      var circleInner = circleInnerGroup.get('children').find(function (item) {
        return item.attr().id === 'circle-inner';
      });
      var circleIcon = circleInnerGroup.get('children').find(function (item) {
        return item.attr().id === 'circle-icon';
      });
      var circleLabel = container.get('children').find(function (item) {
        return item.attr().id === 'circle-label';
      });
      var circleChildrenGroup = container.get('children').find(function (item) {
        return item.attr().id === 'circle-children-group';
      });
      var circleChildren = circleChildrenGroup === null || circleChildrenGroup === void 0 ? void 0 : circleChildrenGroup.get('children').find(function (item) {
        return item.attr().id === 'circle-children';
      });
      var circleChildrenIcon = circleChildrenGroup === null || circleChildrenGroup === void 0 ? void 0 : circleChildrenGroup.get('children').find(function (item) {
        return item.attr().id === 'circle-children-icon';
      });
      var color = ((_data$style = data.style) === null || _data$style === void 0 ? void 0 : _data$style.dark) ? GREY : normalizeColor(((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var innerNodeSize = ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : _data$style3.nodeSize) || 48;
      var innerSize = innerNodeSize > 28 ? innerNodeSize : 28;
      var outerSize = innerSize + 4;
      var targetAttrs = {
        border: {
          stroke: color.normal,
          lineWidth: 2
        },
        selected: {
          r: 0
        },
        inner: {
          fill: color.dark
        },
        icon: {
          fill: ((_data$style4 = data.style) === null || _data$style4 === void 0 ? void 0 : _data$style4.dark) ? '#8D93B0' : '#FFFFFF'
        },
        label: {
          fill: ((_data$style5 = data.style) === null || _data$style5 === void 0 ? void 0 : _data$style5.dark) ? '#8D93B0' : '#3B3B3B'
        },
        children: {
          fill: color.normal
        },
        childrenIcon: {
          fill: ((_data$style6 = data.style) === null || _data$style6 === void 0 ? void 0 : _data$style6.dark) ? '#8D93B0' : '#FFFFFF'
        }
      };

      if (name === EnumNodeAndEdgeStatus.SELECTED && value) {
        targetAttrs.border.lineWidth = 5;
        targetAttrs.selected.r = outerSize / 2 + 10;
      }

      if (name === EnumNodeAndEdgeStatus.LIGHT && value) {
        targetAttrs.selected.r = outerSize / 2 + 10;
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.border.stroke = GREY.dark;
        targetAttrs.inner.fill = GREY.dark;
        targetAttrs.icon.fill = '#8D93B0';
        targetAttrs.label.fill = '#8D93B0';
        targetAttrs.children.fill = GREY.normal;
        targetAttrs.childrenIcon.fill = '#8D93B0';
      }

      circleBorder.attr(targetAttrs.border);
      circleSelected.attr(targetAttrs.selected);
      circleInner.attr(targetAttrs.inner);
      circleIcon.attr(targetAttrs.icon);
      if (circleLabel) circleLabel.attr(targetAttrs.label);
      if (circleChildren) circleChildren.attr(targetAttrs.children);
      if (circleChildrenIcon) circleChildrenIcon.attr(targetAttrs.childrenIcon);
    }
  });
});

var RegisterRectNode = (function (g6) {
  g6.registerNode('RectNode', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style2, _cfg$style3, _cfg$style4, _cfg$style5, _cfg$style6, _cfg$style7, _cfg$style9;

      var hasLabel = cfg.label;
      var innerNodeSize = ((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : _cfg$style.nodeSize) || 48;
      var innerSize = innerNodeSize > 28 ? innerNodeSize : 28;
      var outerSize = innerSize + 4;
      var color = ((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : _cfg$style2.dark) ? GREY : normalizeColor(((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : _cfg$style3.primaryColor) || PRIMARY_NODE_COLOR);
      var keyShape = group.addShape('rect', {
        attrs: {
          id: 'rect-floor',
          x: 0,
          y: 0,
          width: outerSize,
          height: outerSize
        },
        draggable: true,
        name: 'rect-floor'
      });
      group.addShape('rect', {
        attrs: {
          id: 'rect-border',
          x: 0,
          y: 0,
          width: outerSize,
          height: outerSize,
          stroke: color.normal,
          lineWidth: 2
        },
        draggable: true,
        name: 'rect-border'
      });
      group.addShape('rect', {
        attrs: {
          id: 'rect-selected',
          x: -5,
          y: -5,
          width: 0,
          height: 0,
          fill: '#000',
          opacity: 0.15
        },
        draggable: true,
        name: 'rect-selected'
      });
      var inner = group.addGroup({
        attrs: {
          id: 'rect-inner-group'
        },
        draggable: true,
        name: 'rect-inner-group'
      }, {});
      inner.addShape('rect', {
        attrs: {
          id: 'rect-inner',
          x: 0,
          y: 0,
          width: innerSize,
          height: innerSize,
          fill: color.dark
        },
        draggable: true,
        name: 'rect-inner'
      });
      inner.addShape('text', {
        attrs: {
          id: 'rect-icon',
          x: innerSize / 2,
          y: innerSize / 2,
          text: iconFont(((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : _cfg$style4.icon) || cfg.data.type || '', ((_cfg$style5 = cfg.style) === null || _cfg$style5 === void 0 ? void 0 : _cfg$style5.fontFamily) || DEFAULT_ICON_FONT_FAMILY),
          fontSize: 20,
          textAlign: 'center',
          textBaseline: 'middle',
          fontFamily: ((_cfg$style6 = cfg.style) === null || _cfg$style6 === void 0 ? void 0 : _cfg$style6.fontFamily) || DEFAULT_ICON_FONT_FAMILY,
          fill: ((_cfg$style7 = cfg.style) === null || _cfg$style7 === void 0 ? void 0 : _cfg$style7.dark) ? '#8D93B0' : '#FFFFFF'
        },
        draggable: true,
        name: 'rect-icon'
      });
      inner.translate((outerSize - innerSize) / 2, (outerSize - innerSize) / 2);

      if (hasLabel) {
        var _cfg$style8;

        group.addShape('text', {
          attrs: {
            id: 'rect-label',
            x: outerSize / 2,
            y: outerSize + 14,
            fontSize: 12,
            text: cfg.label,
            textAlign: 'center',
            fill: ((_cfg$style8 = cfg.style) === null || _cfg$style8 === void 0 ? void 0 : _cfg$style8.dark) ? '#8D93B0' : '#3B3B3B'
          },
          draggable: true,
          name: 'rect-label'
        });
      }

      if (!cfg.badge) return keyShape;
      var children = group.addGroup({
        attrs: {
          id: 'rect-children-group'
        },
        draggable: true,
        name: 'rect-children-group'
      }, {});
      children.addShape('rect', {
        attrs: {
          id: 'rect-children',
          x: 0,
          y: 0,
          width: 12,
          height: 12,
          fill: color.normal
        },
        draggable: true,
        name: 'rect-children'
      });
      children.addShape('text', {
        attrs: {
          id: 'rect-children-icon',
          x: 12 / 2,
          y: 12 / 2,
          text: cfg.badge,
          fontSize: 10,
          textAlign: 'center',
          textBaseline: 'middle',
          fill: ((_cfg$style9 = cfg.style) === null || _cfg$style9 === void 0 ? void 0 : _cfg$style9.dark) ? '#8D93B0' : '#FFFFFF'
        },
        draggable: true,
        name: 'rect-children-icon'
      });
      children.translate(outerSize - 12, 0);
      return keyShape;
    },
    setState: function setState(name, value, node) {
      var _data$style, _data$style2, _data$style3, _data$style4, _data$style5, _data$style6;

      if (!name) return;
      var data = node.get('model');
      var container = node.getContainer();
      var rectBorder = container.get('children').find(function (item) {
        return item.attr().id === 'rect-border';
      });
      var rectSelected = container.get('children').find(function (item) {
        return item.attr().id === 'rect-selected';
      });
      var rectInnerGroup = container.get('children').find(function (item) {
        return item.attr().id === 'rect-inner-group';
      });
      var rectInner = rectInnerGroup.get('children').find(function (item) {
        return item.attr().id === 'rect-inner';
      });
      var rectIcon = rectInnerGroup.get('children').find(function (item) {
        return item.attr().id === 'rect-icon';
      });
      var rectLabel = container.get('children').find(function (item) {
        return item.attr().id === 'rect-label';
      });
      var rectChildrenGroup = container.get('children').find(function (item) {
        return item.attr().id === 'rect-children-group';
      });
      var rectChildren = rectChildrenGroup === null || rectChildrenGroup === void 0 ? void 0 : rectChildrenGroup.get('children').find(function (item) {
        return item.attr().id === 'rect-children';
      });
      var rectChildrenIcon = rectChildrenGroup === null || rectChildrenGroup === void 0 ? void 0 : rectChildrenGroup.get('children').find(function (item) {
        return item.attr().id === 'rect-children-icon';
      });
      var color = ((_data$style = data.style) === null || _data$style === void 0 ? void 0 : _data$style.dark) ? GREY : normalizeColor(((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var innerNodeSize = ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : _data$style3.nodeSize) || 48;
      var innerSize = innerNodeSize > 28 ? innerNodeSize : 28;
      var outerSize = innerSize + 4;
      var targetAttrs = {
        border: {
          stroke: color.normal,
          lineWidth: 2
        },
        selected: {
          width: 0,
          height: 0
        },
        inner: {
          fill: color.dark
        },
        icon: {
          fill: ((_data$style4 = data.style) === null || _data$style4 === void 0 ? void 0 : _data$style4.dark) ? '#8D93B0' : '#FFFFFF'
        },
        label: {
          fill: ((_data$style5 = data.style) === null || _data$style5 === void 0 ? void 0 : _data$style5.dark) ? '#8D93B0' : '#3B3B3B'
        },
        children: {
          fill: color.normal
        },
        childrenIcon: {
          fill: ((_data$style6 = data.style) === null || _data$style6 === void 0 ? void 0 : _data$style6.dark) ? '#8D93B0' : '#FFFFFF'
        }
      };

      if (name === EnumNodeAndEdgeStatus.SELECTED && value) {
        targetAttrs.border.lineWidth = 5;
        targetAttrs.selected.width = outerSize + 10;
        targetAttrs.selected.height = outerSize + 10;
      }

      if (name === EnumNodeAndEdgeStatus.LIGHT && value) {
        targetAttrs.selected.width = outerSize + 10;
        targetAttrs.selected.height = outerSize + 10;
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.border.stroke = GREY.dark;
        targetAttrs.inner.fill = GREY.dark;
        targetAttrs.icon.fill = '#8D93B0';
        targetAttrs.label.fill = '#8D93B0';
        targetAttrs.children.fill = GREY.normal;
        targetAttrs.childrenIcon.fill = '#8D93B0';
      }

      rectBorder.attr(targetAttrs.border);
      rectSelected.attr(targetAttrs.selected);
      rectInner.attr(targetAttrs.inner);
      rectIcon.attr(targetAttrs.icon);
      if (rectLabel) rectLabel.attr(targetAttrs.label);
      if (rectChildren) rectChildren.attr(targetAttrs.children);
      if (rectChildrenIcon) rectChildrenIcon.attr(targetAttrs.childrenIcon);
    }
  });
});

function makeHexagon(border) {
  var height = border / 2 + border * Math.sqrt(5) / 4;
  return [[border / 2, 0], [border, border / 4], [border, height - border / 4], [border / 2, height], [0, height - border / 4], [0, border / 4]];
} // eslint-disable-next-line @typescript-eslint/no-explicit-any


var RegisterHexagonNode = (function (g6) {
  g6.registerNode('HexagonNode', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style2, _cfg$style3, _cfg$style4, _cfg$style5, _cfg$style6, _cfg$style7, _cfg$style8, _cfg$style9, _cfg$style11, _cfg$style12;

      var hasLabel = cfg.label;
      var innerNodeSize = ((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : _cfg$style.nodeSize) || 48;
      var innerSize = innerNodeSize > 28 ? innerNodeSize : 28;
      var outerSize = innerSize + 4;
      var color = ((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : _cfg$style2.dark) ? GREY : normalizeColor(((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : _cfg$style3.primaryColor) || PRIMARY_NODE_COLOR);
      var keyShape = group.addShape('polygon', {
        attrs: {
          id: 'hexagon-floor',
          points: makeHexagon(outerSize)
        },
        draggable: true,
        name: 'hexagon-floor'
      });
      group.addShape('polygon', {
        attrs: {
          id: 'hexagon-border',
          points: makeHexagon(outerSize),
          stroke: ((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : _cfg$style4.dark) ? '#1E202D' : color.normal,
          lineWidth: 2
        },
        draggable: true,
        name: 'hexagon-border'
      });
      var selected = group.addShape('polygon', {
        attrs: {
          id: 'hexagon-selected',
          points: [],
          fill: '#FFF',
          opacity: 0.15
        },
        draggable: true,
        name: 'hexagon-selected'
      });
      selected.translate(-5, -5);
      var inner = group.addGroup({
        attrs: {
          id: 'hexagon-inner-group'
        },
        draggable: true,
        name: 'hexagon-inner-group'
      }, {});
      inner.addShape('polygon', {
        attrs: {
          id: 'hexagon-inner',
          points: makeHexagon(innerSize),
          fill: ((_cfg$style5 = cfg.style) === null || _cfg$style5 === void 0 ? void 0 : _cfg$style5.dark) ? '#1E202D' : color.dark
        },
        draggable: true,
        name: 'hexagon-inner'
      });
      inner.translate((outerSize - innerSize) / 2, (outerSize - innerSize) / 2);
      inner.addShape('text', {
        attrs: {
          id: 'hexagon-icon',
          x: innerSize / 2,
          y: innerSize / 2,
          text: iconFont(((_cfg$style6 = cfg.style) === null || _cfg$style6 === void 0 ? void 0 : _cfg$style6.icon) || cfg.data.type || '', ((_cfg$style7 = cfg.style) === null || _cfg$style7 === void 0 ? void 0 : _cfg$style7.fontFamily) || DEFAULT_ICON_FONT_FAMILY),
          fontSize: 20,
          textAlign: 'center',
          textBaseline: 'middle',
          fontFamily: ((_cfg$style8 = cfg.style) === null || _cfg$style8 === void 0 ? void 0 : _cfg$style8.fontFamily) || DEFAULT_ICON_FONT_FAMILY,
          fill: ((_cfg$style9 = cfg.style) === null || _cfg$style9 === void 0 ? void 0 : _cfg$style9.dark) ? '#8D93B0' : '#FFFFFF'
        },
        draggable: true,
        name: 'hexagon-name'
      });

      if (hasLabel) {
        var _cfg$style10;

        group.addShape('text', {
          attrs: {
            id: 'hexagon-label',
            x: outerSize / 2,
            y: outerSize + 14,
            fontSize: 12,
            text: cfg.label,
            textAlign: 'center',
            fill: ((_cfg$style10 = cfg.style) === null || _cfg$style10 === void 0 ? void 0 : _cfg$style10.dark) ? '#8D93B0' : '#3B3B3B'
          },
          draggable: true,
          name: 'hexagon-label'
        });
      }

      if (!cfg.badge) return keyShape;
      var children = group.addGroup({
        attrs: {
          id: 'hexagon-children-group'
        },
        draggable: true,
        name: 'hexagon-children-group'
      }, {});
      children.addShape('polygon', {
        attrs: {
          id: 'hexagon-children',
          points: makeHexagon(16),
          fill: ((_cfg$style11 = cfg.style) === null || _cfg$style11 === void 0 ? void 0 : _cfg$style11.dark) ? '#1E202D' : color.normal
        },
        draggable: true,
        name: 'hexagon-children'
      });
      children.addShape('text', {
        attrs: {
          id: 'hexagon-children-icon',
          x: 16 / 2,
          y: 16 / 2,
          text: cfg.badge,
          fontSize: 10,
          textAlign: 'center',
          textBaseline: 'middle',
          fill: ((_cfg$style12 = cfg.style) === null || _cfg$style12 === void 0 ? void 0 : _cfg$style12.dark) ? '#8D93B0' : '#FFFFFF'
        },
        draggable: true,
        name: 'hexagon-children-icon'
      });
      children.translate(outerSize / 2 - 16 / 2, 0);
      return keyShape;
    },
    setState: function setState(name, value, node) {
      var _data$style, _data$style2, _data$style3, _data$style4, _data$style5, _data$style6;

      if (!name) return;
      var data = node.get('model');
      var container = node.getContainer();
      var hexagonBorder = container.get('children').find(function (item) {
        return item.attr().id === 'hexagon-border';
      });
      var hexagonSelected = container.get('children').find(function (item) {
        return item.attr().id === 'hexagon-selected';
      });
      var hexagonInnerGroup = container.get('children').find(function (item) {
        return item.attr().id === 'hexagon-inner-group';
      });
      var hexagonInner = hexagonInnerGroup.get('children').find(function (item) {
        return item.attr().id === 'hexagon-inner';
      });
      var hexagonIcon = hexagonInnerGroup.get('children').find(function (item) {
        return item.attr().id === 'hexagon-icon';
      });
      var hexagonLabel = container.get('children').find(function (item) {
        return item.attr().id === 'hexagon-label';
      });
      var hexagonChildrenGroup = container.get('children').find(function (item) {
        return item.attr().id === 'hexagon-children-group';
      });
      var hexagonChildren = hexagonChildrenGroup === null || hexagonChildrenGroup === void 0 ? void 0 : hexagonChildrenGroup.get('children').find(function (item) {
        return item.attr().id === 'hexagon-children';
      });
      var hexagonChildrenIcon = hexagonChildrenGroup === null || hexagonChildrenGroup === void 0 ? void 0 : hexagonChildrenGroup.get('children').find(function (item) {
        return item.attr().id === 'hexagon-children-icon';
      });
      var color = ((_data$style = data.style) === null || _data$style === void 0 ? void 0 : _data$style.dark) ? GREY : normalizeColor(((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var innerNodeSize = ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : _data$style3.nodeSize) || 48;
      var innerSize = innerNodeSize > 28 ? innerNodeSize : 28;
      var outerSize = innerSize + 4;
      var targetAttrs = {
        border: {
          stroke: color.normal,
          lineWidth: 2
        },
        selected: {
          points: []
        },
        inner: {
          fill: color.dark
        },
        icon: {
          fill: ((_data$style4 = data.style) === null || _data$style4 === void 0 ? void 0 : _data$style4.dark) ? '#8D93B0' : '#FFFFFF'
        },
        label: {
          fill: ((_data$style5 = data.style) === null || _data$style5 === void 0 ? void 0 : _data$style5.dark) ? '#8D93B0' : '#3B3B3B'
        },
        children: {
          fill: color.normal
        },
        childrenIcon: {
          fill: ((_data$style6 = data.style) === null || _data$style6 === void 0 ? void 0 : _data$style6.dark) ? '#8D93B0' : '#FFFFFF'
        }
      };

      if (name === EnumNodeAndEdgeStatus.SELECTED && value) {
        targetAttrs.border.lineWidth = 5;
        targetAttrs.selected.points = makeHexagon(outerSize + 10);
      }

      if (name === EnumNodeAndEdgeStatus.LIGHT && value) {
        targetAttrs.selected.points = makeHexagon(outerSize + 10);
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.border.stroke = GREY.dark;
        targetAttrs.inner.fill = GREY.dark;
        targetAttrs.icon.fill = '#8D93B0';
        targetAttrs.label.fill = '#8D93B0';
        targetAttrs.children.fill = GREY.normal;
        targetAttrs.childrenIcon.fill = '#8D93B0';
      }

      hexagonBorder.attr(targetAttrs.border);
      hexagonSelected.attr(targetAttrs.selected);
      hexagonInner.attr(targetAttrs.inner);
      hexagonIcon.attr(targetAttrs.icon);
      if (hexagonLabel) hexagonLabel.attr(targetAttrs.label);
      if (hexagonChildren) hexagonChildren.attr(targetAttrs.children);
      if (hexagonChildrenIcon) hexagonChildrenIcon.attr(targetAttrs.childrenIcon);
    },
    getAnchorPoints: function getAnchorPoints() {
      var x = 1 / (2 + Math.sqrt(5));
      return [[0.5, 0], [1, x], [1, (Math.sqrt(5) + 1) * x], [0.5, 1], [0, (Math.sqrt(5) + 1) * x], [0, x]];
    }
  });
});

var RegisterPointNode = (function (g6) {
  g6.registerNode('PointNode', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style2, _cfg$style3;

      var hasLabel = cfg.label;
      var color = ((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : _cfg$style.dark) ? GREY : normalizeColor(((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : _cfg$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var keyShape = group.addShape('circle', {
        attrs: {
          id: 'point-floor',
          x: 0,
          y: 0,
          r: 4,
          stroke: ((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : _cfg$style3.dark) ? '#1E202D' : color.dark,
          lineWidth: 3
        },
        draggable: true,
        name: 'point-floor'
      });
      group.addShape('circle', {
        attrs: {
          id: 'point-selected',
          x: 0,
          y: 0,
          r: 0,
          stroke: '#FFF',
          lineWidth: 6,
          opacity: 0.15
        },
        draggable: true,
        name: 'point-selected'
      });

      if (hasLabel) {
        var _cfg$style4;

        group.addShape('text', {
          attrs: {
            id: 'point-label',
            x: 4 + 7,
            y: 4,
            fontSize: 12,
            text: cfg.label,
            textAlign: 'left',
            fill: ((_cfg$style4 = cfg.style) === null || _cfg$style4 === void 0 ? void 0 : _cfg$style4.dark) ? '#8D93B0' : '#3B3B3B'
          },
          draggable: true,
          name: 'point-label'
        });
      }

      return keyShape;
    },
    setState: function setState(name, value, node) {
      var _data$style, _data$style2, _data$style3;

      if (!name) return;
      var data = node.get('model');
      var container = node.getContainer();
      var floor = container.get('children').find(function (item) {
        return item.attr().id === 'point-floor';
      });
      var selected = container.get('children').find(function (item) {
        return item.attr().id === 'point-selected';
      });
      var text = container.get('children').find(function (item) {
        return item.attr().id === 'point-label';
      });
      var color = ((_data$style = data.style) === null || _data$style === void 0 ? void 0 : _data$style.dark) ? GREY : normalizeColor(((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var targetAttrs = {
        floor: {
          stroke: color.dark
        },
        selected: {
          r: 0
        },
        text: {
          fill: ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : _data$style3.dark) ? '#8D93B0' : '#3B3B3B'
        }
      };

      if (name === EnumNodeAndEdgeStatus.SELECTED && value || name === EnumNodeAndEdgeStatus.LIGHT && value) {
        targetAttrs.floor.stroke = color.normal;
        targetAttrs.selected = {
          r: 8
        };
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.floor.stroke = GREY.dark;
        targetAttrs.text.fill = '#8D93B0';
      }

      floor.attr(targetAttrs.floor);
      selected.attr(targetAttrs.selected);
      if (text) text.attr(targetAttrs.text);
    }
  });
});

var RegisterStubNode = (function (g6) {
  g6.registerNode('StubNode', {
    draw: function draw(cfg, group) {
      var _cfg$style, _cfg$style2;

      var hasLabel = cfg.label;
      var color = ((_cfg$style = cfg.style) === null || _cfg$style === void 0 ? void 0 : _cfg$style.dark) ? GREY : normalizeColor(((_cfg$style2 = cfg.style) === null || _cfg$style2 === void 0 ? void 0 : _cfg$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var keyShape = group.addShape('rect', {
        attrs: {
          id: 'stub-floor',
          x: 0,
          y: 0,
          height: 4,
          width: 12,
          radius: [2],
          fill: color.dark
        },
        draggable: true,
        name: 'stub-floor'
      });
      group.addShape('rect', {
        attrs: {
          id: 'stub-selected',
          x: 0,
          y: 0,
          height: 0,
          width: 0,
          radius: [0],
          fill: '#FFF',
          opacity: 0.15
        },
        draggable: true,
        name: 'stub-selected'
      });

      if (hasLabel) {
        var _cfg$style3;

        group.addShape('text', {
          attrs: {
            id: 'stub-label',
            x: 12 + 7,
            y: 6,
            fontSize: 12,
            text: cfg.label,
            textAlign: 'left',
            fill: ((_cfg$style3 = cfg.style) === null || _cfg$style3 === void 0 ? void 0 : _cfg$style3.dark) ? '#8D93B0' : '#3B3B3B'
          },
          draggable: true,
          name: 'stub-label'
        });
      }

      return keyShape;
    },
    setState: function setState(name, value, node) {
      var _data$style, _data$style2, _data$style3;

      if (!name) return;
      var data = node.get('model');
      var container = node.getContainer();
      var floor = container.get('children').find(function (item) {
        return item.attr().id === 'stub-floor';
      });
      var selected = container.get('children').find(function (item) {
        return item.attr().id === 'stub-selected';
      });
      var text = container.get('children').find(function (item) {
        return item.attr().id === 'stub-label';
      });
      var color = ((_data$style = data.style) === null || _data$style === void 0 ? void 0 : _data$style.dark) ? GREY : normalizeColor(((_data$style2 = data.style) === null || _data$style2 === void 0 ? void 0 : _data$style2.primaryColor) || PRIMARY_NODE_COLOR);
      var targetAttrs = {
        floor: {
          fill: color.dark
        },
        selected: {
          r: 0
        },
        text: {
          fill: ((_data$style3 = data.style) === null || _data$style3 === void 0 ? void 0 : _data$style3.dark) ? '#8D93B0' : '#3B3B3B'
        }
      };

      if (name === EnumNodeAndEdgeStatus.SELECTED && value || name === EnumNodeAndEdgeStatus.LIGHT && value) {
        targetAttrs.floor.fill = color.normal;
        targetAttrs.selected = {
          r: 8
        };
      }

      if (name === EnumNodeAndEdgeStatus.DARK && value) {
        targetAttrs.floor.fill = GREY.dark;
        targetAttrs.text.fill = '#8D93B0';
      }

      floor.attr(targetAttrs.floor);
      selected.attr(targetAttrs.selected);
      if (text) text.attr(targetAttrs.text);
    }
  });
});

// import { Node, Edge } from '@antv/g6';
var graphinHighlight = {
  getDefaultCfg: function getDefaultCfg() {
    return {
      multiple: true,
      keyCode: 18
    };
  },
  getEvents: function getEvents() {
    return {
      'node:click': 'onClick',
      'edge:click': 'onEdgeClick',
      keyup: 'onKeyUp',
      keydown: 'onKeyDown',
      'canvas:click': 'onCanvasClick'
    };
  },
  clearStates: function clearStates() {
    // eslint-disable-next-line
    var graph = this.graph;
    graph.getNodes().forEach(function (node) {
      graph.clearItemStates(node, ['selected', 'highlight.source', 'highlight.target', 'highlight.dark', 'highlight.light']);
    });
    graph.getEdges().forEach(function (edge) {
      graph.clearItemStates(edge, ['selected']);
    });
  },
  onCanvasClick: function onCanvasClick() {
    this.clearStates();
  },
  // TODO NEED TO redefine "this" type
  onEdgeClick: function onEdgeClick(e) {
    // eslint-disable-next-line
    var graph = this.graph;
    var currentEdge = e.item;
    var sourceNode = currentEdge.get('source');
    var targetNode = currentEdge.get('target');
    this.clearStates();
    currentEdge.toFront();
    graph.getNodes().forEach(function (node) {
      var id = node.get('id');

      if (id === sourceNode.get('id') || id === targetNode.get('id')) {
        graph.setItemState(sourceNode, 'highlight.source', true);
        graph.setItemState(targetNode, 'highlight.target', true);
        graph.setItemState(node, 'highlight.dark', false);
        graph.setItemState(node, 'highlight.light', true);
        graph.setItemState(currentEdge, 'selected', true);
      } else {
        graph.setItemState(node, 'highlight.light', false);
        graph.setItemState(node, 'highlight.dark', true);
      }
    });
  },
  // TODO NEED TO redefine "this" type
  process: function process(node) {
    // eslint-disable-next-line
    var graph = this.graph;
    /** process Edges */

    var allEdges = graph.getEdges();
    var relativeEdges = node.getEdges();
    var relativeEdgesIds = relativeEdges.map(function (edge) {
      return edge.get('id');
    });
    var unRelativeEdges = [];
    var relativeNodeSet = new Set([node]);
    allEdges.forEach(function (edge) {
      var id = edge.get('id');
      var source = edge.get('source');
      var target = edge.get('target');

      if (relativeEdgesIds.indexOf(id) !== -1) {
        relativeNodeSet.add(source);
        relativeNodeSet.add(target);
      } else {
        unRelativeEdges.push(edge);
      }
    });
    /** process Nodes */

    var allNodes = graph.getNodes();

    var relativeNodes = _toConsumableArray(relativeNodeSet);

    var relativeNodesIds = relativeNodes.map(function (item) {
      return item.get('id');
    });
    var unRelativeNodes = allNodes.filter(function (item) {
      return relativeNodesIds.indexOf(item.get('id')) === -1;
    });
    return {
      relativeEdges: relativeEdges,
      unRelativeEdges: unRelativeEdges,
      relativeNodes: relativeNodes,
      unRelativeNodes: unRelativeNodes
    };
  },
  // TODO NEED TO redefine "this" type
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  onClick: function onClick(e) {
    var keydown = this.keydown,
        graph = this.graph; // eslint-disable-line

    var currentNode = e.item;

    var _this$process = this.process(currentNode),
        relativeEdges = _this$process.relativeEdges,
        unRelativeEdges = _this$process.unRelativeEdges,
        relativeNodes = _this$process.relativeNodes,
        unRelativeNodes = _this$process.unRelativeNodes; // 单选


    if (!keydown) {
      this.clearStates();
      relativeNodes.forEach(function (node) {
        if (currentNode.get('id') === node.get('id')) {
          graph.setItemState(currentNode, 'selected', true);
        } else {
          graph.setItemState(node, 'highlight.dark', false);
          graph.setItemState(node, 'highlight.light', true);
        }
      });
      unRelativeNodes.forEach(function (node) {
        graph.setItemState(node, 'highlight.light', false);
        graph.setItemState(node, 'highlight.dark', true);
      });
      relativeEdges.forEach(function (edge) {
        edge.toFront();
        graph.setItemState(edge, 'highlight.dark', false);
        graph.setItemState(edge, 'highlight.light', true);
      });
      unRelativeEdges.forEach(function (edge) {
        edge.toBack();
        graph.setItemState(edge, 'highlight.light', false);
        graph.setItemState(edge, 'highlight.dark', true);
      });
    } else {
      //  按住ctrl 多选
      relativeEdges.forEach(function (edge) {
        graph.setItemState(edge, 'highlight.dark', false);
        graph.setItemState(edge, 'highlight.light', true);
      });
      graph.setItemState(currentNode, 'highlight.dark', false);
      graph.setItemState(currentNode, 'highlight.light', true);
    }
  },
  onKeyDown: function onKeyDown(e) {
    var ctx = this; // eslint-disable-line

    var keyCode = this.keyCode; // eslint-disable-line

    var code = e.keyCode || e.which;

    if (code === keyCode) {
      ctx.keydown = true;
    } else {
      ctx.keydown = false;
    }
  },
  onKeyUp: function onKeyUp() {
    var ctx = this; // eslint-disable-line

    ctx.keydown = false;
  }
};

var defaultRegister = {
  nodeShape: function nodeShape() {
    return [{
      name: 'CircleNode',
      register: function register() {
        RegisterCircleNode(G6);
      }
    }, {
      name: 'RectNode',
      register: function register() {
        RegisterRectNode(G6);
      }
    }, {
      name: 'HexagonNode',
      register: function register() {
        RegisterHexagonNode(G6);
      }
    }, {
      name: 'RegisterPointNode',
      register: function register() {
        RegisterStubNode(G6);
      }
    }, {
      name: 'StubNode',
      register: function register() {
        RegisterPointNode(G6);
      }
    }];
  },
  edgeShape: function edgeShape() {
    return [{
      name: 'SimplicityLineEdge',
      register: function register() {
        RegisterSimplicityLineEdge(G6);
      }
    }, {
      name: 'LineEdge',
      register: function register() {
        RegisterLineEdge(G6);
      }
    }, {
      name: 'LoopEdge',
      register: function register() {
        RegisterLoopEdge(G6);
      }
    }, {
      name: 'PolyEdge',
      register: function register() {
        RegisterPolyEdge(G6);
      }
    }];
  },
  behavior: function behavior() {
    return [{
      name: 'graphin-highlight',
      mode: 'default',
      options: {},
      register: function register() {
        // TODO better support for registerBehavior
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        G6.registerBehavior('graphin-highlight', graphinHighlight);
      }
    }];
  }
};
var defaultExtend = {
  nodeShape: function nodeShape() {
    return [{
      name: 'SimplicityNode',
      render: renderNodeShape
    }];
  },
  marker: function marker() {
    return [];
  },
  icon: function icon() {
    return [];
  }
};

var dummyRegister = function dummyRegister() {
  return [];
};

var dummyExtend = function dummyExtend() {
  return [];
};

var dummyIcon = function dummyIcon() {
  return [];
};

var toUpperCaseWithFirst = function toUpperCaseWithFirst(str) {
  return "".concat(str[0].toUpperCase()).concat(str.slice(1));
};

var graphinRegister = function graphinRegister(props) {
  var _props$extend = props.extend,
      extend = _props$extend === void 0 ? {} : _props$extend,
      _props$register = props.register,
      register = _props$register === void 0 ? {} : _props$register,
      _props$options = props.options,
      options = _props$options === void 0 ? {} : _props$options;
  var defaultBehaviors = defaultRegister.behavior().filter(function (behavior) {
    var behaviorName = behavior.name.split('-')[1];
    var disableName = "disable".concat(toUpperCaseWithFirst(behaviorName));
    return !options[disableName];
  }); // props.register 处理

  var _register$nodeShape = register.nodeShape,
      nodeShape = _register$nodeShape === void 0 ? dummyRegister : _register$nodeShape,
      _register$edgeShape = register.edgeShape,
      edgeShape = _register$edgeShape === void 0 ? dummyRegister : _register$edgeShape,
      _register$behavior = register.behavior,
      behavior = _register$behavior === void 0 ? dummyRegister : _register$behavior;
  var registerNodes = [].concat(_toConsumableArray(defaultRegister.nodeShape()), _toConsumableArray(nodeShape(G6)));
  var registerEdges = [].concat(_toConsumableArray(defaultRegister.edgeShape()), _toConsumableArray(edgeShape(G6)));
  var registerBehaviors = [].concat(_toConsumableArray(defaultBehaviors), _toConsumableArray(behavior(G6)));
  registerNodes.forEach(function (item) {
    item.register(G6);
  });
  registerEdges.forEach(function (item) {
    item.register(G6);
  });
  var modes = [];
  registerBehaviors.forEach(function (item) {
    item.register(G6);
    var name = item.name,
        mode = item.mode;
    modes.push(_objectSpread2({
      mode: mode,
      type: name
    }, item.options));
  });
  var initialValue = {
    default: []
  };
  var behaviorMode = modes.reduce(function (acc, curr) {
    var mode = curr.mode,
        others = _objectWithoutProperties(curr, ["mode"]);

    if (!acc[mode]) {
      acc[mode] = [];
    }

    acc[mode].push(others);
    return _objectSpread2({}, acc);
  }, initialValue); // props.extend 处理

  var _extend$icon = extend.icon,
      icon = _extend$icon === void 0 ? dummyIcon : _extend$icon,
      _extend$nodeShape = extend.nodeShape,
      ExNodeShape = _extend$nodeShape === void 0 ? dummyExtend : _extend$nodeShape,
      _extend$marker = extend.marker,
      ExMarker = _extend$marker === void 0 ? dummyExtend : _extend$marker;
  var extendNodes = [].concat(_toConsumableArray(defaultExtend.nodeShape()), _toConsumableArray(ExNodeShape()));
  var extendMarker = [].concat(_toConsumableArray(defaultExtend.marker()), _toConsumableArray(ExMarker()));
  extendNodes.forEach(function (item) {
    compiler(item);
  });
  registerInnerMarker(extendMarker);
  registerFontFamily(icon());
  return behaviorMode;
};

var HistoryController = function HistoryController() {
  var _this = this;

  _classCallCheck(this, HistoryController);

  this.save = function (state) {
    _this.history = _this.history.slice(0, _this.historyIndex + 1);
    _this.history = _this.history.concat([_objectSpread2({}, state)]);
    _this.historyIndex = _this.historyIndex + 1;
  };

  this.undo = function () {
    if (_this.getHistoryInfo().disableUndo) {
      console.warn('There is no more undo history');
      return;
    }

    _this.historyIndex = _this.historyIndex - 1;
    return _this.history[_this.historyIndex];
  };

  this.redo = function () {
    if (_this.getHistoryInfo().disableRedo) {
      console.warn('There is no more redo history');
      return;
    }

    _this.historyIndex = _this.historyIndex + 1;
    return _this.history[_this.historyIndex];
  };

  this.getHistoryInfo = function () {
    return {
      currentStep: _this.historyIndex + 1,
      allStep: _this.history.length,
      disableRedo: _this.historyIndex === _this.history.length - 1,
      disableUndo: _this.historyIndex === 0
    };
  };

  this.reset = function () {
    _this.history = [];
    _this.historyIndex = -1;
  };

  this.history = [];
  this.historyIndex = -1;
};

function isEven(number) {
  return number % 2 === 0;
}

function isOdd(number) {
  return !isEven(number);
}

function makePolyEdge(edges, data, options) {
  if (!options.edge.autoPoly) return edges;
  var noLoopEdges = edges.filter(function (edge) {
    return edge.source !== edge.target;
  });
  var loopEdges = edges.filter(function (edge) {
    return edge.source === edge.target;
  });

  var groups = groupBy(noLoopEdges, function (edge) {
    // a => b === b => a
    var name = [edge.source, edge.target].sort();
    return "".concat(name[0], "-").concat(name[1]);
  });

  var polyGroups = pickBy(groups, function (group) {
    return group.length > 1;
  });

  var directGroups = pickBy(groups, function (group) {
    return group.length <= 1;
  });

  var polyEdges = flatMap(polyGroups, function (group) {
    var distance = isEven(group.length) ? -20 : -40;
    return group.map(function (edge) {
      return {
        edge: edge,
        point: [edge.source, edge.target].sort()
      };
    }).map(function (_ref, index) {
      var edge = _ref.edge,
          point = _ref.point;
      var source = data.nodes.find(function (node) {
        return node.id === point[0];
      });
      var target = data.nodes.find(function (node) {
        return node.id === point[1];
      });
      if (!source || !target) throw new Error('Invalid Edge, Cannot Find Source/Target Node');
      if (isEven(group.length) && isEven(index)) distance += 40;
      if (isOdd(group.length) && (isOdd(index) || index === 0)) distance += 40;

      var polyEdge = _objectSpread2({}, edge, {
        shape: 'PolyEdge'
      });

      polyEdge.poly = {
        distance: isEven(index) ? distance : -distance
      };
      return polyEdge;
    });
  });

  var directEdges = flatMap(directGroups);

  var transformedEdges = [].concat(_toConsumableArray(loopEdges), _toConsumableArray(directEdges), _toConsumableArray(polyEdges));
  return transformedEdges;
}

function checkEdges(edges, data, options) {
  var transformedEdges = edges.filter(function (edge) {
    var source = edge.source,
        target = edge.target;

    if (!source || !target) {
      // eslint-disable-next-line no-console
      console.warn("edge requires  source and target\uFF0Cthis '".concat(JSON.stringify(edge), "' edge will be automatically filtered"));
      return false;
    }

    if (!edge.data) {
      // eslint-disable-next-line no-console
      console.warn("edge requires an data field\uFF0Cthis '".concat(JSON.stringify(edge), "' edge will be automatically filtered"));
      return false;
    }
    /** 边是可以重复的，因为properties可能不一样 */


    return true;
  }).map(function (edge) {
    var shape = edge.shape,
        style = edge.style;
    return _objectSpread2({
      type: shape || 'LineEdge',
      style: style || {
        line: {
          width: 1
        },
        label: {
          size: 12
        }
      },
      poly: {
        distance: 0
      },
      loopCfg: {
        position: 'top',
        dist: 20
      }
    }, edge, {
      data: _objectSpread2({}, edge.data, {
        source: edge.source,
        target: edge.target
      })
    });
  }).map(function (edge) {
    // loop edge checker
    if (!options.edge.autoLoop) return edge; // skip user-defined shape

    if (edge.type === 'LineEdge' && edge.source === edge.target) {
      edge.type = 'loop';
    }

    return edge;
  });
  transformedEdges = makePolyEdge(transformedEdges, data, options);
  return transformedEdges;
} // eslint-disable-next-line @typescript-eslint/no-unused-vars


function checkNodes(nodes, _data, _options) {
  var nodeIds = [];
  var graphinNodes = nodes.filter(function (node) {
    var id = node.id; // 如果节点不存在，则忽略该节点

    if (!id) {
      console.warn("node requires an id\uFF0Cthis '".concat(JSON.stringify(node), "' node will be automatically filtered"));
      return false;
    }

    if (!node.data) {
      console.warn("node requires an data field\uFF0Cthis '".concat(JSON.stringify(node), "' node will be automatically filtered"));
      return false;
    } // 如果节点ID存在重复，则忽略后加入的节点


    if (nodeIds.indexOf(id) !== -1) {
      return false;
    }

    nodeIds.push(id);
    return true;
  }).map(function (node) {
    return _objectSpread2({
      type: node.shape || 'CircleNode'
    }, node, {
      data: _objectSpread2({}, node.data, {
        id: node.id
      })
    });
  });
  return graphinNodes;
} // Checking data, filter out invalid data and fill in optional field with default value


var checkData = function checkData() {
  var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
    nodes: [],
    edges: []
  };
  var options = arguments.length > 1 ? arguments[1] : undefined;
  var _data$edges = data.edges,
      edges = _data$edges === void 0 ? [] : _data$edges,
      _data$nodes = data.nodes,
      nodes = _data$nodes === void 0 ? [] : _data$nodes,
      combos = data.combos; // nodes

  var graphinNodes = checkNodes(nodes); // edges

  var graphinEdges = checkEdges(edges, data, options);
  return {
    nodes: graphinNodes,
    edges: graphinEdges,
    combos: combos
  };
};

/**
 *
 * @param {*} data
 * 如果是nodes，则返回nodes，如果输入的是nodes和edges的对象，则返回对应的对象
 * @param {*} cfg
 */
var circleLayout = function circleLayout(data, cfg) {
  var x = cfg.x,
      y = cfg.y,
      r = cfg.r;
  var startX = x;
  var startY = y;
  var RR = r;
  var edges = data.edges,
      nodes = data.nodes;
  var length = nodes.length;
  var newNodes = nodes.map(function (node, index) {
    var isCenterNode = node.x === startX && node.y === startY;
    var isCenter = !!isCenterNode;
    var R = isCenterNode ? 0 : RR;
    var angle = index / length * 2 * Math.PI;
    return _objectSpread2({}, node, {
      x: isCenter ? startX : startX + R * Math.cos(angle),
      y: isCenter ? startY : startY + R * Math.sin(angle),
      layout: _objectSpread2({}, node.layout, {
        circle: {
          x: startX,
          y: startY,
          theta: angle,
          isCenter: isCenter
        }
      })
    });
  });

  if (edges) {
    return {
      nodes: newNodes,
      edges: edges
    };
  }

  return newNodes;
};

var radialLayout = function radialLayout(data, options) {
  var source = cloneDeep(data); // eslint-disable-next-line new-cap

  var layout = new G6.Layout.radial(_objectSpread2({}, options));
  layout.init(source);
  layout.execute();
  return {
    nodes: layout.nodes,
    edges: data.edges
  };
};

var getDegree = function getDegree(node, edges) {
  var nodeId = node.data.id;
  var index = 0;
  edges.forEach(function (edge) {
    if (edge.data.source === nodeId || edge.data.target === nodeId) {
      index = index + 1;
    }
  });
  return index;
};

var makeBoundingBox = function makeBoundingBox(bb) {
  if (bb.x2 != null && bb.y2 != null && bb.x2 >= bb.x1 && bb.y2 >= bb.y1) {
    return {
      x1: bb.x1,
      y1: bb.y1,
      x2: bb.x2,
      y2: bb.y2,
      w: bb.x2 - bb.x1,
      h: bb.y2 - bb.y1
    };
  }

  if (bb.w >= 0 && bb.h >= 0) {
    return {
      x1: bb.x1,
      y1: bb.y1,
      x2: bb.x1 + bb.w,
      y2: bb.y1 + bb.h,
      w: bb.w,
      h: bb.h
    };
  }
};
var defaults = {
  fit: true,
  padding: 30,
  startAngle: 3 / 2 * Math.PI,
  sweep: undefined,
  clockwise: true,
  equidistant: false,
  minNodeSpacing: 10,
  boundingBox: undefined,
  avoidOverlap: true,
  nodeDimensionsIncludeLabels: false,
  height: undefined,
  width: undefined,
  spacingFactor: undefined,
  // eslint-disable-next-line
  concentric: function concentric(node) {
    // returns numeric value for each node, placing higher nodes in levels towards the centre
    return node.degree();
  },
  // eslint-disable-next-line
  levelWidth: function levelWidth(nodes) {
    // the letiation of concentric values in each level
    return nodes.maxDegree() / 4;
  },
  animate: false,
  animationDuration: 500,
  animationEasing: undefined,
  ready: undefined,
  stop: undefined
};

var ConcentricLayout = /*#__PURE__*/function () {
  function ConcentricLayout(options) {
    _classCallCheck(this, ConcentricLayout);

    var edges = options.data.edges;
    this.options = _objectSpread2({}, defaults, {}, {
      concentric: function concentric(node) {
        // eslint-disable-next-line
        return getDegree(node, edges);
      }
    }, {}, options);
  }

  _createClass(ConcentricLayout, [{
    key: "run",
    value: function run() {
      var options = this.options;
      var clockwise = options.counterclockwise !== undefined ? !options.counterclockwise : options.clockwise;
      var nodes = this.options.data.nodes;
      var bb = makeBoundingBox(options.boundingBox ? options.boundingBox : {
        x1: 0,
        y1: 0,
        w: options.width,
        h: options.height
      });
      var center = {
        x: bb.x1 + bb.w / 2,
        y: bb.y1 + bb.h / 2
      };
      var maxNodeSize = 0; // 计算每个节点的concentric权重value

      var nodeValues = nodes.map(function (node) {
        return {
          value: options.concentric(node),
          node: node
        };
      }).sort(function (a, b) {
        return b.value - a.value;
      }); // maxNodeSize = Math.max(maxNodeSize, nbb.w, nbb.h);

      maxNodeSize = 50;
      var maxDegree = nodeValues[0].value;
      var levelWidth = options.levelWidth(nodes, maxDegree); // put the values into levels

      var levels = [[]];
      var currentLevel = levels[0];
      nodeValues.forEach(function (node) {
        if (currentLevel.length > 0) {
          var firstItem = currentLevel[0].value;
          var diff = Math.abs(firstItem - node.value);

          if (diff >= levelWidth) {
            currentLevel = [];
            levels.push(currentLevel);
          }
        }

        currentLevel.push(node);
      }); // create positions from levels

      var minDist = maxNodeSize + options.minNodeSpacing; // min dist between nodes

      if (!options.avoidOverlap) {
        // then strictly constrain to bb
        var firstLvlHasMulti = levels.length > 0 && levels[0].length > 1;
        var maxR = Math.min(bb.w, bb.h) / 2 - minDist;
        var rStep = maxR / (levels.length + (firstLvlHasMulti ? 1 : 0));
        minDist = Math.min(minDist, rStep);
      } // find the metrics for each level


      var r = 0;
      levels.forEach(function (level) {
        var sweep = options.sweep === undefined ? 2 * Math.PI - 2 * Math.PI / level.length : options.sweep;
        level.dTheta = sweep / Math.max(1, level.length - 1);
        var dTheta = level.dTheta; // calculate the radius

        if (level.length > 1 && options.avoidOverlap) {
          // but only if more than one node (can't overlap)
          var dcos = Math.cos(dTheta) - Math.cos(0);
          var dsin = Math.sin(dTheta) - Math.sin(0);
          var rMin = Math.sqrt(minDist * minDist / (dcos * dcos + dsin * dsin)); // s.t. no nodes overlapping

          r = Math.max(rMin, r);
        }

        level.r = r;
        r += minDist;
      });

      if (options.equidistant) {
        var rDeltaMax = 0;
        var radius = 0;

        for (var i = 0; i < levels.length; i++) {
          var level = levels[i];
          var rDelta = level.r - radius;
          rDeltaMax = Math.max(rDeltaMax, rDelta);
        }

        radius = 0;

        for (var _i = 0; _i < levels.length; _i++) {
          var _level = levels[_i];

          if (_i === 0) {
            radius = _level.r;
          }

          _level.r = radius;
          radius += rDeltaMax;
        }
      } // calculate the node positions


      var pos = {}; // id => position

      var outerR = [].concat(levels).pop().r;
      var result = [];

      for (var _i2 = 0; _i2 < levels.length; _i2++) {
        var _level2 = levels[_i2];
        var dTheta = _level2.dTheta;
        var _radius = _level2.r;

        for (var j = 0; j < _level2.length; j++) {
          var val = _level2[j];
          var theta = options.startAngle + (clockwise ? 1 : -1) * dTheta * j;
          var p = {
            x: center.x + _radius * Math.cos(theta),
            y: center.y + _radius * Math.sin(theta)
          };
          pos[val.node.data.id] = p;
          result.push(_objectSpread2({}, val.node, {
            data: val.node.data,
            degree: val.value,
            layout: _objectSpread2({}, val.node.layout, {
              concentric: {
                outerR: outerR,
                center: center,
                theta: theta
              }
            }),
            x: p.x,
            y: p.y
          }));
        }
      }

      var edges = options.data.edges;
      return {
        outerR: outerR,
        levels: levels,
        nodes: result,
        edges: edges
      };
    }
  }]);

  return ConcentricLayout;
}();

/**
 * 向量运算 Youtube教程：https://www.youtube.com/watch?v=Kti2mNKDOTw&list=PLA9470D64579500CE&index=6
 *
 * 向量有3个容易混淆概念
 * scalar Multip 系数积
 * dot Product 内积/点积
 * cross product 外积/有向积
 */
var Vector = function Vector(x, y) {
  var _this = this;

  _classCallCheck(this, Vector);

  this.getvec = function () {
    return _this;
  };

  this.add = function (v2) {
    return new Vector(_this.x + v2.x, _this.y + v2.y);
  };

  this.subtract = function (v2) {
    return new Vector(_this.x - v2.x, _this.y - v2.y);
  };

  this.magnitude = function () {
    return Math.sqrt(_this.x * _this.x + _this.y * _this.y);
  };

  this.normalise = function () {
    return _this.divide(_this.magnitude());
  };

  this.divide = function (n) {
    return new Vector(_this.x / n || 0, _this.y / n || 0);
  };

  this.scalarMultip = function (n) {
    return new Vector(_this.x * n, _this.y * n);
  };

  this.x = x;
  this.y = y;
};

var Point = function Point(position, id, data) {
  var _this = this;

  var mass = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1.0;

  _classCallCheck(this, Point);

  this.updateAcc = function (force) {
    /**
     * 加速度也是一个向量，根据力的平行四边形法则进行力的合成，用向量运算就是加运算
     */
    _this.a = _this.a.add(force.divide(_this.m)); // a = a + F/m
  };

  this.p = position; // 点的位置，用[x,y]向量来表示

  this.m = mass; // 点的质量，默认为1.0

  this.v = new Vector(0, 0); // 速度，初始值为向量零 [0,0] velocity, init with x=0, y=0

  this.a = new Vector(0, 0); // 加速度，初始值为向量零 [0,0] acceleration, init with x=0, y=0

  this.id = id; // 点的唯一ID  id of Point, defaults to -1

  this.data = data;
};

var Node = function Node(data) {
  _classCallCheck(this, Node);

  this.id = data.id;
  this.data = data || {};
  this.x = data.x || 0;
  this.y = data.y || 0;
};
var Edge = function Edge(id, source, target, data) {
  _classCallCheck(this, Edge);

  this.id = id;
  this.source = source;
  this.target = target;
  this.data = data || {};
};

var Spring = function Spring(source, target, length) {
  _classCallCheck(this, Spring);

  this.source = source;
  this.target = target;
  this.length = length;
};

var ForceLayout = function ForceLayout(options) {
  var _this = this;

  _classCallCheck(this, ForceLayout);

  /**
   * Iterate options to update this.props
   * @param {*} options
   */
  this.updateOptions = function (options) {
    if (!options) {
      return;
    }

    Object.keys(options).forEach(function (key) {
      _this.props[key] = options[key];
    });
  };

  this.setData = function (data) {
    // clean all data
    _this.nodes = [];
    _this.edges = [];
    _this.nodeSet = {};
    _this.edgeSet = {};
    _this.nodePoints = new Map();
    _this.edgeSprings = new Map();
    _this.sourceData = data;
    _this.averageDistance = 0; // add nodes and edges

    if ('nodes' in data || 'edges' in data) {
      _this.addNodes(data.nodes); // eslint-disable-next-line


      _this.addEdges(data.edges);
    }
  };

  this.getMass = function (node) {
    var _ref = node.layout || {},
        _ref$degree = _ref.degree,
        degree = _ref$degree === void 0 ? getDegree(node, _this.edges) : _ref$degree,
        force = _ref.force;
    /** 当你在layout.force.mass中制定了才使用 */


    if (force && force.mass) {
      // eslint-disable-next-line prefer-destructuring
      return force.mass;
    }
    /** 默认质量都是通过节点的度数自动计算的 */


    return degree < 5 ? 1 : degree * 10;
  };

  this.init = function () {
    /** 初始化点和边的信息 */
    var _this$props = _this.props,
        width = _this$props.width,
        height = _this$props.height;

    _this.nodes.forEach(function (node) {
      var x = node.data.x || width / 2;
      var y = node.data.y || height / 2;
      var vec = new Vector(x, y);

      if (!node.data.layout) {
        node.data.layout = {};
      }

      var degree = getDegree(node, _this.edges);
      node.data.layout.degree = degree;

      var mass = _this.getMass(node.data);

      _this.nodePoints.set(node.id, new Point(vec, String(node.id), node.data, mass));
    });

    _this.edges.forEach(function (edge) {
      var source = _this.nodePoints.get(edge.source.id);

      var target = _this.nodePoints.get(edge.target.id);

      var length = _this.props.defSpringLen(edge, source, target);

      _this.edgeSprings.set(edge.id, new Spring(source, target, length));
    });
    /** 其他参数设置 */


    var size = _this.nodePoints.size;
    var vv = Math.pow(10, 2);
    _this.props.minEnergyThreshold = 1 / 2 * Math.pow(1, 2) * 1 * size * vv;
  };

  this.start = function () {
    /** 初始化节点 */
    _this.init();

    if (_this.props.animation) _this.animation();else _this.slienceForce();
  };

  this.calTotalEnergy = function () {
    var energy = 0.0;

    _this.nodes.forEach(function (node) {
      var point = _this.nodePoints.get(node.id);

      var speed = point.v.magnitude();
      var m = point.m; // 1;

      energy += m * Math.pow(speed, 2) * 0.5; // p = 1/2*(mv^2)
    });

    return energy;
  };

  this.slienceForce = function () {
    var firstTickInterval = 0.22;

    for (var i = 0; i < _this.props.MaxIterations; i++) {
      var tickInterval = Math.max(0.02, firstTickInterval - i * 0.002);

      _this.tick(tickInterval);

      var energy = _this.calTotalEnergy();
      /** 如果需要监控信息，则提供给用户 */


      var monitor = _this.registers.get('monitor');

      if (monitor) {
        monitor(_this.reportMointor(energy));
      }

      if (energy <= _this.props.minEnergyThreshold || i === _this.props.MaxIterations - 1 // 1000000次/(1000/60) = 60000s = 1min
      ) {
          _this.render();

          if (_this.props.done) {
            _this.props.done();
          }

          break;
        }
    }
  };
  /** polyfill: support webworker requestAnimationFrame */
  // eslint-disable-next-line @typescript-eslint/no-explicit-any


  this.requestAnimationFrame = function (fn) {
    var enableWorker = _this.props.enableWorker;

    if (enableWorker) {
      return setInterval(function () {
        fn();
      }, 16);
    }

    return window.requestAnimationFrame(fn);
  };

  this.cancelAnimationFrame = function (handleId) {
    var enableWorker = _this.props.enableWorker;

    if (enableWorker) {
      clearInterval(handleId);
    } else {
      window.cancelAnimationFrame(handleId);
    }
  };

  this.animation = function () {
    if (_this.props.enableWorker) {
      var startTimer = new Date().valueOf();
      var firstTickInterval = 0.22;

      var interval = function interval(step) {
        // 目标：迭代10次，稳定在2s，函数选择需要后续考虑
        return step > 10 ? 2000 : 20 * step * step;
      };

      for (var i = 0; i < _this.props.MaxIterations; i++) {
        var tickInterval = Math.max(0.02, firstTickInterval - i * 0.002);

        _this.tick(tickInterval);

        var diff = new Date().valueOf() - startTimer;

        if (diff >= interval(i)) {
          _this.render();

          startTimer = new Date().valueOf();
        }

        var energy = _this.calTotalEnergy();
        /** 如果需要监控信息，则提供给用户 */


        var monitor = _this.registers.get('monitor');

        if (monitor) {
          monitor(_this.reportMointor(energy));
        } // console.log('average', this.averageDistance);


        if (_this.averageDistance < 0.5) {
          _this.render();

          if (_this.props.done) {
            _this.props.done();
          }

          return;
        }
      }

      return;
    }

    var step = function step() {
      var _this$props2 = _this.props,
          done = _this$props2.done,
          tickInterval = _this$props2.tickInterval;

      _this.tick(tickInterval);

      _this.render();

      _this.iterations++;

      var energy = _this.calTotalEnergy();
      /** 如果需要监控信息，则提供给用户 */


      var monitor = _this.registers.get('monitor');

      if (monitor) {
        monitor(_this.reportMointor(energy));
      } // console.log('average', this.averageDistance);


      if (_this.averageDistance < 0.5) {
        _this.cancelAnimationFrame(_this.timer);

        _this.iterations = 0;
        _this.done = true;

        if (done) {
          done();
        }
      } else {
        _this.timer = _this.requestAnimationFrame(step);
      }
    };

    _this.timer = _this.requestAnimationFrame(step);
  };

  this.render = function () {
    var render = _this.registers.get('render');

    var nodes = [];

    _this.nodePoints.forEach(function (node) {
      nodes.push(_objectSpread2({}, _this.nodeSet[node.id] && _this.nodeSet[node.id].data, {
        x: node.p.x,
        y: node.p.y
      }));
    });

    if (render) {
      render({
        nodes: nodes,
        edges: _this.sourceData.edges
      });
    } else {
      // eslint-disable-next-line no-console
      console.error('need a render function');
    }
  };

  this.reportMointor = function (energy) {
    var params = {
      energy: energy,
      iterations: _this.iterations,
      nodes: _this.nodes,
      edges: _this.edges
    };
    return params;
  };

  this.tick = function (interval) {
    _this.updateCoulombsLaw();

    _this.updateHookesLaw();

    _this.attractToCentre();

    _this.updateVelocity(interval);

    _this.updatePosition(interval);
  };
  /** 布局算法 */


  this.updateCoulombsLaw = function () {
    var len = _this.nodes.length;

    for (var i = 0; i < len; i++) {
      for (var j = i + 1; j < len; j++) {
        // eslint-disable-next-line no-continue
        if (i === j) continue;
        var iNode = _this.nodes[i];
        var jNode = _this.nodes[j];
        var coulombDisScale = _this.props.coulombDisScale;
        var repulsion = _this.props.repulsion;

        var v = _this.nodePoints.get(iNode.id).p.subtract(_this.nodePoints.get(jNode.id).p);

        var dis = (v.magnitude() + 0.1) * coulombDisScale;
        var direction = v.normalise(); // 向量的方向：基向量

        var factor = 1;

        _this.nodePoints.get(iNode.id).updateAcc( // 得到库伦力
        direction.scalarMultip(repulsion * factor).divide(Math.pow(dis, 2)));

        _this.nodePoints.get(jNode.id).updateAcc(direction.scalarMultip(repulsion * factor).divide(-Math.pow(dis, 2)));
      }
    }
  };

  this.updateHookesLaw = function () {
    _this.edges.forEach(function (edge) {
      var spring = _this.edgeSprings.get(edge.id);

      var v = spring.target.p.subtract(spring.source.p);
      var displacement = spring.length - v.magnitude();
      var direction = v.normalise();
      spring.source.updateAcc(direction.scalarMultip(-_this.props.stiffness * displacement));
      spring.target.updateAcc(direction.scalarMultip(_this.props.stiffness * displacement));
    });
  };

  this.attractToCentre = function () {
    var implementForce = function implementForce(node, center) {
      var radio = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 2;

      var point = _this.nodePoints.get(node.id);

      var direction = point.p.subtract(center);
      point.updateAcc(direction.scalarMultip(-radio));
    };

    _this.nodes.forEach(function (node) {
      // 默认的向心力指向画布中心
      var degree = node.data && node.data.layout && node.data.layout.degree;
      var leafNode = degree === 1;
      var singleNode = degree === 0;
      /** 默认的向心力配置 */

      var defaultRadio = {
        leaf: 2,
        single: 2,
        others: 1,
        // eslint-disable-next-line
        center: function center(_node) {
          return {
            x: _this.props.width / 2,
            y: _this.props.height / 2
          };
        }
      };

      var _defaultRadio$_this$p = _objectSpread2({}, defaultRadio, {}, _this.props.centripetalOptions),
          leaf = _defaultRadio$_this$p.leaf,
          single = _defaultRadio$_this$p.single,
          others = _defaultRadio$_this$p.others,
          center = _defaultRadio$_this$p.center;

      var _center = center(node),
          x = _center.x,
          y = _center.y;

      var centerVector = new Vector(x, y);
      /** 如果radio为0，则认为忽略向心力 */

      if (leaf === 0 || single === 0 || others === 0) {
        return;
      }

      if (singleNode) {
        implementForce(node, centerVector, single);
        return;
      }

      if (leafNode) {
        implementForce(node, centerVector, leaf);
        return;
      }
      /** others */


      implementForce(node, centerVector, others);
    });
  };

  this.updateVelocity = function (interval) {
    _this.nodes.forEach(function (node) {
      var point = _this.nodePoints.get(node.id);

      point.v = point.v.add(point.a.scalarMultip(interval)) // 根据加速度求速度公式 V_curr= a*@t + V_pre
      .scalarMultip(_this.props.damping);

      if (point.v.magnitude() > _this.props.maxSpeed) {
        point.v = point.v.normalise().scalarMultip(_this.props.maxSpeed);
      }

      point.a = new Vector(0, 0);
    });
  };

  this.updatePosition = function (interval) {
    var sum = 0;

    _this.nodes.forEach(function (node) {
      var point = _this.nodePoints.get(node.id);

      var distance = point.v.scalarMultip(interval);
      sum = sum + distance.magnitude();
      point.p = point.p.add(point.v.scalarMultip(interval)); // 路程公式 s = v * t
    });

    _this.averageDistance = sum / _this.nodes.length;
  };
  /**
   * add one Node
   * @param {[type]} node [description]
   */


  this.addNode = function (node) {
    var ignore = _this.props.ignore;

    if (ignore && ignore(node)) {
      return;
    }

    if (!(node.id in _this.nodeSet)) {
      _this.nodes.push(node);
    }

    _this.nodeSet[node.id] = node;
  };
  /**
   * add Nodes
   * @param {[type]} data [description]
   */


  this.addNodes = function (data) {
    data.forEach(function (node) {
      _this.addNode(new Node(node));
    });
  };
  /**
   * add one Edge
   * @param {[type]} edge [description]
   */


  this.addEdge = function (edge) {
    if (!(edge.id in _this.edgeSet)) {
      _this.edges.push(edge);
    }

    _this.edgeSet[edge.id] = edge;
    return edge;
  };
  /**
   * add Edges
   * @param {[type]} data [description]
   */


  this.addEdges = function (data) {
    try {
      var len = data.length;

      for (var i = 0; i < len; i++) {
        var e = data[i];
        var sourceId = e.source;
        var targetId = e.target; // eslint-disable-next-line

        var node1 = _this.nodeSet[sourceId];

        if (node1 === undefined) {
          throw new TypeError("invalid node name: ".concat(e.source));
        } // eslint-disable-next-line


        var node2 = _this.nodeSet[targetId];

        if (node2 === undefined) {
          throw new TypeError("invalid node name: ".concat(e.target));
        }

        var attr = e.data;
        var edge = new Edge(String(_this.nextEdgeId++), node1, node2, attr);

        _this.addEdge(edge);
      }
    } catch (error) {
      console.error(error);
    }
  }; // eslint-disable-next-line @typescript-eslint/no-explicit-any


  this.register = function (type, options) {
    _this.registers.set(type, options); // 将用户的自定义函数注册进来

  };

  this.restart = function (dragNode, graph) {
    /** 将位置更新到nodePoint中 */
    var ignore = _this.props.ignore;
    graph.getNodes().forEach(function (nodeItem) {
      var node = nodeItem.get('model');

      if (ignore && ignore(node)) {
        return;
      }

      var vec = new Vector(node.x, node.y);

      var point = _this.nodePoints.get(node.id);

      if (point) {
        point.p = vec;

        _this.nodePoints.set(node.id, point);
      }
    });

    var changeNodePosition = function changeNodePosition(node) {
      var vec = new Vector(node.x, node.y); // const mass = (node.layout && node.layout.force && node.layout.force.mass) || 100000;

      var mass = _this.getMass(node);

      _this.nodePoints.set(node.id, new Point(vec, node.id, node.data, mass));

      _this.edges.forEach(function (edge) {
        var source = _this.nodePoints.get(edge.source.id);

        var target = _this.nodePoints.get(edge.target.id);

        if (source.id === node.id || target.id === node.id) {
          var length = _this.edgeSprings.get(edge.id).length || 100;

          _this.edgeSprings.set(edge.id, new Spring(source, target, length));
        }
      });
    }; // TODO:支持多点拖拽


    dragNode.forEach(changeNodePosition);
    if (_this.props.restartAnimation) _this.animation();else _this.slienceForce();
  };

  this.stop = function () {
    window.cancelAnimationFrame(_this.timer);
    _this.done = true;
  };

  this.props = {
    stiffness: 200.0,
    enableWorker: false,
    defSpringLen: function defSpringLen(edge) {
      return edge.data.spring || 200;
    },
    repulsion: 200.0 * 5,
    centripetalOptions: {
      leaf: 2,
      single: 2
    },
    damping: 0.9,
    minEnergyThreshold: 0.1,
    maxSpeed: 1000,
    coulombDisScale: 0.005,
    tickInterval: 0.02,
    groupFactor: 4,
    MaxIterations: 10000,
    animation: true,
    restartAnimation: true,
    width: 200,
    height: 200
  };
  this.updateOptions(options);
  /** 存放器：节点与边 */

  this.sourceData = {
    nodes: [],
    edges: []
  };
  this.nodes = [];
  this.edges = [];
  this.nodeSet = {};
  this.edgeSet = {};
  this.nodePoints = new Map();
  this.edgeSprings = new Map();
  this.registers = new Map();
  this.done = false;
  this.averageDistance = 0;
  /** 计数器 */

  this.iterations = 0;
  this.nextEdgeId = 0; // 边属性计数自增

  this.timer = 0;
  this.center = new Vector(0, 0);
};

/**
 *
 * @param {boolean} isOptimize 是否开启Shape的渲染优化，默认针对非KeyShape节点
 * @param {Item} node 单个Node
 */
var optimizeDrawingByNode = function optimizeDrawingByNode(isOptimize, node) {
  var shapes = node.getContainer().get('children');
  var keyShape = shapes.find(function (item) {
    return item.isKeyShape;
  }); //eslint-disable-line

  keyShape.show();
  shapes.forEach(function (shape) {
    if (isOptimize && shape !== keyShape) {
      shape.hide();
    } else {
      shape.show();
    }
  });
};
/**
 *
 * @param {object} graph G6的Graph实例
 * @param {boolean} isOptimize 是否减少Shape的渲染，默认是非KeyShape节点
 */


var optimizeDrawing = function optimizeDrawing(graph, isOptimize) {
  graph.getNodes().forEach(function (node) {
    optimizeDrawingByNode(isOptimize, node);
  });
  /** 渲染 */

  graph.autoPaint();
};

var forceOptions = {};
var workerFunction = (function () {
  onmessage = function onmessage(e) {
    var data = e.data;
    /** parser an object with method */

    var newForceOptions = JSON.parse(JSON.stringify(forceOptions), function (key, value) {
      if (typeof value === 'string' && value.indexOf('function ') === 0) {
        // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
        // @ts-ignore
        // eslint-disable-next-line no-eval
        return eval("(".concat(value, ")"));
      }

      return value;
    });
    var simulation = new ForceLayout(_objectSpread2({}, newForceOptions, {
      done: function done() {
        // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
        // @ts-ignore
        postMessage({
          done: true
        });
        if (newForceOptions.done) newForceOptions.done();
      }
    }));
    simulation.setData(data); // eslint-disable-next-line @typescript-eslint/no-explicit-any

    simulation.register('render', function (forceData) {
      // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
      // @ts-ignore
      postMessage({
        forceData: forceData,
        done: false
      });
    });
    simulation.start();
  };
});

var babelDepString = ["function _instanceof(left, right) { if (right != null && typeof Symbol !== \"undefined\" && right[Symbol.hasInstance]) { return !!right[Symbol.hasInstance](left); } else { return left instanceof right; } }\n  function _classCallCheck(instance, Constructor) { if (!_instanceof(instance, Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n  function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }\n  function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }\n  var  _objectSpread2 = Object.assign\n  "];
var workerDepString = [Point.toString(), Vector.toString(), Spring.toString(), Node.toString(), Edge.toString(), getDegree.toString(), ForceLayout.toString()];
var globalWorker;

var forceLayout = function forceLayout(data, options) {
  var graph = options.graph,
      others = _objectWithoutProperties(options, ["graph"]);

  if (globalWorker) {
    globalWorker.terminate();
  }
  /** serialize an object with method */


  var optionString = JSON.stringify(others, // eslint-disable-next-line
  function (_key, value) {
    if (typeof value === 'function') {
      return value.toString();
    }

    return value;
  }, 2);
  var workerStringArray = [].concat(babelDepString, workerDepString, ["const forceOptions = ".concat(optionString, ";"), workerFunction.toString(), ";workerFunction()"]);
  /** Build a worker from an anonymous function body */

  var blobURL = URL.createObjectURL(new Blob(['(()=>{'].concat(_toConsumableArray(workerStringArray), ['})()']), {
    type: 'application/javascript'
  }));
  globalWorker = new Worker(blobURL);
  globalWorker.postMessage({
    nodes: data.nodes,
    edges: data.edges
  }); // let renderIndex = -1;
  // replace array to swap to avoid memory leak
  // eslint-disable-next-line @typescript-eslint/no-explicit-any

  var swap = {};
  var requestAnimationFrameId;

  globalWorker.onmessage = function (e) {
    var _e$data = e.data,
        forceData = _e$data.forceData,
        done = _e$data.done; // renderIndex = renderIndex + 1;
    // allData.push(forceData);
    // swap.pre = swap.current;

    if (requestAnimationFrameId) window.cancelAnimationFrame(requestAnimationFrameId);

    if (done) {
      // force render
      return;
    }

    if (!swap.pre) {
      // 从第二个渲染开始做补间动画
      swap.pre = forceData;
    } else {
      swap.current = forceData; // eslint-disable-next-line @typescript-eslint/no-explicit-any

      swap.current.nodes.forEach(function (node, index) {
        var preNode = swap.pre.nodes[index]; // 计算出每个节点的 deltaX 与 deltaY
        // 补间动画可能需要重新设计采样频率才能保证顺滑
        // 至少保证60像素的位移，避免补间动画卡顿问题

        var deltaX = (node.x - preNode.x) / 60;
        var deltaY = (node.y - preNode.y) / 60; // 同方向至少移动1像素
        // eslint-disable-next-line no-nested-ternary

        deltaX = Math.abs(deltaX) > 1 ? deltaX : deltaX >= 0 ? 1 : -1; // eslint-disable-next-line no-nested-ternary

        deltaY = Math.abs(deltaY) > 1 ? deltaY : deltaY >= 0 ? 1 : -1;
        preNode.deltaX = deltaX;
        preNode.deltaY = deltaY;
      });
      /** 补间动画 */

      var step = function step() {
        // console.time('cost');
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        swap.pre.nodes.forEach(function (item) {
          var node = graph.findById(item.id);
          var model = node.get('model');
          model.x = item.x;
          model.y = item.y;
          item.x = item.x + item.deltaX;
          item.y = item.y + item.deltaY;
        });
        graph.refreshPositions(); // console.timeEnd('cost');

        requestAnimationFrameId = window.requestAnimationFrame(step);
      };

      requestAnimationFrameId = window.requestAnimationFrame(step);
    }
  };

  return {
    data: data,
    // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
    // @ts-ignore
    simulation: null
  };
};

var forceLayout$1 = function forceLayout$1(data, options) {
  var width = options.width,
      height = options.height,
      graph = options.graph,
      _options$enableWorker = options.enableWorker,
      enableWorker = _options$enableWorker === void 0 ? false : _options$enableWorker,
      animation = options.animation,
      _options$done = options.done,
      _done = _options$done === void 0 ? function (_graph) {} : _options$done,
      isOptimization = options.isOptimization,
      others = _objectWithoutProperties(options, ["width", "height", "graph", "enableWorker", "animation", "done", "isOptimization"]);
  /** Webworker solution. Otherwise, browser UI rendering is blocked */


  if (enableWorker && data.nodes.length > 100) {
    // 100以下的节点不走webworker
    return forceLayout(data, options);
  }
  /** 1. Create a force simulator */


  var simulation = new ForceLayout(_objectSpread2({
    width: width,
    height: height,
    animation: animation !== undefined ? animation : true,
    done: function done() {
      if (isOptimization) {
        optimizeDrawing(graph, false);
      }

      _done(graph);
    }
  }, others)); // 2. Mount Data

  simulation.setData(data); // 3. Custom rendering function

  simulation.register('render', function (forceData) {
    try {
      forceData.nodes.forEach(function (item) {
        var node = graph.findById(item.id);

        if (node) {
          // 因为有可能画布删除了节点
          var model = node.get('model');
          model.x = item.x;
          model.y = item.y;

          if (isOptimization) {
            optimizeDrawingByNode(true, node);
          }
        }
      });
      graph.refreshPositions();
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
    }
  });
  /**  4. Start force  simulator */

  simulation.start();
  return {
    data: data,
    simulation: simulation
  };
};

var dagreLayout = function dagreLayout(data, options) {
  var source = cloneDeep(data); // eslint-disable-next-line new-cap

  var layout = new G6.Layout.dagre(_objectSpread2({
    type: 'dagre'
  }, options));
  layout.init(source);
  layout.execute();
  return {
    nodes: layout.nodes,
    edges: data.edges
  }; // graph.positionsAnimate();
};

var gridLayout = function gridLayout(data, options) {
  var width = options.width,
      height = options.height,
      _options$nodeSep = options.nodeSep,
      nodeSep = _options$nodeSep === void 0 ? 100 : _options$nodeSep,
      _options$nodeSize = options.nodeSize,
      nodeSize = _options$nodeSize === void 0 ? 50 : _options$nodeSize;
  var nodes = data.nodes,
      edges = data.edges;
  var count = nodes.length;
  var cols = Math.round(Math.sqrt(count * (height / width))); // 列的个数

  var rows = Math.round(Math.sqrt(count * (width / height))); // 行的个数

  var start = {
    x: width / 2 - (cols / 2 - 1) * (nodeSize + nodeSep / 2),
    y: height / 2 - (rows / 2 - 1) * (nodeSize + nodeSep / 2)
  };
  var resultNodes = nodes.map(function (node, index) {
    var xIndex = Math.floor(index / cols) - 1; // 行序号，向下取整

    var yIndex = Math.floor(index % cols) - 1; // 列序号，向下取整

    var x = start.x + xIndex * (nodeSize + nodeSep / 2);
    var y = start.y + yIndex * (nodeSize + nodeSep / 2);
    return _objectSpread2({}, node, {
      x: x,
      y: y
    });
  });
  return {
    nodes: resultNodes,
    edges: edges
  };
};

var randomLayout = function randomLayout(data, cfg) {
  var defaultBbox = {
    x: 0,
    y: 0,
    w: 500,
    h: 500
  };
  var bbox = cfg.bbox;

  var _defaultBbox$bbox = _objectSpread2({}, defaultBbox, {}, bbox),
      x = _defaultBbox$bbox.x,
      y = _defaultBbox$bbox.y,
      w = _defaultBbox$bbox.w,
      h = _defaultBbox$bbox.h;

  var edges = data.edges,
      nodes = data.nodes;
  var newNodes = nodes.map(function (node) {
    return _objectSpread2({}, node, {
      x: x + Math.round(Math.random() * w),
      y: y + Math.round(Math.random() * h)
    });
  });
  return {
    nodes: newNodes,
    edges: edges
  };
};

/* eslint-disable no-param-reassign */
var getRandomPosition = function getRandomPosition() {
  return Math.round((Math.random() - 0.5) * 80);
};
/**
 *
 * @param data
 * @param options
 */


var tweak = function tweak(data, options) {
  var graph = options.graph,
      width = options.width,
      height = options.height;
  var currNodes = data.nodes,
      currEdges = data.edges; // TODO: Graph Type export TreeData
  // eslint-disable-next-line @typescript-eslint/no-explicit-any

  var _graph$save = graph.save(),
      preNodes = _graph$save.nodes;
  /** 将图上之前节点的位置信息存储在positionMap中 */


  var positionMap = new Map();
  preNodes.forEach(function (item) {
    var id = item.id,
        x = item.x,
        y = item.y;
    positionMap.set(id, {
      x: x,
      y: y
    });
  });
  var incrementNodesMap = new Map();
  currNodes.forEach(function (node) {
    var id = node.id;
    var position = positionMap.get(id);

    if (position) {
      node.x = position.x;
      node.y = position.y;
    } else {
      incrementNodesMap.set(id, node);
    }
  });
  var incrementPositonMap = new Map();
  currEdges.forEach(function (edge) {
    var source = edge.source,
        target = edge.target;
    var nodeInSource = incrementNodesMap.get(source);
    var nodeInTarget = incrementNodesMap.get(target);
    var positionInSource = positionMap.get(source);
    var positionInTarget = positionMap.get(target);

    if (nodeInSource && positionInTarget) {
      incrementPositonMap.set(source, {
        // ...nodeInSource,
        x: positionInTarget.x + getRandomPosition(),
        y: positionInTarget.y + getRandomPosition()
      });
    }

    if (nodeInTarget && positionInSource) {
      incrementPositonMap.set(target, {
        // ...nodeInTarget,
        x: positionInSource.x + getRandomPosition(),
        y: positionInSource.y + getRandomPosition()
      });
    }
  });
  currNodes.forEach(function (node) {
    var id = node.id;
    var position = positionMap.get(id) || incrementPositonMap.get(id);

    if (position) {
      node.x = position.x;
      node.y = position.y;
    } else {
      node.x = Math.round(Math.random() * width);
      node.y = Math.round(Math.random() * height);
    }
  });
  return {
    data: {
      nodes: currNodes,
      edges: currEdges
    }
  };
};

var defaultLayouts = function defaultLayouts(graphin, prevProps) {
  var graph = graphin.graph;
  var width = graph.get('width');
  var height = graph.get('height');
  return [{
    name: 'random',
    desc: '随机布局',
    icon: 'random',
    layout: function layout(data, options) {
      var defaultOptions = {
        /** 随机区域的bbox */
        bbox: {
          x: 0,
          y: 0,
          w: width,
          h: height
        }
      };
      return {
        data: randomLayout(data, _objectSpread2({}, defaultOptions, {}, options))
      };
    }
  }, {
    name: 'circle',
    desc: '圆形布局',
    icon: 'chrome',
    layout: function layout(data, options) {
      var defaultOptions = {
        /** 圆心 x坐标 */
        x: width / 2,

        /** 圆心 y坐标 */
        y: height / 2,

        /** 半径，默认半径为节点数*10 */
        r: data.nodes.length * 10
      };
      return {
        data: circleLayout(data, _objectSpread2({}, defaultOptions, {}, options))
      };
    }
  }, {
    name: 'dagre',
    desc: '有向分层',
    icon: 'apartment',
    layout: function layout(data, options) {
      var defaultOptions = {
        /** 中心点坐标 */
        // WARNING: center is not working any more ?
        center: [0, 0],

        /** 节点大小 */
        nodeSize: [50, 50],

        /**  节点水平间距(px) */
        nodesep: 12,

        /** 每一层节点之间间距 */
        ranksep: 50,

        /** 放置位置 */
        align: 'UL'
      };
      return {
        data: dagreLayout(data, _objectSpread2({}, defaultOptions, {}, options))
      };
    }
  }, {
    name: 'radial',
    desc: '迳向布局',
    icon: 'trademark',
    layout: function layout(data, options) {
      var defaultOptions = {
        /** 中心点坐标 */
        center: [width / 2, height / 2],

        /** 防止覆盖 */
        preventOverlap: true,

        /** 节点大小 */
        nodeSize: 100,

        /** 每层的半径 */
        unitRadius: 150
      };
      return {
        data: radialLayout(data, _objectSpread2({}, defaultOptions, {}, options))
      };
    }
  }, {
    name: 'grid',
    desc: '横纵布局',
    icon: 'appstore',
    layout: function layout(data, options) {
      var defaultOptions = {
        /** 布局范围的宽度 */
        width: width,

        /** 布局范围的高度 */
        height: height,

        /** 节点间的间距，上下左右均是一致的 */
        nodeSep: 100,

        /** 节点的大小，单位px */
        nodeSize: 50
      };
      return {
        data: gridLayout(data, _objectSpread2({}, defaultOptions, {}, options))
      };
    }
  }, {
    name: 'concentric',
    desc: '同心圆布局',
    icon: 'chrome',
    layout: function layout(data, options) {
      var defaultOptions = {
        /** 同心圆的布局范围，默认为当前画布的宽高范围 */
        boundingBox: {
          x1: 0,
          y1: 0,
          w: width,
          h: height
        },

        /** 节点间的距离，默认为60 */
        minNodeSpacing: 60,

        /** 每层的节点度数范围 */
        levelWidth: function levelWidth(nodes, maxDegree) {
          /** 同心圆层数 */
          var levelNum = 8;
          return maxDegree / levelNum;
        }
      };
      return {
        data: new ConcentricLayout(_objectSpread2({}, defaultOptions, {}, options, {
          data: data
        })).run()
      };
    }
  }, {
    name: 'force',
    desc: '力导布局',
    icon: 'branches',
    layout: function layout(data, options) {
      var defaultOptions = {
        data: data,

        /** 前置布局，默认为 concentric */
        preset: {
          /** 特殊情况处理：前置布局为force，但是前置的数据也为空，则证明是初始化force布局，否则为正常前置force布局 */
          name: prevProps.layout && prevProps.layout.name || 'concentric',
          options: {}
        },

        /** spring stiffness 弹簧劲度系数 * */
        stiffness: 200.0,

        /** repulsion 斥力，这里指代 库伦常量Ke */
        repulsion: 200.0 * 5,

        /** 向心力 */
        centripetalOptions: {
          leaf: 1.6,
          single: 1.6
        },

        /** 速度的减震因子，其实就是阻尼系数 */
        damping: 0.9,

        /** 最小能量阈值，当粒子运动，有阻尼系数的存在，最终会将初始的能量消耗殆尽 */
        minEnergyThreshold: 0.1,

        /** 最大的速度 [0,1000] */
        maxSpeed: 1000,

        /** 最大迭代数 */
        MaxIterations: 10000,

        /** 是否开启动画 */
        animation: true
      };

      var layouOpts = _objectSpread2({}, defaultOptions, {}, options);

      var _layouOpts$preset = layouOpts.preset,
          presetName = _layouOpts$preset.name,
          _layouOpts$preset$opt = _layouOpts$preset.options,
          presetOptions = _layouOpts$preset$opt === void 0 ? {} : _layouOpts$preset$opt;

      if (presetName === 'force' && data.nodes.length === 0) {
        presetName = 'concentric';
        presetOptions = {};
      }

      var presetData = data; // 处理 前置布局后的数据

      if (presetName === 'force') {
        presetData = tweak(presetData, options).data;
      } else {
        var layouts = defaultLayouts(graphin, prevProps);
        var presetLayout = layouts.find(function (item) {
          return item.name === presetName;
        }) || layouts[5]; // concentric

        presetData = presetLayout === null || presetLayout === void 0 ? void 0 : presetLayout.layout(data, presetOptions).data;
      }

      var force = forceLayout$1(presetData, layouOpts);
      return {
        data: force.data,
        forceSimulation: force.simulation
      };
    }
  }];
};

var layoutInfo = function layoutInfo(layouts) {
  return layouts.map(function (item) {
    var desc = item.desc,
        name = item.name,
        icon = item.icon;
    return {
      desc: desc,
      name: name,
      icon: icon
    };
  });
};

var noopLayout = function noopLayout() {
  return [];
};

var layoutController = function layoutController(graphin, params) {
  var _graphin$g6Options, _graphin$g6Options2;

  var props = graphin.props,
      forceSimulation = graphin.forceSimulation,
      graph = graphin.graph;
  var width = graph.get('width');
  var height = graph.get('height');
  var PropsData = params.data,
      _params$prevProps = params.prevProps,
      prevProps = _params$prevProps === void 0 ? props : _params$prevProps;
  var layout = props.layout; // 数据的校验

  var data = checkData(PropsData, {
    edge: {
      autoPoly: !!((_graphin$g6Options = graphin.g6Options) === null || _graphin$g6Options === void 0 ? void 0 : _graphin$g6Options.autoPolyEdge),
      autoLoop: !!((_graphin$g6Options2 = graphin.g6Options) === null || _graphin$g6Options2 === void 0 ? void 0 : _graphin$g6Options2.autoLoopEdge)
    }
  }); // 重置forceSimulation

  if (forceSimulation) {
    forceSimulation.stop();
  } // 注册 Layout


  var _props$extend = props.extend,
      extend = _props$extend === void 0 ? {} : _props$extend;
  var extendLayout = extend.layout || noopLayout;
  var layouts = [].concat(_toConsumableArray(defaultLayouts(graphin, prevProps)), _toConsumableArray(extendLayout(graphin, prevProps))); // eslint-disable-next-line no-param-reassign

  graphin.getLayoutInfo = function () {
    return layoutInfo(layouts);
  }; // 当没有节点，则不参加布局


  if (data.nodes && data.nodes.length === 0) {
    return {
      data: data
    };
  }

  var hasPosition = data.nodes.every(function (node) {
    return !window.isNaN(Number(node.x)) && !window.isNaN(Number(node.y));
  });

  if (!(layout && layout.name)) {
    // layout不存在，且有位置信息，则认为是 save-render 操作
    if (hasPosition) {
      return {
        data: data
      };
    }

    layout = {
      name: 'concentric'
    };
  } // 设置布局的 options参数


  var _layout = layout,
      name = _layout.name;

  var options = _objectSpread2({
    graph: graph,
    width: width,
    height: height,
    data: data
  }, layout.options); // 得到当前匹配的布局函数


  var matchLayout = layouts.find(function (item) {
    return item.name === name;
  }) || {
    name: '',
    icon: '',
    layout: function layout(inputData) {
      return {
        data: inputData
      };
    }
  };
  var layoutData = matchLayout.layout(data, options);
  return _objectSpread2({}, layoutData, {
    data: _objectSpread2({}, layoutData.data, {
      combos: data.combos
    })
  });
};

var highlight = function highlight(graph) {
  return function (nodeIds) {
    graph.getNodes().forEach(function (node) {
      graph.clearItemStates(node, ['highlight.light', 'highlight.dark']);

      if (nodeIds.indexOf(node.get('id')) !== -1) {
        graph.setItemState(node, 'highlight.light', false);
      } else {
        graph.setItemState(node, 'highlight.dark', true);
      }
    });
  };
};

var getInfo = function getInfo(graph) {
  return function () {
    var nodes = graph.get('nodes');
    var edges = graph.get('edges');
    return {
      count: {
        nodes: nodes.length,
        edges: edges.length
      }
    };
  };
};

var search = function search(graph) {
  return function () {
    var words = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    // 搜索分词，默认空格隔开
    var wordsArray = words.trim().split(' '); // 目前先只支持node 的搜索
    // TODO: why graph export TreeData ?
    // eslint-disable-next-line @typescript-eslint/no-explicit-any

    var _graph$save = graph.save(),
        nodes = _graph$save.nodes; // 匹配方法


    var matchWord = function matchWord(node, word) {
      var id = node.id,
          _node$label = node.label,
          label = _node$label === void 0 ? '' : _node$label,
          properties = node.properties; // 按 id 匹配

      if (word && String(id).indexOf(word) !== -1) {
        return {
          isMatch: true,
          searchType: 'id'
        };
      } // 按 label 匹配


      if (word && String(label).indexOf(word) !== -1) {
        return {
          isMatch: true,
          searchType: 'label'
        };
      }

      var matchProperty = []; // 按 property 匹配

      if (properties) {
        // eslint-disable-next-line
        matchProperty = properties.filter(function (property) {
          return property.value && property.value === word;
        });
      }

      if (matchProperty.length > 0) {
        return {
          isMatch: true,
          searchType: 'property'
        };
      }

      return {
        isMatch: false,
        searchType: ''
      };
    };

    var result = [];
    nodes.forEach(function (node) {
      var matchResult = wordsArray.map(function (word) {
        return matchWord(node.data, word);
      });
      var searchTypes = matchResult.reduce(function (acc, curr) {
        var searchType = curr.searchType;

        if (searchType && acc.indexOf(searchType) === -1) {
          acc.push(searchType);
        }

        return acc;
      }, []);

      if (searchTypes.length > 0) {
        result.push(_objectSpread2({}, node, {
          searchTypes: searchTypes
        }));
      }
    });
    return result;
  };
};

var apis = function apis(context) {
  var graph = context.graph,
      clear = context.clear,
      handleRedo = context.handleRedo,
      handleUndo = context.handleUndo,
      handleSaveHistory = context.handleSaveHistory,
      getHistoryInfo = context.getHistoryInfo,
      getLayoutInfo = context.getLayoutInfo;
  return {
    highlight: function highlight$1(nodeIds) {
      return highlight(graph)(nodeIds);
    },
    getInfo: function getInfo$1() {
      return _objectSpread2({}, getInfo(graph)(), {
        layouts: getLayoutInfo()
      });
    },
    search: function search$1(words) {
      return search(graph)(words);
    },
    history: {
      redo: handleRedo,
      undo: handleUndo,
      save: handleSaveHistory,
      getInfo: getHistoryInfo
    },
    clear: clear
  };
};

var getContainerSize = function getContainerSize(el) {
  var clientWidth = el.clientWidth,
      clientHeight = el.clientHeight;
  return {
    width: clientWidth,
    height: clientHeight
  };
};

var handleResize = function handleResize(graphin) {
  var graphDOM = graphin.graphDOM,
      graph = graphin.graph;

  var _getContainerSize = getContainerSize(graphDOM),
      width = _getContainerSize.width,
      height = _getContainerSize.height;

  graph.set('width', width);
  graph.set('height', height);
  var canvas = graph.get('canvas');

  if (canvas) {
    canvas.changeSize(width, height);
    graph.autoPaint();
    graphin.setState({
      width: width,
      height: height
    });
  }
};

var changeZoom = function changeZoom(graphin) {
  var graph = graphin.graph,
      g6Options = graphin.g6Options; // const { forceSimulation } = state;

  var _g6Options$isZoomOpti = g6Options.isZoomOptimize,
      isZoomOptimize = _g6Options$isZoomOpti === void 0 ? function () {
    return false;
  } : _g6Options$isZoomOpti,
      _g6Options$keyShapeZo = g6Options.keyShapeZoom,
      keyShapeZoom = _g6Options$keyShapeZo === void 0 ? 0.6 : _g6Options$keyShapeZo;
  /** 缩放的时候隐藏IMAGE/TEXT */

  var timer = null;
  graph.on('viewportchange', function (evt) {
    if (evt.action === 'zoom' && isZoomOptimize(graph, evt)) {
      if (timer) window.clearTimeout(timer);
      timer = window.setTimeout(function () {
        try {
          if (graphin.state.forceSimulation) {
            /** 如果存在力导，那么缩放结束且力导未结束前，只展示keyShape */
            if (graphin.state.forceSimulation.done) optimizeDrawing(graph, false);
          }
          /** 只有缩放比率大于keyShapeZoom，才展示所有的，否则只展示keyshape */


          if (graph.getZoom() > keyShapeZoom) {
            optimizeDrawing(graph, false);
          }
        } catch (error) {
          optimizeDrawing(graph, false);
        }
      }, 200);
      optimizeDrawing(graph, true);
    }
  });
};

var dragWithForce = function dragWithForce(graphin) {
  var graph = graphin.graph,
      g6Options = graphin.g6Options;
  var _g6Options$autoFollow = g6Options.autoFollowWithForce,
      autoFollowWithForce = _g6Options$autoFollow === void 0 ? true : _g6Options$autoFollow,
      _g6Options$autoPinWit = g6Options.autoPinWithForce,
      autoPinWithForce = _g6Options$autoPinWit === void 0 ? true : _g6Options$autoPinWit,
      _g6Options$restartFor = g6Options.restartForceOnDrag,
      restartForceOnDrag = _g6Options$restartFor === void 0 ? true : _g6Options$restartFor;
  /** 拖拽Force节点：start */

  graph.on('node:dragstart', function () {
    if (graphin.state.forceSimulation) {
      graphin.state.forceSimulation.stop();
    }
  });
  /** 拖拽结束 */

  graph.on('node:dragend', function (e) {
    if (graphin.state.forceSimulation && autoFollowWithForce && restartForceOnDrag) {
      var nodeModel = e.item.get('model');
      nodeModel.x = e.x;
      nodeModel.y = e.y; // 策略：拖拽后就定在拖拽处

      nodeModel.layout = _objectSpread2({}, nodeModel.layout, {
        force: {
          mass: autoPinWithForce ? 1000000 : null
        }
      }); // TODO :未来多选可以拖拽。

      var drageNodes = [nodeModel];
      graphin.state.forceSimulation.restart(drageNodes, graph);
      graph.refreshPositions();
    }
  });
};

var handleGraphEvents = function handleGraphEvents(graphin) {
  /**
   * 监听window事件
   * resize :debounce处理
   */
  var handleResizeEvent = debounce(function () {
    handleResize(graphin);
  }, 100);
  window.addEventListener('resize', handleResizeEvent, false);
  /**
   * 监听wheel/zoom事件
   */

  changeZoom(graphin);
  /**
   * 基于力导的节点拖拽
   */

  dragWithForce(graphin);
  /**
   * 事件清除
   */

  return {
    clear: function clear() {
      window.removeEventListener('resize', handleResizeEvent, false);
    }
  };
};

/* eslint-disable @typescript-eslint/no-explicit-any */
var deepEqual = function deepEqual(x, y) {
  /** 1. NaN */
  if (window.isNaN(x) && window.isNaN(y) && typeof x === 'number' && typeof y === 'number') {
    return true;
  }
  /** 2. primitives and function reference */


  if (x === y) {
    return true;
  }
  /** 3.Function,Date,RegExp,String,Number */


  if (typeof x === 'function' && typeof y === 'function' || x instanceof Date && y instanceof Date || x instanceof RegExp && y instanceof RegExp || x instanceof String && y instanceof String || x instanceof Number && y instanceof Number) {
    return x.toString() === y.toString();
  }
  /** 4.plain object */


  if (!(x instanceof Object && y instanceof Object)) {
    return false;
  }

  var isEqualArray = [];
  var xKey = Object.keys(x);
  var yKey = Object.keys(y);

  if (xKey.length !== yKey.length) {
    return false;
  }

  for (var i = 0; i < xKey.length; i++) {
    var key = xKey[i];
    var isEqual = deepEqual(x[key], y[key]);
    isEqualArray.push(isEqual);
  }

  return isEqualArray.every(function (c) {
    return c;
  });
};

var Graph = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Graph, _React$PureComponent);

  var _super = _createSuper(Graph);

  function Graph(props) {
    var _this;

    _classCallCheck(this, Graph);

    _this = _super.call(this, props);
    _this.graphDOM = null;

    _this.getApis = function () {
      var context = _this.getContext();

      return apis(context);
    };

    _this.getHistoryInfo = function () {
      return _this.history.getHistoryInfo();
    };

    _this.clear = function () {
      _this.graph.clear();

      _this.history.reset();

      _this.clearEvents();

      _this.setState({
        data: {
          nodes: [],
          edges: []
        },
        forceSimulation: null,
        graphSave: null
      }, function () {
        var data = _this.state.data;

        _this.renderGraph(data);
      });
    };

    _this.getContext = function () {
      return _assertThisInitialized(_this);
    };

    _this.renderGraphWithLifeCycle = function (firstRender) {
      var data = _this.state.data;

      _this.graph.changeData(cloneDeep(data));

      _this.graph.emit('afterchangedata');

      _this.handleSaveHistory();

      if (firstRender) {
        initGraphAfterRender(_this.props, _this.graphDOM, _this.graph);
      }
    };

    _this.stopForceSimulation = function () {
      var forceSimulation = _this.state.forceSimulation;

      if (forceSimulation) {
        forceSimulation.stop();
      }
    };

    _this.handleSaveHistory = function () {
      var currentState = _objectSpread2({}, _this.state, {
        graphSave: cloneDeep(_this.graph.save())
      });

      _this.history.save(currentState);
    };

    _this.handleUndo = function () {
      _this.stopForceSimulation();

      var prevState = _this.history.undo();

      if (prevState) {
        _this.setState(_objectSpread2({}, prevState), function () {
          _this.renderGraphByHistory();
        });
      }
    };

    _this.handleRedo = function () {
      _this.stopForceSimulation();

      var nextState = _this.history.redo();

      if (nextState) {
        _this.setState(_objectSpread2({}, nextState), function () {
          _this.renderGraphByHistory();
        });
      }
    };

    _this.renderGraph = function (data) {
      _this.graph.changeData(cloneDeep(data));
      /**
       * TODO 移除 `afterchangedata` Event
       * 此方法应该放到G6的changeData方法中去emit
       */


      _this.graph.emit('afterchangedata');
    };

    _this.renderGraphByHistory = function () {
      var _this$state = _this.state,
          forceSimulation = _this$state.forceSimulation,
          graphSave = _this$state.graphSave;

      if (forceSimulation) {
        forceSimulation.restart(graphSave.nodes || [], _this.graph);
      }

      _this.renderGraph(graphSave);
    };

    _this.renderChildren = function () {
      var children = _this.props.children;
      var combineProps = {
        graph: _this.graph,
        graphDOM: _this.graphDOM,
        graphVars: _this.state,
        apis: _this.getApis()
      };

      if (!children) {
        return null;
      }

      if (typeof children === 'function') {
        return children(combineProps);
      }
      /**
       * 1. <Graphin> <div> this is text <ContextMenu />  </div> </Graphin>
       * 2. <Graphin> <CustomerComponent> this is text  <ContextMenu /> </CustomerComponent> </Graphin>
       * 3. <Graphin> <Fragment> this is text  <ContextMenu /> </Graphin>
       */


      if (React.isValidElement(children) && (String(children.type) === 'Symbol(react.fragment)' || typeof children.type === 'string')) {
        console.error('Please do not wrap components inside dom element or Fragment when using Graphin');
        return children;
      }

      if (!Array.isArray(children)) {
        children = [children];
      }

      return React.Children.map(children, function (child) {
        // do not pass props if element is a DOM element or not a valid react element.
        if (!React.isValidElement(child) || typeof child.type === 'string') {
          return child;
        }

        return React.cloneElement(child, _objectSpread2({}, combineProps));
      });
    };

    _this.state = {
      isGraphReady: false,
      data: props.data,
      forceSimulation: null,
      width: 0,
      height: 0,
      graphSave: null
    };
    _this.history = new HistoryController();
    _this.forceSimulation = null;

    _this.getLayoutInfo = function () {};

    return _this;
  }

  _createClass(Graph, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      var data = this.props.data; // register props.extend and props.register

      var behaviorsMode = graphinRegister(this.props); // init G6 instance

      var _initController = initGraph(this.props, this.graphDOM, behaviorsMode),
          instance = _initController.instance,
          width = _initController.width,
          height = _initController.height,
          options = _initController.options;

      this.g6Options = options;
      this.graph = instance;

      var _layoutController = layoutController(this.getContext(), {
        data: data
      }),
          newData = _layoutController.data,
          forceSimulation = _layoutController.forceSimulation;

      this.forceSimulation = forceSimulation;
      this.setState({
        isGraphReady: true,
        graph: this.graph,
        width: width,
        height: height,
        data: newData,
        forceSimulation: forceSimulation
      }, function () {
        _this2.renderGraphWithLifeCycle(true);
      });
      this.handleEvents();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var _this3 = this;

      var isDataChange = this.shouldUpdate(prevProps, 'data');
      var isLayoutChange = this.shouldUpdate(prevProps, 'layout'); // only rerender when data or layout change

      if (isDataChange || isLayoutChange) {
        var currentData = this.state.data;

        if (isDataChange) {
          var _data = this.props.data;
          currentData = _data;
        }

        var _layoutController2 = layoutController(this.getContext(), {
          data: currentData,
          prevProps: prevProps
        }),
            data = _layoutController2.data,
            forceSimulation = _layoutController2.forceSimulation;

        this.forceSimulation = forceSimulation;
        this.setState({
          data: data,
          forceSimulation: forceSimulation
        }, function () {
          // rerender Graph
          _this3.renderGraphWithLifeCycle();
        });
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.clearEvents();
    }
  }, {
    key: "componentDidCatch",
    value: function componentDidCatch(error, info) {
      console.error('Catch component error: ', error, info);
    }
  }, {
    key: "shouldUpdate",
    value: function shouldUpdate(prevProps, key) {
      /* eslint-disable react/destructuring-assignment */
      var prevVal = prevProps[key];
      var currentVal = this.props[key]; // console.time('deep equal');

      var isEqual = deepEqual(prevVal, currentVal); // console.timeEnd('deep equal');

      return !isEqual;
    }
  }, {
    key: "handleEvents",
    value: function handleEvents() {
      this.clearEvents = handleGraphEvents(this.getContext()).clear;
    }
  }, {
    key: "render",
    value: function render() {
      var _this4 = this;

      var isGraphReady = this.state.isGraphReady;
      return React.createElement("div", {
        id: "graphin-container"
      }, React.createElement("div", {
        "data-testid": "custom-element",
        className: "graphin-core",
        ref: function ref(node) {
          _this4.graphDOM = node;
        }
      }), React.createElement("div", {
        className: "graphin-components"
      }, isGraphReady && this.renderChildren()));
    }
  }]);

  return Graph;
}(React.PureComponent);

var Tree = function Tree(root) {
  var _this = this;

  _classCallCheck(this, Tree);

  this.nodeIds = [];

  this.bfs = function (cb) {
    if (!_this.root) {
      return;
    }

    var queue = [];
    queue.push(_this.root);

    while (queue.length) {
      var node = queue.shift();

      if (cb(node)) {
        return node;
      }

      if (node.children.length) {
        queue.push.apply(queue, _toConsumableArray(node.children));
      }
    }
  };

  this.getRoot = function () {
    return _this.root;
  };

  this.getNode = function (id) {
    var result = _this.bfs(function (node) {
      return node.id === id;
    });

    return result;
  }; // eslint-disable-next-line


  this.addRoot = function (id, data) {
    _this.root = {
      id: id,
      data: data,
      children: []
    };
    _this.root.parent = _this.root;

    _this.nodeIds.push(id);
  }; // eslint-disable-next-line


  this.addNode = function (conf) {
    var parentId = conf.parentId,
        id = conf.id,
        data = conf.data;

    if (!_this.root) {
      _this.addRoot(id, data);

      return;
    }

    var parent;

    if (!parentId) {
      // If parentId was not given, pick a random node as parent
      var index = Math.floor(Math.random() * _this.nodeIds.length);
      parent = _this.getNode(_this.nodeIds[index]);
    } else {
      parent = _this.getNode(parentId);
    }

    if (!parent) {
      console.error("Parent node doesn't exist!");
      return;
    }

    _this.nodeIds.push(id);

    parent.children.push({
      id: id,
      data: data,
      parent: parent,
      children: []
    });
  }; // Pass in the root of an existing tree


  if (root) this.root = root;
};

var defaultOptions = {
  /** 节点 */
  nodeCount: 10,
  nodeType: 'company'
};
/**
 * 1,mock data with edges,nodes
 * 2.mock nodes properties
 * 3.filter edges
 * 4.
 */

var Mock = function Mock(count) {
  var _this = this;

  _classCallCheck(this, Mock);

  this.initNodes = function () {
    var _this$options = _this.options,
        nodeCount = _this$options.nodeCount,
        nodeType = _this$options.nodeType;
    var temp = Array.from({
      length: nodeCount
    });
    _this.nodes = temp.map(function (node, index) {
      return {
        id: "node-".concat(index),
        label: "node-".concat(index),
        type: nodeType,
        properties: []
      };
    });

    for (var i = 0; i < nodeCount; i = i + 1) {
      for (var j = 0; j < nodeCount - 1; j = j + 1) {
        _this.edges.push({
          source: "node-".concat(i),
          target: "node-".concat(j),
          label: "edge-".concat(i, "_").concat(j),
          properties: []
        });
      }
    }

    _this.nodeIds = _this.nodes.map(function (node) {
      return node.id;
    });
  };

  this.expand = function (snodes) {
    _this.edges = [];
    _this.nodes = [];
    snodes.forEach(function (node) {
      for (var i = 0; i < _this.options.nodeCount; i += 1) {
        _this.nodes.push({
          id: "".concat(node.id, "-").concat(i),
          type: node.type,
          label: "".concat(node.id, "-").concat(i),
          properties: []
        });

        _this.edges.push({
          source: "".concat(node.id, "-").concat(i),
          target: node.id,
          label: "edge-".concat(i, "_").concat(node.id),
          properties: []
        });
      }
    });
    return _this;
  };

  this.type = function (nodeType) {
    _this.nodes = _this.nodes.map(function (node) {
      return _objectSpread2({}, node, {
        type: nodeType
      });
    });
    return _this;
  };

  this.circle = function () {
    var centerId = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
    var id = centerId;

    if (_this.nodeIds.indexOf(id) === -1) {
      id = 'node-0';
    }

    _this.edges = _this.edges.filter(function (edge) {
      return edge.source === id || edge.target === id;
    });
    return _this;
  };
  /**
   * @param ratio 随机的稀疏程度，默认0.5
   */


  this.random = function () {
    var ratio = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0.5;
    var nodeCount = _this.options.nodeCount;
    var length = parseInt(String(nodeCount * ratio));
    /**  随机ID */

    var randomArray = _this.nodeIds.sort(function () {
      return Math.random() - 0.5;
    }).slice(0, length);

    _this.edges = _this.edges.filter(function (edge) {
      return randomArray.indexOf(edge.target) !== -1;
    });
    _this.edges = _this.edges.sort(function () {
      return Math.random() - 0.5;
    }).slice(0, length);
    return _this;
  };

  this.tree = function () {
    _this.edges = [];
    var tree = new Tree();
    var rootId = _this.nodeIds[0];

    _this.nodeIds.forEach(function (id) {
      tree.addNode({
        id: id
      });
    });

    tree.bfs(function (node) {
      if (node.id !== rootId) {
        _this.edges.push({
          source: node.parent && node.parent.id,
          target: node.id,
          label: "edge-".concat(node.parent && node.parent.id, "_").concat(node.id),
          properties: []
        });
      }

      return false;
    });
    return _this;
  };

  this.value = function () {
    return {
      nodes: _this.nodes,
      edges: _this.edges
    };
  };

  this.combos = function (chunkSize) {
    var comboIds = new Set();
    _this.nodes = _this.nodes.map(function (node, index) {
      var comboIndex = Math.ceil((index + 1) / chunkSize);
      var comboId = "combo-".concat(comboIndex);
      comboIds.add(comboId);
      return _objectSpread2({}, node, {
        comboId: comboId
      });
    });
    _this.combosData = _toConsumableArray(comboIds).map(function (c) {
      return {
        id: c,
        label: c
      };
    });
    return _this;
  };

  this.graphin = function () {
    return {
      nodes: _this.nodes.map(function (node) {
        return {
          id: node.id,
          label: "node-".concat(node.id),
          data: node,
          shape: 'CircleNode',
          comboId: node.comboId,
          style: {
            nodeSize: 24
          }
        };
      }),
      edges: _this.edges.map(function (edge) {
        return {
          source: edge.source,
          target: edge.target,
          label: edge.label,
          data: edge
        };
      }),
      combos: _this.combosData
    };
  };

  this.options = defaultOptions;
  this.options.nodeCount = count;
  this.nodes = [];
  this.edges = [];
  this.nodeIds = [];
  this.initNodes();
};

var mock = function mock(count) {
  return new Mock(count);
};
/**
 * mock(10).type('company').value()
 * mock(10).type('company').circle('node-1').value()
 * mock(10).type('company').random('node-1').value()
 * mock(10).type('company').random('node-1').value()
 *
 *
 * graphin()
 */

var floorRandom = function floorRandom(number) {
  return Math.floor(Math.random() * number);
};

var randomColor = function randomColor() {
  var opacity = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
  var r = floorRandom(255);
  var g = floorRandom(255);
  var b = floorRandom(255);
  var color = "rgba(".concat(r, ",").concat(g, ",").concat(b, ",").concat(opacity, ")");
  return color;
};

var colorMap = {};
/**
 *
 * @param {*} name 分类的名称
 * @example
 * debug('Tooltip')('render','...')
 * @todo https://developer.mozilla.org/zh-CN/docs/Web/API/Console
 *
 */

var debug = function debug(name) {
  if (!colorMap[name]) {
    colorMap[name] = randomColor();
  }

  var color = colorMap[name]; // eslint-disable-next-line

  return function () {
    // eslint-disable-line
    if ( process.env.NODE_ENV === 'development') {
      var _console;

      for (var _len = arguments.length, message = new Array(_len), _key = 0; _key < _len; _key++) {
        message[_key] = arguments[_key];
      }

      // eslint-disable-next-line no-console
      (_console = console).log.apply(_console, ["%c".concat(name), "color:  ".concat(color, "; font-style:italic ;padding: 2px;font-weight:700")].concat(message));
    }
  };
};

var shallowEqual = function shallowEqual(prev, current) {
  var isEqual = true;
  var prevKeys = Object.keys(prev);
  var currentKeys = Object.keys(current);
  if (prevKeys.length !== currentKeys.length) return false;

  for (var i = 0; i < prevKeys.length; i++) {
    var key = prevKeys[i];

    if (prev[key] !== current[key]) {
      isEqual = false;
      break;
    }
  }

  return isEqual;
};

var index = {
  hexToRgba: hexToRgba,
  debug: debug,
  mock: mock,
  shallowEqual: shallowEqual
};

var index$1 = {
  Dagre: dagreLayout,
  Radial: radialLayout,
  Force: ForceLayout,
  Concentric: ConcentricLayout,
  Circle: circleLayout,
  Grid: gridLayout,
  Random: randomLayout,
  Tweak: tweak
};

export default Graph;
export { index$1 as Layout, index as Utils };
